/********************************************************************************
** Form generated from reading UI file 'KasaSmartSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KASASMARTSETTINGSENTRY_H
#define UI_KASASMARTSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_KasaSmartSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLineEdit *NameEdit;
    QLabel *IPLabel;
    QLineEdit *IPEdit;
    QLabel *NameLabel;

    void setupUi(QWidget *KasaSmartSettingsEntry)
    {
        if (KasaSmartSettingsEntry->objectName().isEmpty())
            KasaSmartSettingsEntry->setObjectName(QString::fromUtf8("KasaSmartSettingsEntry"));
        KasaSmartSettingsEntry->resize(216, 89);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KasaSmartSettingsEntry->sizePolicy().hasHeightForWidth());
        KasaSmartSettingsEntry->setSizePolicy(sizePolicy);
        KasaSmartSettingsEntry->setWindowTitle(QString::fromUtf8("Kasa Smart Settings Entry"));
        gridLayout = new QGridLayout(KasaSmartSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(KasaSmartSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 1, 5, 1, 1);

        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 1, 0, 1, 1);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 1, 3, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 1, 4, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(KasaSmartSettingsEntry);

        QMetaObject::connectSlotsByName(KasaSmartSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *KasaSmartSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("KasaSmartSettingsEntry", "Kasa Smart Device", nullptr));
        IPLabel->setText(QCoreApplication::translate("KasaSmartSettingsEntry", "IP:", nullptr));
        NameLabel->setText(QCoreApplication::translate("KasaSmartSettingsEntry", "Name", nullptr));
        (void)KasaSmartSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class KasaSmartSettingsEntry: public Ui_KasaSmartSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_KASASMARTSETTINGSENTRY_H
