/********************************************************************************
** Form generated from reading UI file 'OpenRGBPluginContainer.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBPLUGINCONTAINER_H
#define UI_OPENRGBPLUGINCONTAINER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBPluginContainer
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *PluginContainerLayout;

    void setupUi(QWidget *OpenRGBPluginContainer)
    {
        if (OpenRGBPluginContainer->objectName().isEmpty())
            OpenRGBPluginContainer->setObjectName(QString::fromUtf8("OpenRGBPluginContainer"));
        OpenRGBPluginContainer->resize(256, 120);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OpenRGBPluginContainer->sizePolicy().hasHeightForWidth());
        OpenRGBPluginContainer->setSizePolicy(sizePolicy);
        OpenRGBPluginContainer->setWindowTitle(QString::fromUtf8("Plugin Container"));
        verticalLayout = new QVBoxLayout(OpenRGBPluginContainer);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        PluginContainerLayout = new QGridLayout();
        PluginContainerLayout->setObjectName(QString::fromUtf8("PluginContainerLayout"));

        verticalLayout->addLayout(PluginContainerLayout);


        retranslateUi(OpenRGBPluginContainer);

        QMetaObject::connectSlotsByName(OpenRGBPluginContainer);
    } // setupUi

    void retranslateUi(QWidget *OpenRGBPluginContainer)
    {
        (void)OpenRGBPluginContainer;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBPluginContainer: public Ui_OpenRGBPluginContainer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBPLUGINCONTAINER_H
