/********************************************************************************
** Form generated from reading UI file 'NanoleafSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NANOLEAFSETTINGSENTRY_H
#define UI_NANOLEAFSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NanoleafSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *IPLabel;
    QLabel *IPValue;
    QLabel *PortLabel;
    QLabel *PortValue;
    QLabel *AuthKeyLabel;
    QLabel *AuthKeyValue;
    QPushButton *UnpairButton;
    QPushButton *PairButton;

    void setupUi(QWidget *NanoleafSettingsEntry)
    {
        if (NanoleafSettingsEntry->objectName().isEmpty())
            NanoleafSettingsEntry->setObjectName(QString::fromUtf8("NanoleafSettingsEntry"));
        NanoleafSettingsEntry->resize(287, 207);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(NanoleafSettingsEntry->sizePolicy().hasHeightForWidth());
        NanoleafSettingsEntry->setSizePolicy(sizePolicy);
        NanoleafSettingsEntry->setWindowTitle(QString::fromUtf8("Nanoleaf Settings Entry"));
        gridLayout = new QGridLayout(NanoleafSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(NanoleafSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 1, 0, 1, 1);

        IPValue = new QLabel(groupBox);
        IPValue->setObjectName(QString::fromUtf8("IPValue"));

        gridLayout_2->addWidget(IPValue, 1, 1, 1, 4);

        PortLabel = new QLabel(groupBox);
        PortLabel->setObjectName(QString::fromUtf8("PortLabel"));

        gridLayout_2->addWidget(PortLabel, 2, 0, 1, 1);

        PortValue = new QLabel(groupBox);
        PortValue->setObjectName(QString::fromUtf8("PortValue"));

        gridLayout_2->addWidget(PortValue, 2, 1, 1, 1);

        AuthKeyLabel = new QLabel(groupBox);
        AuthKeyLabel->setObjectName(QString::fromUtf8("AuthKeyLabel"));

        gridLayout_2->addWidget(AuthKeyLabel, 3, 0, 1, 1);

        AuthKeyValue = new QLabel(groupBox);
        AuthKeyValue->setObjectName(QString::fromUtf8("AuthKeyValue"));

        gridLayout_2->addWidget(AuthKeyValue, 3, 1, 1, 1);

        UnpairButton = new QPushButton(groupBox);
        UnpairButton->setObjectName(QString::fromUtf8("UnpairButton"));

        gridLayout_2->addWidget(UnpairButton, 4, 1, 1, 1);

        PairButton = new QPushButton(groupBox);
        PairButton->setObjectName(QString::fromUtf8("PairButton"));

        gridLayout_2->addWidget(PairButton, 4, 1, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(NanoleafSettingsEntry);

        QMetaObject::connectSlotsByName(NanoleafSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *NanoleafSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("NanoleafSettingsEntry", "Nanoleaf Device", nullptr));
        IPLabel->setText(QCoreApplication::translate("NanoleafSettingsEntry", "IP:", nullptr));
        IPValue->setText(QString());
        PortLabel->setText(QCoreApplication::translate("NanoleafSettingsEntry", "Port:", nullptr));
        PortValue->setText(QString());
        AuthKeyLabel->setText(QCoreApplication::translate("NanoleafSettingsEntry", "Auth Key:", nullptr));
        AuthKeyValue->setText(QString());
        UnpairButton->setText(QCoreApplication::translate("NanoleafSettingsEntry", "Unpair", nullptr));
        PairButton->setText(QCoreApplication::translate("NanoleafSettingsEntry", "Pair", nullptr));
        (void)NanoleafSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class NanoleafSettingsEntry: public Ui_NanoleafSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NANOLEAFSETTINGSENTRY_H
