/********************************************************************************
** Form generated from reading UI file 'ManualDevicesSettingsPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANUALDEVICESSETTINGSPAGE_H
#define UI_MANUALDEVICESSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ManualDevicesSettingsPage
{
public:
    QAction *ActionSaveAndRescan;
    QAction *ActionSaveNoRescan;
    QVBoxLayout *verticalLayout;
    QListWidget *deviceList;
    QHBoxLayout *horizontalLayout;
    QPushButton *addDeviceButton;
    QPushButton *removeDeviceButton;
    QToolButton *saveConfigurationButton;

    void setupUi(QWidget *ManualDevicesSettingsPage)
    {
        if (ManualDevicesSettingsPage->objectName().isEmpty())
            ManualDevicesSettingsPage->setObjectName(QString::fromUtf8("ManualDevicesSettingsPage"));
        ManualDevicesSettingsPage->resize(400, 300);
        ManualDevicesSettingsPage->setWindowTitle(QString::fromUtf8("Manually Added Devices Settings Page"));
        ActionSaveAndRescan = new QAction(ManualDevicesSettingsPage);
        ActionSaveAndRescan->setObjectName(QString::fromUtf8("ActionSaveAndRescan"));
        ActionSaveNoRescan = new QAction(ManualDevicesSettingsPage);
        ActionSaveNoRescan->setObjectName(QString::fromUtf8("ActionSaveNoRescan"));
        verticalLayout = new QVBoxLayout(ManualDevicesSettingsPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        deviceList = new QListWidget(ManualDevicesSettingsPage);
        deviceList->setObjectName(QString::fromUtf8("deviceList"));
        deviceList->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        verticalLayout->addWidget(deviceList);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        addDeviceButton = new QPushButton(ManualDevicesSettingsPage);
        addDeviceButton->setObjectName(QString::fromUtf8("addDeviceButton"));

        horizontalLayout->addWidget(addDeviceButton);

        removeDeviceButton = new QPushButton(ManualDevicesSettingsPage);
        removeDeviceButton->setObjectName(QString::fromUtf8("removeDeviceButton"));

        horizontalLayout->addWidget(removeDeviceButton);

        saveConfigurationButton = new QToolButton(ManualDevicesSettingsPage);
        saveConfigurationButton->setObjectName(QString::fromUtf8("saveConfigurationButton"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(saveConfigurationButton->sizePolicy().hasHeightForWidth());
        saveConfigurationButton->setSizePolicy(sizePolicy);
        saveConfigurationButton->setPopupMode(QToolButton::MenuButtonPopup);

        horizontalLayout->addWidget(saveConfigurationButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(ManualDevicesSettingsPage);

        QMetaObject::connectSlotsByName(ManualDevicesSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ManualDevicesSettingsPage)
    {
        ActionSaveAndRescan->setText(QCoreApplication::translate("ManualDevicesSettingsPage", "Save and Rescan", nullptr));
        ActionSaveNoRescan->setText(QCoreApplication::translate("ManualDevicesSettingsPage", "Save without Rescan", nullptr));
        addDeviceButton->setText(QCoreApplication::translate("ManualDevicesSettingsPage", "Add Device...", nullptr));
        removeDeviceButton->setText(QCoreApplication::translate("ManualDevicesSettingsPage", "Remove", nullptr));
        saveConfigurationButton->setText(QCoreApplication::translate("ManualDevicesSettingsPage", "Save and Rescan", nullptr));
        (void)ManualDevicesSettingsPage;
    } // retranslateUi

};

namespace Ui {
    class ManualDevicesSettingsPage: public Ui_ManualDevicesSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MANUALDEVICESSETTINGSPAGE_H
