/********************************************************************************
** Form generated from reading UI file 'QMKORGBSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QMKORGBSETTINGSENTRY_H
#define UI_QMKORGBSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_QMKORGBSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLineEdit *USBPIDEdit;
    QLineEdit *NameEdit;
    QLabel *NameLabel;
    QLineEdit *USBVIDEdit;
    QLabel *USBPIDLabel;
    QLabel *USBVIDLabel;

    void setupUi(QWidget *QMKORGBSettingsEntry)
    {
        if (QMKORGBSettingsEntry->objectName().isEmpty())
            QMKORGBSettingsEntry->setObjectName(QString::fromUtf8("QMKORGBSettingsEntry"));
        QMKORGBSettingsEntry->resize(531, 237);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(QMKORGBSettingsEntry->sizePolicy().hasHeightForWidth());
        QMKORGBSettingsEntry->setSizePolicy(sizePolicy);
        QMKORGBSettingsEntry->setWindowTitle(QString::fromUtf8(" QMK Settings Entry"));
        gridLayout = new QGridLayout(QMKORGBSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(QMKORGBSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        USBPIDEdit = new QLineEdit(groupBox);
        USBPIDEdit->setObjectName(QString::fromUtf8("USBPIDEdit"));

        gridLayout_2->addWidget(USBPIDEdit, 2, 5, 1, 1);

        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 1, 3, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 1, 0, 1, 1);

        USBVIDEdit = new QLineEdit(groupBox);
        USBVIDEdit->setObjectName(QString::fromUtf8("USBVIDEdit"));

        gridLayout_2->addWidget(USBVIDEdit, 2, 3, 1, 1);

        USBPIDLabel = new QLabel(groupBox);
        USBPIDLabel->setObjectName(QString::fromUtf8("USBPIDLabel"));

        gridLayout_2->addWidget(USBPIDLabel, 2, 4, 1, 1);

        USBVIDLabel = new QLabel(groupBox);
        USBVIDLabel->setObjectName(QString::fromUtf8("USBVIDLabel"));

        gridLayout_2->addWidget(USBVIDLabel, 2, 0, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);

        QWidget::setTabOrder(NameEdit, USBVIDEdit);
        QWidget::setTabOrder(USBVIDEdit, USBPIDEdit);

        retranslateUi(QMKORGBSettingsEntry);

        QMetaObject::connectSlotsByName(QMKORGBSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *QMKORGBSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("QMKORGBSettingsEntry", "QMK Device", nullptr));
        NameLabel->setText(QCoreApplication::translate("QMKORGBSettingsEntry", "Name:", nullptr));
        USBPIDLabel->setText(QCoreApplication::translate("QMKORGBSettingsEntry", "USB PID:", nullptr));
        USBVIDLabel->setText(QCoreApplication::translate("QMKORGBSettingsEntry", "USB VID:", nullptr));
        (void)QMKORGBSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class QMKORGBSettingsEntry: public Ui_QMKORGBSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QMKORGBSETTINGSENTRY_H
