/********************************************************************************
** Form generated from reading UI file 'OpenRGBProfileSaveDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBPROFILESAVEDIALOG_H
#define UI_OPENRGBPROFILESAVEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBProfileSaveDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *existing;
    QListWidget *list_profile;
    QLabel *new_2;
    QLineEdit *lineEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OpenRGBProfileSaveDialog)
    {
        if (OpenRGBProfileSaveDialog->objectName().isEmpty())
            OpenRGBProfileSaveDialog->setObjectName(QString::fromUtf8("OpenRGBProfileSaveDialog"));
        OpenRGBProfileSaveDialog->resize(184, 186);
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OpenRGBProfileSaveDialog->sizePolicy().hasHeightForWidth());
        OpenRGBProfileSaveDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(OpenRGBProfileSaveDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        existing = new QLabel(OpenRGBProfileSaveDialog);
        existing->setObjectName(QString::fromUtf8("existing"));

        verticalLayout->addWidget(existing);

        list_profile = new QListWidget(OpenRGBProfileSaveDialog);
        list_profile->setObjectName(QString::fromUtf8("list_profile"));

        verticalLayout->addWidget(list_profile);

        new_2 = new QLabel(OpenRGBProfileSaveDialog);
        new_2->setObjectName(QString::fromUtf8("new_2"));

        verticalLayout->addWidget(new_2);

        lineEdit = new QLineEdit(OpenRGBProfileSaveDialog);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));

        verticalLayout->addWidget(lineEdit);

        buttonBox = new QDialogButtonBox(OpenRGBProfileSaveDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(OpenRGBProfileSaveDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), OpenRGBProfileSaveDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), OpenRGBProfileSaveDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(OpenRGBProfileSaveDialog);
    } // setupUi

    void retranslateUi(QDialog *OpenRGBProfileSaveDialog)
    {
        OpenRGBProfileSaveDialog->setWindowTitle(QCoreApplication::translate("OpenRGBProfileSaveDialog", "Profile Name", nullptr));
        existing->setText(QCoreApplication::translate("OpenRGBProfileSaveDialog", "Save to an existing profile:", nullptr));
        new_2->setText(QCoreApplication::translate("OpenRGBProfileSaveDialog", "Create a new profile:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenRGBProfileSaveDialog: public Ui_OpenRGBProfileSaveDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBPROFILESAVEDIALOG_H
