/********************************************************************************
** Form generated from reading UI file 'ElgatoLightStripSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ELGATOLIGHTSTRIPSETTINGSENTRY_H
#define UI_ELGATOLIGHTSTRIPSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ElgatoLightStripSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QLineEdit *IPEdit;

    void setupUi(QWidget *ElgatoLightStripSettingsEntry)
    {
        if (ElgatoLightStripSettingsEntry->objectName().isEmpty())
            ElgatoLightStripSettingsEntry->setObjectName(QString::fromUtf8("ElgatoLightStripSettingsEntry"));
        ElgatoLightStripSettingsEntry->resize(225, 108);
        ElgatoLightStripSettingsEntry->setWindowTitle(QString::fromUtf8("Elgato Light Strip Settings Entry"));
        gridLayout = new QGridLayout(ElgatoLightStripSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(ElgatoLightStripSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_2->addWidget(label, 1, 0, 2, 2);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 3, 0, 1, 1);


        gridLayout->addWidget(groupBox, 0, 0, 1, 2);


        retranslateUi(ElgatoLightStripSettingsEntry);

        QMetaObject::connectSlotsByName(ElgatoLightStripSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *ElgatoLightStripSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("ElgatoLightStripSettingsEntry", "Elgato Light Strip", nullptr));
        label->setText(QCoreApplication::translate("ElgatoLightStripSettingsEntry", "IP:", nullptr));
        (void)ElgatoLightStripSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class ElgatoLightStripSettingsEntry: public Ui_ElgatoLightStripSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ELGATOLIGHTSTRIPSETTINGSENTRY_H
