/********************************************************************************
** Form generated from reading UI file 'OpenRGBDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBDIALOG_H
#define UI_OPENRGBDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBDialog
{
public:
    QAction *ActionSaveProfile;
    QAction *ActionSaveProfileAs;
    QWidget *centralWidget;
    QGridLayout *gridLayout;
    QTabWidget *MainTabBar;
    QWidget *TabDevices;
    QGridLayout *gridLayout_3;
    QTabWidget *DevicesTabBar;
    QWidget *TabInformation;
    QGridLayout *gridLayout_2;
    QTabWidget *InformationTabBar;
    QWidget *TabSettings;
    QGridLayout *gridLayout_4;
    QTabWidget *SettingsTabBar;
    QHBoxLayout *MainButtonsLayout;
    QFrame *MainButtonsFrame;
    QGridLayout *gridLayout_5;
    QPushButton *ButtonToggleDeviceView;
    QPushButton *ButtonRescan;
    QToolButton *ButtonSaveProfile;
    QPushButton *ButtonDeleteProfile;
    QPushButton *ButtonLoadProfile;
    QComboBox *ProfileBox;
    QHBoxLayout *DetectorLayout;
    QLabel *DetectionProgressLabel;
    QProgressBar *DetectionProgressBar;
    QPushButton *ButtonStopDetection;

    void setupUi(QMainWindow *OpenRGBDialog)
    {
        if (OpenRGBDialog->objectName().isEmpty())
            OpenRGBDialog->setObjectName(QString::fromUtf8("OpenRGBDialog"));
        OpenRGBDialog->resize(700, 350);
        ActionSaveProfile = new QAction(OpenRGBDialog);
        ActionSaveProfile->setObjectName(QString::fromUtf8("ActionSaveProfile"));
        ActionSaveProfileAs = new QAction(OpenRGBDialog);
        ActionSaveProfileAs->setObjectName(QString::fromUtf8("ActionSaveProfileAs"));
        centralWidget = new QWidget(OpenRGBDialog);
        centralWidget->setObjectName(QString::fromUtf8("centralWidget"));
        gridLayout = new QGridLayout(centralWidget);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        MainTabBar = new QTabWidget(centralWidget);
        MainTabBar->setObjectName(QString::fromUtf8("MainTabBar"));
        MainTabBar->setTabShape(QTabWidget::Rounded);
        MainTabBar->setIconSize(QSize(20, 20));
        TabDevices = new QWidget();
        TabDevices->setObjectName(QString::fromUtf8("TabDevices"));
        gridLayout_3 = new QGridLayout(TabDevices);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        DevicesTabBar = new QTabWidget(TabDevices);
        DevicesTabBar->setObjectName(QString::fromUtf8("DevicesTabBar"));
        DevicesTabBar->setTabPosition(QTabWidget::West);

        gridLayout_3->addWidget(DevicesTabBar, 1, 0, 1, 1);

        MainTabBar->addTab(TabDevices, QString());
        TabInformation = new QWidget();
        TabInformation->setObjectName(QString::fromUtf8("TabInformation"));
        gridLayout_2 = new QGridLayout(TabInformation);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        InformationTabBar = new QTabWidget(TabInformation);
        InformationTabBar->setObjectName(QString::fromUtf8("InformationTabBar"));
        InformationTabBar->setTabPosition(QTabWidget::West);

        gridLayout_2->addWidget(InformationTabBar, 0, 0, 1, 1);

        MainTabBar->addTab(TabInformation, QString());
        TabSettings = new QWidget();
        TabSettings->setObjectName(QString::fromUtf8("TabSettings"));
        gridLayout_4 = new QGridLayout(TabSettings);
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        SettingsTabBar = new QTabWidget(TabSettings);
        SettingsTabBar->setObjectName(QString::fromUtf8("SettingsTabBar"));
        SettingsTabBar->setTabPosition(QTabWidget::West);

        gridLayout_4->addWidget(SettingsTabBar, 0, 0, 1, 1);

        MainTabBar->addTab(TabSettings, QString());

        gridLayout->addWidget(MainTabBar, 2, 0, 1, 5);

        MainButtonsLayout = new QHBoxLayout();
        MainButtonsLayout->setObjectName(QString::fromUtf8("MainButtonsLayout"));
        MainButtonsFrame = new QFrame(centralWidget);
        MainButtonsFrame->setObjectName(QString::fromUtf8("MainButtonsFrame"));
        MainButtonsFrame->setFrameShape(QFrame::NoFrame);
        MainButtonsFrame->setFrameShadow(QFrame::Raised);
        gridLayout_5 = new QGridLayout(MainButtonsFrame);
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        ButtonToggleDeviceView = new QPushButton(MainButtonsFrame);
        ButtonToggleDeviceView->setObjectName(QString::fromUtf8("ButtonToggleDeviceView"));

        gridLayout_5->addWidget(ButtonToggleDeviceView, 0, 0, 1, 1);

        ButtonRescan = new QPushButton(MainButtonsFrame);
        ButtonRescan->setObjectName(QString::fromUtf8("ButtonRescan"));

        gridLayout_5->addWidget(ButtonRescan, 0, 1, 1, 1);

        ButtonSaveProfile = new QToolButton(MainButtonsFrame);
        ButtonSaveProfile->setObjectName(QString::fromUtf8("ButtonSaveProfile"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ButtonSaveProfile->sizePolicy().hasHeightForWidth());
        ButtonSaveProfile->setSizePolicy(sizePolicy);
        ButtonSaveProfile->setPopupMode(QToolButton::MenuButtonPopup);

        gridLayout_5->addWidget(ButtonSaveProfile, 0, 2, 1, 1);

        ButtonDeleteProfile = new QPushButton(MainButtonsFrame);
        ButtonDeleteProfile->setObjectName(QString::fromUtf8("ButtonDeleteProfile"));

        gridLayout_5->addWidget(ButtonDeleteProfile, 0, 3, 1, 1);

        ButtonLoadProfile = new QPushButton(MainButtonsFrame);
        ButtonLoadProfile->setObjectName(QString::fromUtf8("ButtonLoadProfile"));

        gridLayout_5->addWidget(ButtonLoadProfile, 0, 4, 1, 1);

        ProfileBox = new QComboBox(MainButtonsFrame);
        ProfileBox->setObjectName(QString::fromUtf8("ProfileBox"));

        gridLayout_5->addWidget(ProfileBox, 0, 5, 1, 1);


        MainButtonsLayout->addWidget(MainButtonsFrame);


        gridLayout->addLayout(MainButtonsLayout, 6, 0, 1, 5);

        DetectorLayout = new QHBoxLayout();
        DetectorLayout->setObjectName(QString::fromUtf8("DetectorLayout"));
        DetectionProgressLabel = new QLabel(centralWidget);
        DetectionProgressLabel->setObjectName(QString::fromUtf8("DetectionProgressLabel"));
        DetectionProgressLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        DetectorLayout->addWidget(DetectionProgressLabel);

        DetectionProgressBar = new QProgressBar(centralWidget);
        DetectionProgressBar->setObjectName(QString::fromUtf8("DetectionProgressBar"));
        DetectionProgressBar->setValue(24);

        DetectorLayout->addWidget(DetectionProgressBar);

        ButtonStopDetection = new QPushButton(centralWidget);
        ButtonStopDetection->setObjectName(QString::fromUtf8("ButtonStopDetection"));

        DetectorLayout->addWidget(ButtonStopDetection);


        gridLayout->addLayout(DetectorLayout, 4, 0, 1, 5);

        OpenRGBDialog->setCentralWidget(centralWidget);

        retranslateUi(OpenRGBDialog);

        MainTabBar->setCurrentIndex(0);
        InformationTabBar->setCurrentIndex(-1);
        SettingsTabBar->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(OpenRGBDialog);
    } // setupUi

    void retranslateUi(QMainWindow *OpenRGBDialog)
    {
        OpenRGBDialog->setWindowTitle(QCoreApplication::translate("OpenRGBDialog", "OpenRGB", nullptr));
        ActionSaveProfile->setText(QCoreApplication::translate("OpenRGBDialog", "Save Profile", nullptr));
#if QT_CONFIG(tooltip)
        ActionSaveProfile->setToolTip(QCoreApplication::translate("OpenRGBDialog", "Save Profile", nullptr));
#endif // QT_CONFIG(tooltip)
        ActionSaveProfileAs->setText(QCoreApplication::translate("OpenRGBDialog", "Save Profile As...", nullptr));
#if QT_CONFIG(tooltip)
        ActionSaveProfileAs->setToolTip(QCoreApplication::translate("OpenRGBDialog", "Save Profile with custom name", nullptr));
#endif // QT_CONFIG(tooltip)
        MainTabBar->setTabText(MainTabBar->indexOf(TabDevices), QCoreApplication::translate("OpenRGBDialog", "Devices", nullptr));
        MainTabBar->setTabText(MainTabBar->indexOf(TabInformation), QCoreApplication::translate("OpenRGBDialog", "Information", nullptr));
        MainTabBar->setTabText(MainTabBar->indexOf(TabSettings), QCoreApplication::translate("OpenRGBDialog", "Settings", nullptr));
        ButtonToggleDeviceView->setText(QCoreApplication::translate("OpenRGBDialog", "Toggle LED View", nullptr));
        ButtonRescan->setText(QCoreApplication::translate("OpenRGBDialog", "Rescan Devices", nullptr));
        ButtonSaveProfile->setText(QCoreApplication::translate("OpenRGBDialog", "Save Profile", nullptr));
        ButtonDeleteProfile->setText(QCoreApplication::translate("OpenRGBDialog", "Delete Profile", nullptr));
        ButtonLoadProfile->setText(QCoreApplication::translate("OpenRGBDialog", "Load Profile", nullptr));
        DetectionProgressLabel->setText(QCoreApplication::translate("OpenRGBDialog", "OpenRGB is detecting devices...", nullptr));
        ButtonStopDetection->setText(QCoreApplication::translate("OpenRGBDialog", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenRGBDialog: public Ui_OpenRGBDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBDIALOG_H
