/****************************************************************************
** Meta object code from reading C++ file 'ManualDevicesSettingsPage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "qt/ManualDevicesSettingsPage/ManualDevicesSettingsPage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ManualDevicesSettingsPage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ManualDevicesSettingsPage_t {
    QByteArrayData data[15];
    char stringdata0[263];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ManualDevicesSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ManualDevicesSettingsPage_t qt_meta_stringdata_ManualDevicesSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 25), // "ManualDevicesSettingsPage"
QT_MOC_LITERAL(1, 26, 10), // "reloadList"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 10), // "reloadMenu"
QT_MOC_LITERAL(4, 49, 17), // "onTextEditChanged"
QT_MOC_LITERAL(5, 67, 23), // "onAddDeviceItemSelected"
QT_MOC_LITERAL(6, 91, 8), // "QAction*"
QT_MOC_LITERAL(7, 100, 6), // "action"
QT_MOC_LITERAL(8, 107, 11), // "changeEvent"
QT_MOC_LITERAL(9, 119, 7), // "QEvent*"
QT_MOC_LITERAL(10, 127, 5), // "event"
QT_MOC_LITERAL(11, 133, 29), // "on_removeDeviceButton_clicked"
QT_MOC_LITERAL(12, 163, 34), // "on_deviceList_itemSelectionCh..."
QT_MOC_LITERAL(13, 198, 31), // "on_ActionSaveNoRescan_triggered"
QT_MOC_LITERAL(14, 230, 32) // "on_ActionSaveAndRescan_triggered"

    },
    "ManualDevicesSettingsPage\0reloadList\0"
    "\0reloadMenu\0onTextEditChanged\0"
    "onAddDeviceItemSelected\0QAction*\0"
    "action\0changeEvent\0QEvent*\0event\0"
    "on_removeDeviceButton_clicked\0"
    "on_deviceList_itemSelectionChanged\0"
    "on_ActionSaveNoRescan_triggered\0"
    "on_ActionSaveAndRescan_triggered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ManualDevicesSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x0a /* Public */,
       3,    0,   60,    2, 0x0a /* Public */,
       4,    0,   61,    2, 0x08 /* Private */,
       5,    1,   62,    2, 0x08 /* Private */,
       8,    1,   65,    2, 0x08 /* Private */,
      11,    0,   68,    2, 0x08 /* Private */,
      12,    0,   69,    2, 0x08 /* Private */,
      13,    0,   70,    2, 0x08 /* Private */,
      14,    0,   71,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ManualDevicesSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ManualDevicesSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->reloadList(); break;
        case 1: _t->reloadMenu(); break;
        case 2: _t->onTextEditChanged(); break;
        case 3: _t->onAddDeviceItemSelected((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 4: _t->changeEvent((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 5: _t->on_removeDeviceButton_clicked(); break;
        case 6: _t->on_deviceList_itemSelectionChanged(); break;
        case 7: _t->on_ActionSaveNoRescan_triggered(); break;
        case 8: _t->on_ActionSaveAndRescan_triggered(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ManualDevicesSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_ManualDevicesSettingsPage.data,
    qt_meta_data_ManualDevicesSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ManualDevicesSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ManualDevicesSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ManualDevicesSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ManualDevicesSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
