/********************************************************************************
** Form generated from reading UI file 'NanoleafNewDeviceDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NANOLEAFNEWDEVICEDIALOG_H
#define UI_NANOLEAFNEWDEVICEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_NanoleafNewDeviceDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *deviceIPLabel;
    QLineEdit *deviceIPEdit;
    QLabel *devicePortLabel;
    QLineEdit *devicePortEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NanoleafNewDeviceDialog)
    {
        if (NanoleafNewDeviceDialog->objectName().isEmpty())
            NanoleafNewDeviceDialog->setObjectName(QString::fromUtf8("NanoleafNewDeviceDialog"));
        NanoleafNewDeviceDialog->resize(184, 186);
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(NanoleafNewDeviceDialog->sizePolicy().hasHeightForWidth());
        NanoleafNewDeviceDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(NanoleafNewDeviceDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        deviceIPLabel = new QLabel(NanoleafNewDeviceDialog);
        deviceIPLabel->setObjectName(QString::fromUtf8("deviceIPLabel"));

        verticalLayout->addWidget(deviceIPLabel);

        deviceIPEdit = new QLineEdit(NanoleafNewDeviceDialog);
        deviceIPEdit->setObjectName(QString::fromUtf8("deviceIPEdit"));

        verticalLayout->addWidget(deviceIPEdit);

        devicePortLabel = new QLabel(NanoleafNewDeviceDialog);
        devicePortLabel->setObjectName(QString::fromUtf8("devicePortLabel"));

        verticalLayout->addWidget(devicePortLabel);

        devicePortEdit = new QLineEdit(NanoleafNewDeviceDialog);
        devicePortEdit->setObjectName(QString::fromUtf8("devicePortEdit"));

        verticalLayout->addWidget(devicePortEdit);

        buttonBox = new QDialogButtonBox(NanoleafNewDeviceDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(NanoleafNewDeviceDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), NanoleafNewDeviceDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), NanoleafNewDeviceDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(NanoleafNewDeviceDialog);
    } // setupUi

    void retranslateUi(QDialog *NanoleafNewDeviceDialog)
    {
        NanoleafNewDeviceDialog->setWindowTitle(QCoreApplication::translate("NanoleafNewDeviceDialog", "New Nanoleaf device", nullptr));
        deviceIPLabel->setText(QCoreApplication::translate("NanoleafNewDeviceDialog", "IP address:", nullptr));
        devicePortLabel->setText(QCoreApplication::translate("NanoleafNewDeviceDialog", "Port:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NanoleafNewDeviceDialog: public Ui_NanoleafNewDeviceDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NANOLEAFNEWDEVICEDIALOG_H
