/********************************************************************************
** Form generated from reading UI file 'OpenRGBSystemInfoPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBSYSTEMINFOPAGE_H
#define UI_OPENRGBSYSTEMINFOPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBSystemInfoPage
{
public:
    QGridLayout *gridLayout;
    QLabel *SMBusAdaptersLabel;
    QLabel *DumpAddressLabel;
    QPushButton *ReadButton;
    QPlainTextEdit *SMBusDataText;
    QLabel *SMBusDumpLabel;
    QSpinBox *DumpAddressBox;
    QLabel *SMBusDetectorLabel;
    QComboBox *SMBusAdaptersBox;
    QLabel *SMBusDetectModeLabel;
    QComboBox *SMBusDetectionModeBox;
    QPushButton *DetectButton;
    QPushButton *DumpButton;
    QLabel *SMBusReaderLabel;
    QHBoxLayout *horizontalLayout;
    QLabel *ReadAddressLabel;
    QSpinBox *ReadAddressBox;
    QLabel *ReadRegisterLabel;
    QSpinBox *ReadRegisterBox;
    QLabel *ReadSizeLabel;
    QSpinBox *ReadSizeBox;

    void setupUi(QFrame *OpenRGBSystemInfoPage)
    {
        if (OpenRGBSystemInfoPage->objectName().isEmpty())
            OpenRGBSystemInfoPage->setObjectName(QString::fromUtf8("OpenRGBSystemInfoPage"));
        OpenRGBSystemInfoPage->resize(500, 320);
        OpenRGBSystemInfoPage->setWindowTitle(QString::fromUtf8("System Info Page"));
        gridLayout = new QGridLayout(OpenRGBSystemInfoPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        SMBusAdaptersLabel = new QLabel(OpenRGBSystemInfoPage);
        SMBusAdaptersLabel->setObjectName(QString::fromUtf8("SMBusAdaptersLabel"));

        gridLayout->addWidget(SMBusAdaptersLabel, 0, 0, 1, 1);

        DumpAddressLabel = new QLabel(OpenRGBSystemInfoPage);
        DumpAddressLabel->setObjectName(QString::fromUtf8("DumpAddressLabel"));

        gridLayout->addWidget(DumpAddressLabel, 2, 1, 1, 1);

        ReadButton = new QPushButton(OpenRGBSystemInfoPage);
        ReadButton->setObjectName(QString::fromUtf8("ReadButton"));

        gridLayout->addWidget(ReadButton, 3, 3, 1, 1);

        SMBusDataText = new QPlainTextEdit(OpenRGBSystemInfoPage);
        SMBusDataText->setObjectName(QString::fromUtf8("SMBusDataText"));

        gridLayout->addWidget(SMBusDataText, 4, 0, 1, 4);

        SMBusDumpLabel = new QLabel(OpenRGBSystemInfoPage);
        SMBusDumpLabel->setObjectName(QString::fromUtf8("SMBusDumpLabel"));

        gridLayout->addWidget(SMBusDumpLabel, 2, 0, 1, 1);

        DumpAddressBox = new QSpinBox(OpenRGBSystemInfoPage);
        DumpAddressBox->setObjectName(QString::fromUtf8("DumpAddressBox"));
        DumpAddressBox->setMaximum(255);
        DumpAddressBox->setDisplayIntegerBase(16);

        gridLayout->addWidget(DumpAddressBox, 2, 2, 1, 1);

        SMBusDetectorLabel = new QLabel(OpenRGBSystemInfoPage);
        SMBusDetectorLabel->setObjectName(QString::fromUtf8("SMBusDetectorLabel"));

        gridLayout->addWidget(SMBusDetectorLabel, 1, 0, 1, 1);

        SMBusAdaptersBox = new QComboBox(OpenRGBSystemInfoPage);
        SMBusAdaptersBox->setObjectName(QString::fromUtf8("SMBusAdaptersBox"));

        gridLayout->addWidget(SMBusAdaptersBox, 0, 1, 1, 3);

        SMBusDetectModeLabel = new QLabel(OpenRGBSystemInfoPage);
        SMBusDetectModeLabel->setObjectName(QString::fromUtf8("SMBusDetectModeLabel"));

        gridLayout->addWidget(SMBusDetectModeLabel, 1, 1, 1, 1);

        SMBusDetectionModeBox = new QComboBox(OpenRGBSystemInfoPage);
        SMBusDetectionModeBox->setObjectName(QString::fromUtf8("SMBusDetectionModeBox"));

        gridLayout->addWidget(SMBusDetectionModeBox, 1, 2, 1, 1);

        DetectButton = new QPushButton(OpenRGBSystemInfoPage);
        DetectButton->setObjectName(QString::fromUtf8("DetectButton"));

        gridLayout->addWidget(DetectButton, 1, 3, 1, 1);

        DumpButton = new QPushButton(OpenRGBSystemInfoPage);
        DumpButton->setObjectName(QString::fromUtf8("DumpButton"));

        gridLayout->addWidget(DumpButton, 2, 3, 1, 1);

        SMBusReaderLabel = new QLabel(OpenRGBSystemInfoPage);
        SMBusReaderLabel->setObjectName(QString::fromUtf8("SMBusReaderLabel"));

        gridLayout->addWidget(SMBusReaderLabel, 3, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        ReadAddressLabel = new QLabel(OpenRGBSystemInfoPage);
        ReadAddressLabel->setObjectName(QString::fromUtf8("ReadAddressLabel"));

        horizontalLayout->addWidget(ReadAddressLabel);

        ReadAddressBox = new QSpinBox(OpenRGBSystemInfoPage);
        ReadAddressBox->setObjectName(QString::fromUtf8("ReadAddressBox"));
        ReadAddressBox->setMaximum(255);
        ReadAddressBox->setDisplayIntegerBase(16);

        horizontalLayout->addWidget(ReadAddressBox);

        ReadRegisterLabel = new QLabel(OpenRGBSystemInfoPage);
        ReadRegisterLabel->setObjectName(QString::fromUtf8("ReadRegisterLabel"));

        horizontalLayout->addWidget(ReadRegisterLabel);

        ReadRegisterBox = new QSpinBox(OpenRGBSystemInfoPage);
        ReadRegisterBox->setObjectName(QString::fromUtf8("ReadRegisterBox"));
        ReadRegisterBox->setMaximum(255);
        ReadRegisterBox->setDisplayIntegerBase(16);

        horizontalLayout->addWidget(ReadRegisterBox);

        ReadSizeLabel = new QLabel(OpenRGBSystemInfoPage);
        ReadSizeLabel->setObjectName(QString::fromUtf8("ReadSizeLabel"));

        horizontalLayout->addWidget(ReadSizeLabel);

        ReadSizeBox = new QSpinBox(OpenRGBSystemInfoPage);
        ReadSizeBox->setObjectName(QString::fromUtf8("ReadSizeBox"));

        horizontalLayout->addWidget(ReadSizeBox);


        gridLayout->addLayout(horizontalLayout, 3, 1, 1, 2);

        QWidget::setTabOrder(SMBusAdaptersBox, SMBusDetectionModeBox);
        QWidget::setTabOrder(SMBusDetectionModeBox, DetectButton);
        QWidget::setTabOrder(DetectButton, DumpAddressBox);
        QWidget::setTabOrder(DumpAddressBox, DumpButton);
        QWidget::setTabOrder(DumpButton, SMBusDataText);

        retranslateUi(OpenRGBSystemInfoPage);

        QMetaObject::connectSlotsByName(OpenRGBSystemInfoPage);
    } // setupUi

    void retranslateUi(QFrame *OpenRGBSystemInfoPage)
    {
        SMBusAdaptersLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "SMBus Adapters:", nullptr));
        DumpAddressLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Address:", nullptr));
        ReadButton->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Read Device", nullptr));
        SMBusDumpLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "SMBus Dumper:", nullptr));
        DumpAddressBox->setSuffix(QString());
        DumpAddressBox->setPrefix(QCoreApplication::translate("OpenRGBSystemInfoPage", "0x", nullptr));
        SMBusDetectorLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "SMBus Detector:", nullptr));
        SMBusDetectModeLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Detection Mode:", nullptr));
        DetectButton->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Detect Devices", nullptr));
        DumpButton->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Dump Device", nullptr));
        SMBusReaderLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "SMBus Reader:", nullptr));
        ReadAddressLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Addr:", nullptr));
        ReadAddressBox->setPrefix(QCoreApplication::translate("OpenRGBSystemInfoPage", "0x", nullptr));
        ReadRegisterLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Reg:", nullptr));
        ReadRegisterBox->setPrefix(QCoreApplication::translate("OpenRGBSystemInfoPage", "0x", nullptr));
        ReadSizeLabel->setText(QCoreApplication::translate("OpenRGBSystemInfoPage", "Size:", nullptr));
        (void)OpenRGBSystemInfoPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBSystemInfoPage: public Ui_OpenRGBSystemInfoPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBSYSTEMINFOPAGE_H
