/********************************************************************************
** Form generated from reading UI file 'OpenRGBSettingsPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBSETTINGSPAGE_H
#define UI_OPENRGBSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBSettingsPage
{
public:
    QGridLayout *gridLayout;
    QPushButton *OpenSettingsFolderButton;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents_2;
    QGridLayout *gridLayout_3;
    QCheckBox *CheckboxAutoStartMinimized;
    QCheckBox *CheckboxLogConsole;
    QCheckBox *CheckboxAMDSMBusReduceCPU;
    QComboBox *ComboBoxAutoStartProfile;
    QCheckBox *CheckboxAutoStartClient;
    QCheckBox *CheckboxDisableKeyExpansion;
    QLineEdit *TextCustomArgs;
    QLabel *HexFormatLabel;
    QComboBox *ComboBoxExitProfile;
    QLabel *UserInterfaceSettingsLabel;
    QCheckBox *CheckboxRunZoneChecks;
    QComboBox *ComboBoxResumeProfile;
    QLabel *ThemeLabel;
    QLabel *DriversSettingsLabel;
    QComboBox *ComboBoxHexFormat;
    QLabel *LabelLanguage;
    QSpacerItem *verticalSpacer;
    QCheckBox *CheckboxAutoStartServer;
    QCheckBox *CheckboxAutoStartProfile;
    QCheckBox *CheckboxAutoStart;
    QCheckBox *CheckboxSaveGeometry;
    QCheckBox *CheckboxLogFile;
    QCheckBox *CheckboxTrayIconGreyscale;
    QLineEdit *TextServerHost;
    QComboBox *ComboBoxSuspendProfile;
    QCheckBox *CheckboxAutoStartSetServerPort;
    QCheckBox *CheckboxShowLEDView;
    QCheckBox *CheckboxMinimizeOnClose;
    QCheckBox *CheckboxSetOnExit;
    QCheckBox *CheckboxLoadGeometry;
    QSpinBox *TextServerPort;
    QLabel *LogManagerSettingsLabel;
    QComboBox *ComboBoxLanguage;
    QCheckBox *CheckboxSetOnSuspend;
    QCheckBox *CheckboxAutoStartCustom;
    QCheckBox *CheckboxAllDevices;
    QLineEdit *TextClientHost;
    QCheckBox *CheckboxAutoStartSetServerHost;
    QLabel *AutoStartStatusLabel;
    QCheckBox *CheckboxSharedSMBusAccess;
    QLabel *AutoStartLabel;
    QComboBox *ComboBoxTheme;
    QCheckBox *CheckboxSetOnResume;
    QLabel *ServerSettingsLabel;
    QCheckBox *CheckboxLegacyWorkaround;

    void setupUi(QWidget *OpenRGBSettingsPage)
    {
        if (OpenRGBSettingsPage->objectName().isEmpty())
            OpenRGBSettingsPage->setObjectName(QString::fromUtf8("OpenRGBSettingsPage"));
        OpenRGBSettingsPage->resize(475, 500);
        OpenRGBSettingsPage->setWindowTitle(QString::fromUtf8("Settings Page"));
        gridLayout = new QGridLayout(OpenRGBSettingsPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        OpenSettingsFolderButton = new QPushButton(OpenRGBSettingsPage);
        OpenSettingsFolderButton->setObjectName(QString::fromUtf8("OpenSettingsFolderButton"));

        gridLayout->addWidget(OpenSettingsFolderButton, 1, 1, 1, 6);

        scrollArea = new QScrollArea(OpenRGBSettingsPage);
        scrollArea->setObjectName(QString::fromUtf8("scrollArea"));
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName(QString::fromUtf8("scrollAreaWidgetContents_2"));
        scrollAreaWidgetContents_2->setGeometry(QRect(0, -321, 554, 1052));
        gridLayout_3 = new QGridLayout(scrollAreaWidgetContents_2);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        CheckboxAutoStartMinimized = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStartMinimized->setObjectName(QString::fromUtf8("CheckboxAutoStartMinimized"));

        gridLayout_3->addWidget(CheckboxAutoStartMinimized, 27, 0, 1, 1);

        CheckboxLogConsole = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxLogConsole->setObjectName(QString::fromUtf8("CheckboxLogConsole"));

        gridLayout_3->addWidget(CheckboxLogConsole, 15, 0, 1, 1);

        CheckboxAMDSMBusReduceCPU = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAMDSMBusReduceCPU->setObjectName(QString::fromUtf8("CheckboxAMDSMBusReduceCPU"));

        gridLayout_3->addWidget(CheckboxAMDSMBusReduceCPU, 17, 0, 1, 1);

        ComboBoxAutoStartProfile = new QComboBox(scrollAreaWidgetContents_2);
        ComboBoxAutoStartProfile->setObjectName(QString::fromUtf8("ComboBoxAutoStartProfile"));

        gridLayout_3->addWidget(ComboBoxAutoStartProfile, 33, 1, 1, 1);

        CheckboxAutoStartClient = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStartClient->setObjectName(QString::fromUtf8("CheckboxAutoStartClient"));

        gridLayout_3->addWidget(CheckboxAutoStartClient, 31, 0, 1, 1);

        CheckboxDisableKeyExpansion = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxDisableKeyExpansion->setObjectName(QString::fromUtf8("CheckboxDisableKeyExpansion"));

        gridLayout_3->addWidget(CheckboxDisableKeyExpansion, 10, 0, 1, 1);

        TextCustomArgs = new QLineEdit(scrollAreaWidgetContents_2);
        TextCustomArgs->setObjectName(QString::fromUtf8("TextCustomArgs"));

        gridLayout_3->addWidget(TextCustomArgs, 32, 1, 1, 1);

        HexFormatLabel = new QLabel(scrollAreaWidgetContents_2);
        HexFormatLabel->setObjectName(QString::fromUtf8("HexFormatLabel"));

        gridLayout_3->addWidget(HexFormatLabel, 12, 0, 1, 1);

        ComboBoxExitProfile = new QComboBox(scrollAreaWidgetContents_2);
        ComboBoxExitProfile->setObjectName(QString::fromUtf8("ComboBoxExitProfile"));

        gridLayout_3->addWidget(ComboBoxExitProfile, 36, 1, 1, 1);

        UserInterfaceSettingsLabel = new QLabel(scrollAreaWidgetContents_2);
        UserInterfaceSettingsLabel->setObjectName(QString::fromUtf8("UserInterfaceSettingsLabel"));

        gridLayout_3->addWidget(UserInterfaceSettingsLabel, 2, 0, 1, 1);

        CheckboxRunZoneChecks = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxRunZoneChecks->setObjectName(QString::fromUtf8("CheckboxRunZoneChecks"));

        gridLayout_3->addWidget(CheckboxRunZoneChecks, 9, 0, 1, 1);

        ComboBoxResumeProfile = new QComboBox(scrollAreaWidgetContents_2);
        ComboBoxResumeProfile->setObjectName(QString::fromUtf8("ComboBoxResumeProfile"));

        gridLayout_3->addWidget(ComboBoxResumeProfile, 35, 1, 1, 1);

        ThemeLabel = new QLabel(scrollAreaWidgetContents_2);
        ThemeLabel->setObjectName(QString::fromUtf8("ThemeLabel"));

        gridLayout_3->addWidget(ThemeLabel, 4, 0, 1, 1);

        DriversSettingsLabel = new QLabel(scrollAreaWidgetContents_2);
        DriversSettingsLabel->setObjectName(QString::fromUtf8("DriversSettingsLabel"));

        gridLayout_3->addWidget(DriversSettingsLabel, 16, 0, 1, 1);

        ComboBoxHexFormat = new QComboBox(scrollAreaWidgetContents_2);
        ComboBoxHexFormat->setObjectName(QString::fromUtf8("ComboBoxHexFormat"));

        gridLayout_3->addWidget(ComboBoxHexFormat, 12, 1, 1, 1);

        LabelLanguage = new QLabel(scrollAreaWidgetContents_2);
        LabelLanguage->setObjectName(QString::fromUtf8("LabelLanguage"));

        gridLayout_3->addWidget(LabelLanguage, 3, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout_3->addItem(verticalSpacer, 38, 0, 1, 1);

        CheckboxAutoStartServer = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStartServer->setObjectName(QString::fromUtf8("CheckboxAutoStartServer"));

        gridLayout_3->addWidget(CheckboxAutoStartServer, 28, 0, 1, 1);

        CheckboxAutoStartProfile = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStartProfile->setObjectName(QString::fromUtf8("CheckboxAutoStartProfile"));

        gridLayout_3->addWidget(CheckboxAutoStartProfile, 33, 0, 1, 1);

        CheckboxAutoStart = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStart->setObjectName(QString::fromUtf8("CheckboxAutoStart"));

        gridLayout_3->addWidget(CheckboxAutoStart, 23, 0, 1, 1);

        CheckboxSaveGeometry = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxSaveGeometry->setObjectName(QString::fromUtf8("CheckboxSaveGeometry"));

        gridLayout_3->addWidget(CheckboxSaveGeometry, 8, 0, 1, 1);

        CheckboxLogFile = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxLogFile->setObjectName(QString::fromUtf8("CheckboxLogFile"));

        gridLayout_3->addWidget(CheckboxLogFile, 14, 0, 1, 1);

        CheckboxTrayIconGreyscale = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxTrayIconGreyscale->setObjectName(QString::fromUtf8("CheckboxTrayIconGreyscale"));

        gridLayout_3->addWidget(CheckboxTrayIconGreyscale, 6, 0, 1, 1);

        TextServerHost = new QLineEdit(scrollAreaWidgetContents_2);
        TextServerHost->setObjectName(QString::fromUtf8("TextServerHost"));

        gridLayout_3->addWidget(TextServerHost, 29, 1, 1, 1);

        ComboBoxSuspendProfile = new QComboBox(scrollAreaWidgetContents_2);
        ComboBoxSuspendProfile->setObjectName(QString::fromUtf8("ComboBoxSuspendProfile"));

        gridLayout_3->addWidget(ComboBoxSuspendProfile, 34, 1, 1, 1);

        CheckboxAutoStartSetServerPort = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStartSetServerPort->setObjectName(QString::fromUtf8("CheckboxAutoStartSetServerPort"));

        gridLayout_3->addWidget(CheckboxAutoStartSetServerPort, 30, 0, 1, 1);

        CheckboxShowLEDView = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxShowLEDView->setObjectName(QString::fromUtf8("CheckboxShowLEDView"));

        gridLayout_3->addWidget(CheckboxShowLEDView, 11, 0, 1, 1);

        CheckboxMinimizeOnClose = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxMinimizeOnClose->setObjectName(QString::fromUtf8("CheckboxMinimizeOnClose"));

        gridLayout_3->addWidget(CheckboxMinimizeOnClose, 5, 0, 1, 1);

        CheckboxSetOnExit = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxSetOnExit->setObjectName(QString::fromUtf8("CheckboxSetOnExit"));

        gridLayout_3->addWidget(CheckboxSetOnExit, 36, 0, 1, 1);

        CheckboxLoadGeometry = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxLoadGeometry->setObjectName(QString::fromUtf8("CheckboxLoadGeometry"));

        gridLayout_3->addWidget(CheckboxLoadGeometry, 7, 0, 1, 1);

        TextServerPort = new QSpinBox(scrollAreaWidgetContents_2);
        TextServerPort->setObjectName(QString::fromUtf8("TextServerPort"));
        TextServerPort->setMinimum(1);
        TextServerPort->setMaximum(65535);
        TextServerPort->setValue(6742);

        gridLayout_3->addWidget(TextServerPort, 30, 1, 1, 1);

        LogManagerSettingsLabel = new QLabel(scrollAreaWidgetContents_2);
        LogManagerSettingsLabel->setObjectName(QString::fromUtf8("LogManagerSettingsLabel"));

        gridLayout_3->addWidget(LogManagerSettingsLabel, 13, 0, 1, 1);

        ComboBoxLanguage = new QComboBox(scrollAreaWidgetContents_2);
        ComboBoxLanguage->setObjectName(QString::fromUtf8("ComboBoxLanguage"));

        gridLayout_3->addWidget(ComboBoxLanguage, 3, 1, 1, 1);

        CheckboxSetOnSuspend = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxSetOnSuspend->setObjectName(QString::fromUtf8("CheckboxSetOnSuspend"));

        gridLayout_3->addWidget(CheckboxSetOnSuspend, 34, 0, 1, 1);

        CheckboxAutoStartCustom = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStartCustom->setObjectName(QString::fromUtf8("CheckboxAutoStartCustom"));

        gridLayout_3->addWidget(CheckboxAutoStartCustom, 32, 0, 1, 1);

        CheckboxAllDevices = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAllDevices->setObjectName(QString::fromUtf8("CheckboxAllDevices"));

        gridLayout_3->addWidget(CheckboxAllDevices, 20, 0, 1, 1);

        TextClientHost = new QLineEdit(scrollAreaWidgetContents_2);
        TextClientHost->setObjectName(QString::fromUtf8("TextClientHost"));

        gridLayout_3->addWidget(TextClientHost, 31, 1, 1, 1);

        CheckboxAutoStartSetServerHost = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxAutoStartSetServerHost->setObjectName(QString::fromUtf8("CheckboxAutoStartSetServerHost"));

        gridLayout_3->addWidget(CheckboxAutoStartSetServerHost, 29, 0, 1, 1);

        AutoStartStatusLabel = new QLabel(scrollAreaWidgetContents_2);
        AutoStartStatusLabel->setObjectName(QString::fromUtf8("AutoStartStatusLabel"));

        gridLayout_3->addWidget(AutoStartStatusLabel, 37, 0, 1, 1);

        CheckboxSharedSMBusAccess = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxSharedSMBusAccess->setObjectName(QString::fromUtf8("CheckboxSharedSMBusAccess"));

        gridLayout_3->addWidget(CheckboxSharedSMBusAccess, 18, 0, 1, 1);

        AutoStartLabel = new QLabel(scrollAreaWidgetContents_2);
        AutoStartLabel->setObjectName(QString::fromUtf8("AutoStartLabel"));

        gridLayout_3->addWidget(AutoStartLabel, 22, 0, 1, 1);

        ComboBoxTheme = new QComboBox(scrollAreaWidgetContents_2);
        ComboBoxTheme->setObjectName(QString::fromUtf8("ComboBoxTheme"));

        gridLayout_3->addWidget(ComboBoxTheme, 4, 1, 1, 1);

        CheckboxSetOnResume = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxSetOnResume->setObjectName(QString::fromUtf8("CheckboxSetOnResume"));

        gridLayout_3->addWidget(CheckboxSetOnResume, 35, 0, 1, 1);

        ServerSettingsLabel = new QLabel(scrollAreaWidgetContents_2);
        ServerSettingsLabel->setObjectName(QString::fromUtf8("ServerSettingsLabel"));

        gridLayout_3->addWidget(ServerSettingsLabel, 19, 0, 1, 1);

        CheckboxLegacyWorkaround = new QCheckBox(scrollAreaWidgetContents_2);
        CheckboxLegacyWorkaround->setObjectName(QString::fromUtf8("CheckboxLegacyWorkaround"));

        gridLayout_3->addWidget(CheckboxLegacyWorkaround, 21, 0, 1, 1);

        scrollArea->setWidget(scrollAreaWidgetContents_2);

        gridLayout->addWidget(scrollArea, 0, 1, 1, 6);


        retranslateUi(OpenRGBSettingsPage);

        QMetaObject::connectSlotsByName(OpenRGBSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *OpenRGBSettingsPage)
    {
        OpenSettingsFolderButton->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Open Settings Folder", nullptr));
        CheckboxAutoStartMinimized->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Start Minimized", nullptr));
        CheckboxLogConsole->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Enable Log Console (restart required)", nullptr));
        CheckboxAMDSMBusReduceCPU->setText(QCoreApplication::translate("OpenRGBSettingsPage", "AMD SMBus: Reduce CPU Usage (restart required)", nullptr));
        CheckboxAutoStartClient->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Start Client", nullptr));
        CheckboxDisableKeyExpansion->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Disable Key Expansion in Device View", nullptr));
        HexFormatLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Hex Format", nullptr));
        UserInterfaceSettingsLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "User Interface Settings:", nullptr));
        CheckboxRunZoneChecks->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Run Zone Checks on Rescan", nullptr));
        ThemeLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Theme (restart required)", nullptr));
        DriversSettingsLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Drivers Settings:", nullptr));
        LabelLanguage->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Language", nullptr));
        CheckboxAutoStartServer->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Start Server", nullptr));
        CheckboxAutoStartProfile->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Load Profile", nullptr));
        CheckboxAutoStart->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Start at Login", nullptr));
        CheckboxSaveGeometry->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Save Geometry on Close", nullptr));
        CheckboxLogFile->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Enable Log File (restart required)", nullptr));
        CheckboxTrayIconGreyscale->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Greyscale Tray Icon", nullptr));
        CheckboxAutoStartSetServerPort->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Set Server Port", nullptr));
        CheckboxShowLEDView->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Show LED View by Default", nullptr));
        CheckboxMinimizeOnClose->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Minimize on Close", nullptr));
        CheckboxSetOnExit->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Set Profile on Exit", nullptr));
        CheckboxLoadGeometry->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Load Window Geometry", nullptr));
        LogManagerSettingsLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Log Manager Settings:", nullptr));
        CheckboxSetOnSuspend->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Set Profile on Suspend", nullptr));
        CheckboxAutoStartCustom->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Custom Arguments", nullptr));
        CheckboxAllDevices->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Serve All Devices (Including those from client connections)", nullptr));
        CheckboxAutoStartSetServerHost->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Set Server Host", nullptr));
        AutoStartStatusLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Start at Login Status", nullptr));
        CheckboxSharedSMBusAccess->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Shared SMBus Access (restart required)", nullptr));
        AutoStartLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Start at Login Settings:", nullptr));
        CheckboxSetOnResume->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Set Profile on Resume", nullptr));
        ServerSettingsLabel->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Server Settings:", nullptr));
        CheckboxLegacyWorkaround->setText(QCoreApplication::translate("OpenRGBSettingsPage", "Legacy Workaround", nullptr));
        (void)OpenRGBSettingsPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBSettingsPage: public Ui_OpenRGBSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBSETTINGSPAGE_H
