/********************************************************************************
** Form generated from reading UI file 'LIFXSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIFXSETTINGSENTRY_H
#define UI_LIFXSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_LIFXSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLineEdit *IPEdit;
    QCheckBox *MultizoneCheckBox;
    QLabel *IPLabel;
    QLabel *NameLabel;
    QLineEdit *NameEdit;
    QCheckBox *ExtendedMultizoneCheckBox;

    void setupUi(QWidget *LIFXSettingsEntry)
    {
        if (LIFXSettingsEntry->objectName().isEmpty())
            LIFXSettingsEntry->setObjectName(QString::fromUtf8("LIFXSettingsEntry"));
        LIFXSettingsEntry->resize(605, 89);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(LIFXSettingsEntry->sizePolicy().hasHeightForWidth());
        LIFXSettingsEntry->setSizePolicy(sizePolicy);
        LIFXSettingsEntry->setWindowTitle(QString::fromUtf8("LIFX Settings Entry"));
        gridLayout = new QGridLayout(LIFXSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(LIFXSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 1, 3, 1, 1);

        MultizoneCheckBox = new QCheckBox(groupBox);
        MultizoneCheckBox->setObjectName(QString::fromUtf8("MultizoneCheckBox"));

        gridLayout_2->addWidget(MultizoneCheckBox, 1, 6, 1, 1);

        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 1, 0, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 1, 4, 1, 1);

        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 1, 5, 1, 1);

        ExtendedMultizoneCheckBox = new QCheckBox(groupBox);
        ExtendedMultizoneCheckBox->setObjectName(QString::fromUtf8("ExtendedMultizoneCheckBox"));
        ExtendedMultizoneCheckBox->setEnabled(false);

        gridLayout_2->addWidget(ExtendedMultizoneCheckBox, 1, 7, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(LIFXSettingsEntry);

        QMetaObject::connectSlotsByName(LIFXSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *LIFXSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("LIFXSettingsEntry", "LIFX Device", nullptr));
        MultizoneCheckBox->setText(QCoreApplication::translate("LIFXSettingsEntry", "Multizone", nullptr));
        IPLabel->setText(QCoreApplication::translate("LIFXSettingsEntry", "IP:", nullptr));
        NameLabel->setText(QCoreApplication::translate("LIFXSettingsEntry", "Name", nullptr));
        ExtendedMultizoneCheckBox->setText(QCoreApplication::translate("LIFXSettingsEntry", "Extended Multizone", nullptr));
        (void)LIFXSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class LIFXSettingsEntry: public Ui_LIFXSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LIFXSETTINGSENTRY_H
