/********************************************************************************
** Form generated from reading UI file 'DebugSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEBUGSETTINGSENTRY_H
#define UI_DEBUGSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DebugSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *TypeLabel;
    QLineEdit *NameEdit;
    QComboBox *TypeComboBox;
    QGroupBox *groupBox_Zones;
    QGridLayout *gridLayout_3;
    QCheckBox *KeyboardCheckBox;
    QCheckBox *LinearCheckBox;
    QCheckBox *SingleCheckBox;
    QCheckBox *ResizableCheckBox;
    QCheckBox *UnderglowCheckBox;
    QLabel *NameLabel;
    QLabel *LayoutLabel;
    QComboBox *LayoutComboBox;

    void setupUi(QWidget *DebugSettingsEntry)
    {
        if (DebugSettingsEntry->objectName().isEmpty())
            DebugSettingsEntry->setObjectName(QString::fromUtf8("DebugSettingsEntry"));
        DebugSettingsEntry->resize(400, 293);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DebugSettingsEntry->sizePolicy().hasHeightForWidth());
        DebugSettingsEntry->setSizePolicy(sizePolicy);
        DebugSettingsEntry->setWindowTitle(QString::fromUtf8("Debug Settings Entry"));
        gridLayout = new QGridLayout(DebugSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(DebugSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        TypeLabel = new QLabel(groupBox);
        TypeLabel->setObjectName(QString::fromUtf8("TypeLabel"));

        gridLayout_2->addWidget(TypeLabel, 1, 0, 1, 1);

        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 0, 1, 1, 1);

        TypeComboBox = new QComboBox(groupBox);
        TypeComboBox->setObjectName(QString::fromUtf8("TypeComboBox"));

        gridLayout_2->addWidget(TypeComboBox, 1, 1, 1, 1);

        groupBox_Zones = new QGroupBox(groupBox);
        groupBox_Zones->setObjectName(QString::fromUtf8("groupBox_Zones"));
        gridLayout_3 = new QGridLayout(groupBox_Zones);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        KeyboardCheckBox = new QCheckBox(groupBox_Zones);
        KeyboardCheckBox->setObjectName(QString::fromUtf8("KeyboardCheckBox"));

        gridLayout_3->addWidget(KeyboardCheckBox, 1, 1, 1, 1);

        LinearCheckBox = new QCheckBox(groupBox_Zones);
        LinearCheckBox->setObjectName(QString::fromUtf8("LinearCheckBox"));

        gridLayout_3->addWidget(LinearCheckBox, 0, 1, 1, 1);

        SingleCheckBox = new QCheckBox(groupBox_Zones);
        SingleCheckBox->setObjectName(QString::fromUtf8("SingleCheckBox"));

        gridLayout_3->addWidget(SingleCheckBox, 0, 0, 1, 1);

        ResizableCheckBox = new QCheckBox(groupBox_Zones);
        ResizableCheckBox->setObjectName(QString::fromUtf8("ResizableCheckBox"));

        gridLayout_3->addWidget(ResizableCheckBox, 1, 0, 1, 1);

        UnderglowCheckBox = new QCheckBox(groupBox_Zones);
        UnderglowCheckBox->setObjectName(QString::fromUtf8("UnderglowCheckBox"));

        gridLayout_3->addWidget(UnderglowCheckBox, 2, 0, 1, 1);


        gridLayout_2->addWidget(groupBox_Zones, 3, 0, 1, 2);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 0, 0, 1, 1);

        LayoutLabel = new QLabel(groupBox);
        LayoutLabel->setObjectName(QString::fromUtf8("LayoutLabel"));

        gridLayout_2->addWidget(LayoutLabel, 2, 0, 1, 1);

        LayoutComboBox = new QComboBox(groupBox);
        LayoutComboBox->setObjectName(QString::fromUtf8("LayoutComboBox"));

        gridLayout_2->addWidget(LayoutComboBox, 2, 1, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(DebugSettingsEntry);

        QMetaObject::connectSlotsByName(DebugSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *DebugSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("DebugSettingsEntry", "Debug Device", nullptr));
        TypeLabel->setText(QCoreApplication::translate("DebugSettingsEntry", "Type:", nullptr));
        NameEdit->setPlaceholderText(QCoreApplication::translate("DebugSettingsEntry", "Device Name", nullptr));
        groupBox_Zones->setTitle(QCoreApplication::translate("DebugSettingsEntry", "Zones", nullptr));
        KeyboardCheckBox->setText(QCoreApplication::translate("DebugSettingsEntry", "Keyboard", nullptr));
        LinearCheckBox->setText(QCoreApplication::translate("DebugSettingsEntry", "Linear", nullptr));
        SingleCheckBox->setText(QCoreApplication::translate("DebugSettingsEntry", "Single", nullptr));
        ResizableCheckBox->setText(QCoreApplication::translate("DebugSettingsEntry", "Resizable", nullptr));
        UnderglowCheckBox->setText(QCoreApplication::translate("DebugSettingsEntry", "Underglow", nullptr));
        NameLabel->setText(QCoreApplication::translate("DebugSettingsEntry", "Name:", nullptr));
        LayoutLabel->setText(QCoreApplication::translate("DebugSettingsEntry", "Layout:", nullptr));
        (void)DebugSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class DebugSettingsEntry: public Ui_DebugSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEBUGSETTINGSENTRY_H
