/****************************************************************************
** Meta object code from reading C++ file 'OpenRGBDevicePage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "qt/OpenRGBDevicePage/OpenRGBDevicePage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OpenRGBDevicePage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OpenRGBDevicePage_t {
    QByteArrayData data[43];
    char stringdata0[839];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OpenRGBDevicePage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OpenRGBDevicePage_t qt_meta_stringdata_OpenRGBDevicePage = {
    {
QT_MOC_LITERAL(0, 0, 17), // "OpenRGBDevicePage"
QT_MOC_LITERAL(1, 18, 13), // "SetAllDevices"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 3), // "red"
QT_MOC_LITERAL(4, 37, 5), // "green"
QT_MOC_LITERAL(5, 43, 4), // "blue"
QT_MOC_LITERAL(6, 48, 15), // "SaveSizeProfile"
QT_MOC_LITERAL(7, 64, 11), // "changeEvent"
QT_MOC_LITERAL(8, 76, 7), // "QEvent*"
QT_MOC_LITERAL(9, 84, 5), // "event"
QT_MOC_LITERAL(10, 90, 15), // "UpdateInterface"
QT_MOC_LITERAL(11, 106, 29), // "on_ColorWheelBox_colorChanged"
QT_MOC_LITERAL(12, 136, 5), // "color"
QT_MOC_LITERAL(13, 142, 26), // "on_SwatchBox_swatchChanged"
QT_MOC_LITERAL(14, 169, 35), // "on_DirectionBox_currentIndexC..."
QT_MOC_LITERAL(15, 205, 5), // "index"
QT_MOC_LITERAL(16, 211, 30), // "on_ZoneBox_currentIndexChanged"
QT_MOC_LITERAL(17, 242, 29), // "on_LEDBox_currentIndexChanged"
QT_MOC_LITERAL(18, 272, 32), // "on_BrightnessSlider_valueChanged"
QT_MOC_LITERAL(19, 305, 5), // "value"
QT_MOC_LITERAL(20, 311, 30), // "on_ModeBox_currentIndexChanged"
QT_MOC_LITERAL(21, 342, 27), // "on_SpeedSlider_valueChanged"
QT_MOC_LITERAL(22, 370, 26), // "on_RedSpinBox_valueChanged"
QT_MOC_LITERAL(23, 397, 26), // "on_HueSpinBox_valueChanged"
QT_MOC_LITERAL(24, 424, 3), // "hue"
QT_MOC_LITERAL(25, 428, 28), // "on_GreenSpinBox_valueChanged"
QT_MOC_LITERAL(26, 457, 26), // "on_SatSpinBox_valueChanged"
QT_MOC_LITERAL(27, 484, 3), // "sat"
QT_MOC_LITERAL(28, 488, 27), // "on_BlueSpinBox_valueChanged"
QT_MOC_LITERAL(29, 516, 26), // "on_ValSpinBox_valueChanged"
QT_MOC_LITERAL(30, 543, 3), // "val"
QT_MOC_LITERAL(31, 547, 26), // "on_HexLineEdit_textChanged"
QT_MOC_LITERAL(32, 574, 4), // "arg1"
QT_MOC_LITERAL(33, 579, 33), // "on_DeviceViewBox_selectionCha..."
QT_MOC_LITERAL(34, 613, 12), // "QVector<int>"
QT_MOC_LITERAL(35, 626, 23), // "on_SetAllButton_clicked"
QT_MOC_LITERAL(36, 650, 22), // "on_RandomCheck_clicked"
QT_MOC_LITERAL(37, 673, 22), // "on_PerLEDCheck_clicked"
QT_MOC_LITERAL(38, 696, 28), // "on_ModeSpecificCheck_clicked"
QT_MOC_LITERAL(39, 725, 25), // "on_EditZoneButton_clicked"
QT_MOC_LITERAL(40, 751, 28), // "on_ApplyColorsButton_clicked"
QT_MOC_LITERAL(41, 780, 30), // "on_SelectAllLEDsButton_clicked"
QT_MOC_LITERAL(42, 811, 27) // "on_DeviceSaveButton_clicked"

    },
    "OpenRGBDevicePage\0SetAllDevices\0\0red\0"
    "green\0blue\0SaveSizeProfile\0changeEvent\0"
    "QEvent*\0event\0UpdateInterface\0"
    "on_ColorWheelBox_colorChanged\0color\0"
    "on_SwatchBox_swatchChanged\0"
    "on_DirectionBox_currentIndexChanged\0"
    "index\0on_ZoneBox_currentIndexChanged\0"
    "on_LEDBox_currentIndexChanged\0"
    "on_BrightnessSlider_valueChanged\0value\0"
    "on_ModeBox_currentIndexChanged\0"
    "on_SpeedSlider_valueChanged\0"
    "on_RedSpinBox_valueChanged\0"
    "on_HueSpinBox_valueChanged\0hue\0"
    "on_GreenSpinBox_valueChanged\0"
    "on_SatSpinBox_valueChanged\0sat\0"
    "on_BlueSpinBox_valueChanged\0"
    "on_ValSpinBox_valueChanged\0val\0"
    "on_HexLineEdit_textChanged\0arg1\0"
    "on_DeviceViewBox_selectionChanged\0"
    "QVector<int>\0on_SetAllButton_clicked\0"
    "on_RandomCheck_clicked\0on_PerLEDCheck_clicked\0"
    "on_ModeSpecificCheck_clicked\0"
    "on_EditZoneButton_clicked\0"
    "on_ApplyColorsButton_clicked\0"
    "on_SelectAllLEDsButton_clicked\0"
    "on_DeviceSaveButton_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OpenRGBDevicePage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,  154,    2, 0x06 /* Public */,
       6,    0,  161,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,  162,    2, 0x08 /* Private */,
      10,    0,  165,    2, 0x08 /* Private */,
      11,    1,  166,    2, 0x08 /* Private */,
      13,    1,  169,    2, 0x08 /* Private */,
      14,    1,  172,    2, 0x08 /* Private */,
      16,    1,  175,    2, 0x08 /* Private */,
      17,    1,  178,    2, 0x08 /* Private */,
      18,    1,  181,    2, 0x08 /* Private */,
      20,    1,  184,    2, 0x08 /* Private */,
      21,    1,  187,    2, 0x08 /* Private */,
      22,    1,  190,    2, 0x08 /* Private */,
      23,    1,  193,    2, 0x08 /* Private */,
      25,    1,  196,    2, 0x08 /* Private */,
      26,    1,  199,    2, 0x08 /* Private */,
      28,    1,  202,    2, 0x08 /* Private */,
      29,    1,  205,    2, 0x08 /* Private */,
      31,    1,  208,    2, 0x08 /* Private */,
      33,    1,  211,    2, 0x08 /* Private */,
      35,    0,  214,    2, 0x08 /* Private */,
      36,    0,  215,    2, 0x08 /* Private */,
      37,    0,  216,    2, 0x08 /* Private */,
      38,    0,  217,    2, 0x08 /* Private */,
      39,    0,  218,    2, 0x08 /* Private */,
      40,    0,  219,    2, 0x08 /* Private */,
      41,    0,  220,    2, 0x08 /* Private */,
      42,    0,  221,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::UChar, QMetaType::UChar, QMetaType::UChar,    3,    4,    5,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QColor,   12,
    QMetaType::Void, QMetaType::QColor,   12,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,   30,
    QMetaType::Void, QMetaType::QString,   32,
    QMetaType::Void, 0x80000000 | 34,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void OpenRGBDevicePage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<OpenRGBDevicePage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->SetAllDevices((*reinterpret_cast< unsigned char(*)>(_a[1])),(*reinterpret_cast< unsigned char(*)>(_a[2])),(*reinterpret_cast< unsigned char(*)>(_a[3]))); break;
        case 1: _t->SaveSizeProfile(); break;
        case 2: _t->changeEvent((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 3: _t->UpdateInterface(); break;
        case 4: _t->on_ColorWheelBox_colorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 5: _t->on_SwatchBox_swatchChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 6: _t->on_DirectionBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_ZoneBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->on_LEDBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->on_BrightnessSlider_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->on_ModeBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->on_SpeedSlider_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->on_RedSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->on_HueSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->on_GreenSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->on_SatSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->on_BlueSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->on_ValSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->on_HexLineEdit_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->on_DeviceViewBox_selectionChanged((*reinterpret_cast< QVector<int>(*)>(_a[1]))); break;
        case 20: _t->on_SetAllButton_clicked(); break;
        case 21: _t->on_RandomCheck_clicked(); break;
        case 22: _t->on_PerLEDCheck_clicked(); break;
        case 23: _t->on_ModeSpecificCheck_clicked(); break;
        case 24: _t->on_EditZoneButton_clicked(); break;
        case 25: _t->on_ApplyColorsButton_clicked(); break;
        case 26: _t->on_SelectAllLEDsButton_clicked(); break;
        case 27: _t->on_DeviceSaveButton_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<int> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (OpenRGBDevicePage::*)(unsigned char , unsigned char , unsigned char );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OpenRGBDevicePage::SetAllDevices)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (OpenRGBDevicePage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OpenRGBDevicePage::SaveSizeProfile)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject OpenRGBDevicePage::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_OpenRGBDevicePage.data,
    qt_meta_data_OpenRGBDevicePage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *OpenRGBDevicePage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenRGBDevicePage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OpenRGBDevicePage.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int OpenRGBDevicePage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void OpenRGBDevicePage::SetAllDevices(unsigned char _t1, unsigned char _t2, unsigned char _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void OpenRGBDevicePage::SaveSizeProfile()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
