/********************************************************************************
** Form generated from reading UI file 'TabLabel.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABLABEL_H
#define UI_TABLABEL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TabLabel
{
public:
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *icon;
    QSpacerItem *horizontalSpacer_2;
    QLabel *name;

    void setupUi(QWidget *TabLabel)
    {
        if (TabLabel->objectName().isEmpty())
            TabLabel->setObjectName(QString::fromUtf8("TabLabel"));
        TabLabel->resize(222, 16);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TabLabel->sizePolicy().hasHeightForWidth());
        TabLabel->setSizePolicy(sizePolicy);
        TabLabel->setWindowTitle(QString::fromUtf8("Tab Label"));
        horizontalLayout = new QHBoxLayout(TabLabel);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
        horizontalLayout->setContentsMargins(-1, 0, -1, 0);
        horizontalSpacer = new QSpacerItem(10, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        icon = new QLabel(TabLabel);
        icon->setObjectName(QString::fromUtf8("icon"));

        horizontalLayout->addWidget(icon);

        horizontalSpacer_2 = new QSpacerItem(10, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        name = new QLabel(TabLabel);
        name->setObjectName(QString::fromUtf8("name"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(name->sizePolicy().hasHeightForWidth());
        name->setSizePolicy(sizePolicy1);
        name->setMinimumSize(QSize(150, 0));
        name->setMaximumSize(QSize(150, 16777215));
        name->setWordWrap(true);

        horizontalLayout->addWidget(name);


        retranslateUi(TabLabel);

        QMetaObject::connectSlotsByName(TabLabel);
    } // setupUi

    void retranslateUi(QWidget *TabLabel)
    {
        icon->setText(QString());
        name->setText(QCoreApplication::translate("TabLabel", "device name", nullptr));
        (void)TabLabel;
    } // retranslateUi

};

namespace Ui {
    class TabLabel: public Ui_TabLabel {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TABLABEL_H
