/********************************************************************************
** Form generated from reading UI file 'OpenRGBSupportedDevicesPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBSUPPORTEDDEVICESPAGE_H
#define UI_OPENRGBSUPPORTEDDEVICESPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBSupportedDevicesPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *Filter;
    QCheckBox *ToggleAllCheckbox;
    QTableView *SupportedDevicesTable;
    QHBoxLayout *ButtonsLayout;
    QPushButton *SaveButton;
    QPushButton *GetHardwareIDsButton;

    void setupUi(QWidget *OpenRGBSupportedDevicesPage)
    {
        if (OpenRGBSupportedDevicesPage->objectName().isEmpty())
            OpenRGBSupportedDevicesPage->setObjectName(QString::fromUtf8("OpenRGBSupportedDevicesPage"));
        OpenRGBSupportedDevicesPage->resize(400, 300);
        OpenRGBSupportedDevicesPage->setWindowTitle(QString::fromUtf8("Supported Devices Page"));
        verticalLayout = new QVBoxLayout(OpenRGBSupportedDevicesPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(OpenRGBSupportedDevicesPage);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        Filter = new QLineEdit(OpenRGBSupportedDevicesPage);
        Filter->setObjectName(QString::fromUtf8("Filter"));

        horizontalLayout->addWidget(Filter);

        ToggleAllCheckbox = new QCheckBox(OpenRGBSupportedDevicesPage);
        ToggleAllCheckbox->setObjectName(QString::fromUtf8("ToggleAllCheckbox"));

        horizontalLayout->addWidget(ToggleAllCheckbox);


        verticalLayout->addLayout(horizontalLayout);

        SupportedDevicesTable = new QTableView(OpenRGBSupportedDevicesPage);
        SupportedDevicesTable->setObjectName(QString::fromUtf8("SupportedDevicesTable"));

        verticalLayout->addWidget(SupportedDevicesTable);

        ButtonsLayout = new QHBoxLayout();
        ButtonsLayout->setObjectName(QString::fromUtf8("ButtonsLayout"));
        SaveButton = new QPushButton(OpenRGBSupportedDevicesPage);
        SaveButton->setObjectName(QString::fromUtf8("SaveButton"));

        ButtonsLayout->addWidget(SaveButton);

        GetHardwareIDsButton = new QPushButton(OpenRGBSupportedDevicesPage);
        GetHardwareIDsButton->setObjectName(QString::fromUtf8("GetHardwareIDsButton"));

        ButtonsLayout->addWidget(GetHardwareIDsButton);


        verticalLayout->addLayout(ButtonsLayout);


        retranslateUi(OpenRGBSupportedDevicesPage);

        QMetaObject::connectSlotsByName(OpenRGBSupportedDevicesPage);
    } // setupUi

    void retranslateUi(QWidget *OpenRGBSupportedDevicesPage)
    {
        label->setText(QCoreApplication::translate("OpenRGBSupportedDevicesPage", "Filter:", nullptr));
        ToggleAllCheckbox->setText(QCoreApplication::translate("OpenRGBSupportedDevicesPage", "Enable/Disable all", nullptr));
        SaveButton->setText(QCoreApplication::translate("OpenRGBSupportedDevicesPage", "Apply Changes", nullptr));
        GetHardwareIDsButton->setText(QCoreApplication::translate("OpenRGBSupportedDevicesPage", "Get Hardware IDs", nullptr));
        (void)OpenRGBSupportedDevicesPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBSupportedDevicesPage: public Ui_OpenRGBSupportedDevicesPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBSUPPORTEDDEVICESPAGE_H
