/********************************************************************************
** Form generated from reading UI file 'OpenRGBDeviceInfoPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBDEVICEINFOPAGE_H
#define UI_OPENRGBDEVICEINFOPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBDeviceInfoPage
{
public:
    QGridLayout *gridLayout;
    QFrame *DeviceInfoFrame;
    QGridLayout *gridLayout_2;
    QLabel *VersionValue;
    QLabel *SerialLabel;
    QLabel *SerialValue;
    QLabel *NameLabel;
    QLabel *NameValue;
    QLabel *VendorLabel;
    QLabel *VendorValue;
    QLabel *TypeLabel;
    QLabel *TypeValue;
    QLabel *DescriptionValue;
    QLabel *DescriptionLabel;
    QLabel *VersionLabel;
    QLabel *LocationLabel;
    QLabel *LocationValue;
    QLabel *FlagsLabel;
    QLabel *FlagsValue;

    void setupUi(QFrame *OpenRGBDeviceInfoPage)
    {
        if (OpenRGBDeviceInfoPage->objectName().isEmpty())
            OpenRGBDeviceInfoPage->setObjectName(QString::fromUtf8("OpenRGBDeviceInfoPage"));
        OpenRGBDeviceInfoPage->resize(500, 300);
        OpenRGBDeviceInfoPage->setWindowTitle(QString::fromUtf8("Device Info Page"));
        OpenRGBDeviceInfoPage->setAutoFillBackground(false);
        OpenRGBDeviceInfoPage->setFrameShape(QFrame::NoFrame);
        OpenRGBDeviceInfoPage->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(OpenRGBDeviceInfoPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        DeviceInfoFrame = new QFrame(OpenRGBDeviceInfoPage);
        DeviceInfoFrame->setObjectName(QString::fromUtf8("DeviceInfoFrame"));
        DeviceInfoFrame->setAutoFillBackground(true);
        DeviceInfoFrame->setFrameShape(QFrame::StyledPanel);
        DeviceInfoFrame->setFrameShadow(QFrame::Sunken);
        gridLayout_2 = new QGridLayout(DeviceInfoFrame);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        VersionValue = new QLabel(DeviceInfoFrame);
        VersionValue->setObjectName(QString::fromUtf8("VersionValue"));
        VersionValue->setText(QString::fromUtf8("Version Value"));
        VersionValue->setWordWrap(true);

        gridLayout_2->addWidget(VersionValue, 4, 1, 1, 1);

        SerialLabel = new QLabel(DeviceInfoFrame);
        SerialLabel->setObjectName(QString::fromUtf8("SerialLabel"));

        gridLayout_2->addWidget(SerialLabel, 6, 0, 1, 1);

        SerialValue = new QLabel(DeviceInfoFrame);
        SerialValue->setObjectName(QString::fromUtf8("SerialValue"));
        SerialValue->setText(QString::fromUtf8("Serial Value"));
        SerialValue->setWordWrap(true);

        gridLayout_2->addWidget(SerialValue, 6, 1, 1, 1);

        NameLabel = new QLabel(DeviceInfoFrame);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 0, 0, 1, 1);

        NameValue = new QLabel(DeviceInfoFrame);
        NameValue->setObjectName(QString::fromUtf8("NameValue"));
        NameValue->setText(QString::fromUtf8("Name Value"));
        NameValue->setWordWrap(true);

        gridLayout_2->addWidget(NameValue, 0, 1, 1, 1);

        VendorLabel = new QLabel(DeviceInfoFrame);
        VendorLabel->setObjectName(QString::fromUtf8("VendorLabel"));

        gridLayout_2->addWidget(VendorLabel, 1, 0, 1, 1);

        VendorValue = new QLabel(DeviceInfoFrame);
        VendorValue->setObjectName(QString::fromUtf8("VendorValue"));
        VendorValue->setText(QString::fromUtf8("Vendor Value"));
        VendorValue->setWordWrap(true);

        gridLayout_2->addWidget(VendorValue, 1, 1, 1, 1);

        TypeLabel = new QLabel(DeviceInfoFrame);
        TypeLabel->setObjectName(QString::fromUtf8("TypeLabel"));

        gridLayout_2->addWidget(TypeLabel, 2, 0, 1, 1);

        TypeValue = new QLabel(DeviceInfoFrame);
        TypeValue->setObjectName(QString::fromUtf8("TypeValue"));
        TypeValue->setText(QString::fromUtf8("Type Value"));
        TypeValue->setWordWrap(true);

        gridLayout_2->addWidget(TypeValue, 2, 1, 1, 1);

        DescriptionValue = new QLabel(DeviceInfoFrame);
        DescriptionValue->setObjectName(QString::fromUtf8("DescriptionValue"));
        DescriptionValue->setText(QString::fromUtf8("Description Value"));
        DescriptionValue->setWordWrap(true);

        gridLayout_2->addWidget(DescriptionValue, 3, 1, 1, 1);

        DescriptionLabel = new QLabel(DeviceInfoFrame);
        DescriptionLabel->setObjectName(QString::fromUtf8("DescriptionLabel"));

        gridLayout_2->addWidget(DescriptionLabel, 3, 0, 1, 1);

        VersionLabel = new QLabel(DeviceInfoFrame);
        VersionLabel->setObjectName(QString::fromUtf8("VersionLabel"));

        gridLayout_2->addWidget(VersionLabel, 4, 0, 1, 1);

        LocationLabel = new QLabel(DeviceInfoFrame);
        LocationLabel->setObjectName(QString::fromUtf8("LocationLabel"));

        gridLayout_2->addWidget(LocationLabel, 5, 0, 1, 1);

        LocationValue = new QLabel(DeviceInfoFrame);
        LocationValue->setObjectName(QString::fromUtf8("LocationValue"));
        LocationValue->setText(QString::fromUtf8("Location Value"));
        LocationValue->setWordWrap(true);

        gridLayout_2->addWidget(LocationValue, 5, 1, 1, 1);

        FlagsLabel = new QLabel(DeviceInfoFrame);
        FlagsLabel->setObjectName(QString::fromUtf8("FlagsLabel"));

        gridLayout_2->addWidget(FlagsLabel, 7, 0, 1, 1);

        FlagsValue = new QLabel(DeviceInfoFrame);
        FlagsValue->setObjectName(QString::fromUtf8("FlagsValue"));
        FlagsValue->setText(QString::fromUtf8("Flags Value"));
        FlagsValue->setWordWrap(true);

        gridLayout_2->addWidget(FlagsValue, 7, 1, 1, 1);

        gridLayout_2->setColumnStretch(1, 1);

        gridLayout->addWidget(DeviceInfoFrame, 0, 0, 1, 1);


        retranslateUi(OpenRGBDeviceInfoPage);

        QMetaObject::connectSlotsByName(OpenRGBDeviceInfoPage);
    } // setupUi

    void retranslateUi(QFrame *OpenRGBDeviceInfoPage)
    {
        SerialLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Serial:", nullptr));
        NameLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Name:", nullptr));
        VendorLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Vendor:", nullptr));
        TypeLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Type:", nullptr));
        DescriptionLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Description:", nullptr));
        VersionLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Version:", nullptr));
        LocationLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Location:", nullptr));
        FlagsLabel->setText(QCoreApplication::translate("OpenRGBDeviceInfoPage", "Flags:", nullptr));
        (void)OpenRGBDeviceInfoPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBDeviceInfoPage: public Ui_OpenRGBDeviceInfoPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBDEVICEINFOPAGE_H
