/********************************************************************************
** Form generated from reading UI file 'OpenRGBZoneResizeDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBZONERESIZEDIALOG_H
#define UI_OPENRGBZONERESIZEDIALOG_H

#include <QTooltipedSlider.h>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBZoneResizeDialog
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *AddSegmentButton;
    QPushButton *RemoveSegmentButton;
    QTooltipedSlider *ResizeSlider;
    QTreeWidget *SegmentsTreeWidget;
    QDialogButtonBox *ButtonBox;
    QSpinBox *ResizeBox;

    void setupUi(QDialog *OpenRGBZoneResizeDialog)
    {
        if (OpenRGBZoneResizeDialog->objectName().isEmpty())
            OpenRGBZoneResizeDialog->setObjectName(QString::fromUtf8("OpenRGBZoneResizeDialog"));
        OpenRGBZoneResizeDialog->resize(450, 250);
        gridLayout = new QGridLayout(OpenRGBZoneResizeDialog);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        AddSegmentButton = new QPushButton(OpenRGBZoneResizeDialog);
        AddSegmentButton->setObjectName(QString::fromUtf8("AddSegmentButton"));

        horizontalLayout->addWidget(AddSegmentButton);

        RemoveSegmentButton = new QPushButton(OpenRGBZoneResizeDialog);
        RemoveSegmentButton->setObjectName(QString::fromUtf8("RemoveSegmentButton"));

        horizontalLayout->addWidget(RemoveSegmentButton);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 2);

        ResizeSlider = new QTooltipedSlider(OpenRGBZoneResizeDialog);
        ResizeSlider->setObjectName(QString::fromUtf8("ResizeSlider"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ResizeSlider->sizePolicy().hasHeightForWidth());
        ResizeSlider->setSizePolicy(sizePolicy);
        ResizeSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(ResizeSlider, 0, 0, 1, 1);

        SegmentsTreeWidget = new QTreeWidget(OpenRGBZoneResizeDialog);
        SegmentsTreeWidget->headerItem()->setText(2, QString());
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("Name"));
        SegmentsTreeWidget->setHeaderItem(__qtreewidgetitem);
        SegmentsTreeWidget->setObjectName(QString::fromUtf8("SegmentsTreeWidget"));
        SegmentsTreeWidget->setColumnCount(3);

        gridLayout->addWidget(SegmentsTreeWidget, 1, 0, 1, 2);

        ButtonBox = new QDialogButtonBox(OpenRGBZoneResizeDialog);
        ButtonBox->setObjectName(QString::fromUtf8("ButtonBox"));
        sizePolicy.setHeightForWidth(ButtonBox->sizePolicy().hasHeightForWidth());
        ButtonBox->setSizePolicy(sizePolicy);
        ButtonBox->setOrientation(Qt::Horizontal);
        ButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(ButtonBox, 4, 0, 1, 2);

        ResizeBox = new QSpinBox(OpenRGBZoneResizeDialog);
        ResizeBox->setObjectName(QString::fromUtf8("ResizeBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ResizeBox->sizePolicy().hasHeightForWidth());
        ResizeBox->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(ResizeBox, 0, 1, 1, 1);

        gridLayout->setColumnStretch(0, 1);

        retranslateUi(OpenRGBZoneResizeDialog);
        QObject::connect(ButtonBox, SIGNAL(accepted()), OpenRGBZoneResizeDialog, SLOT(accept()));
        QObject::connect(ButtonBox, SIGNAL(rejected()), OpenRGBZoneResizeDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(OpenRGBZoneResizeDialog);
    } // setupUi

    void retranslateUi(QDialog *OpenRGBZoneResizeDialog)
    {
        OpenRGBZoneResizeDialog->setWindowTitle(QCoreApplication::translate("OpenRGBZoneResizeDialog", "Resize Zone", nullptr));
        AddSegmentButton->setText(QCoreApplication::translate("OpenRGBZoneResizeDialog", "Add Segment", nullptr));
        RemoveSegmentButton->setText(QCoreApplication::translate("OpenRGBZoneResizeDialog", "Remove Segment", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = SegmentsTreeWidget->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("OpenRGBZoneResizeDialog", "Length", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenRGBZoneResizeDialog: public Ui_OpenRGBZoneResizeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBZONERESIZEDIALOG_H
