/****************************************************************************
** Meta object code from reading C++ file 'OpenRGBSettingsPage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "qt/OpenRGBSettingsPage/OpenRGBSettingsPage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OpenRGBSettingsPage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OpenRGBSettingsPage_t {
    QByteArrayData data[48];
    char stringdata0[1425];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OpenRGBSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OpenRGBSettingsPage_t qt_meta_stringdata_OpenRGBSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 19), // "OpenRGBSettingsPage"
QT_MOC_LITERAL(1, 20, 15), // "TrayIconChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 9), // "tray_icon"
QT_MOC_LITERAL(4, 47, 14), // "UpdateProfiles"
QT_MOC_LITERAL(5, 62, 11), // "changeEvent"
QT_MOC_LITERAL(6, 74, 7), // "QEvent*"
QT_MOC_LITERAL(7, 82, 5), // "event"
QT_MOC_LITERAL(8, 88, 38), // "on_ComboBoxLanguage_currentTe..."
QT_MOC_LITERAL(9, 127, 35), // "on_ComboBoxTheme_currentTextC..."
QT_MOC_LITERAL(10, 163, 39), // "on_ComboBoxHexFormat_currentT..."
QT_MOC_LITERAL(11, 203, 34), // "on_CheckboxMinimizeOnClose_cl..."
QT_MOC_LITERAL(12, 238, 36), // "on_CheckboxTrayIconGreyscale_..."
QT_MOC_LITERAL(13, 275, 31), // "on_CheckboxLoadGeometry_clicked"
QT_MOC_LITERAL(14, 307, 31), // "on_CheckboxSaveGeometry_clicked"
QT_MOC_LITERAL(15, 339, 28), // "on_CheckboxAutoStart_clicked"
QT_MOC_LITERAL(16, 368, 37), // "on_CheckboxAutoStartMinimized..."
QT_MOC_LITERAL(17, 406, 34), // "on_CheckboxAutoStartServer_cl..."
QT_MOC_LITERAL(18, 441, 34), // "on_CheckboxAutoStartClient_cl..."
QT_MOC_LITERAL(19, 476, 35), // "on_CheckboxAutoStartProfile_c..."
QT_MOC_LITERAL(20, 512, 29), // "on_TextServerHost_textChanged"
QT_MOC_LITERAL(21, 542, 30), // "on_TextServerPort_valueChanged"
QT_MOC_LITERAL(22, 573, 29), // "on_TextClientHost_textChanged"
QT_MOC_LITERAL(23, 603, 29), // "on_TextCustomArgs_textChanged"
QT_MOC_LITERAL(24, 633, 46), // "on_ComboBoxAutoStartProfile_c..."
QT_MOC_LITERAL(25, 680, 41), // "on_CheckboxAutoStartSetServer..."
QT_MOC_LITERAL(26, 722, 41), // "on_CheckboxAutoStartSetServer..."
QT_MOC_LITERAL(27, 764, 34), // "on_CheckboxAutoStartCustom_cl..."
QT_MOC_LITERAL(28, 799, 32), // "on_CheckboxRunZoneChecks_clicked"
QT_MOC_LITERAL(29, 832, 35), // "on_OpenSettingsFolderButton_c..."
QT_MOC_LITERAL(30, 868, 29), // "on_CheckboxLogConsole_clicked"
QT_MOC_LITERAL(31, 898, 26), // "on_CheckboxLogFile_clicked"
QT_MOC_LITERAL(32, 925, 36), // "on_CheckboxAMDSMBusReduceCPU_..."
QT_MOC_LITERAL(33, 962, 36), // "on_CheckboxSharedSMBusAccess_..."
QT_MOC_LITERAL(34, 999, 28), // "on_CheckboxSetOnExit_clicked"
QT_MOC_LITERAL(35, 1028, 7), // "checked"
QT_MOC_LITERAL(36, 1036, 41), // "on_ComboBoxExitProfile_curren..."
QT_MOC_LITERAL(37, 1078, 17), // "exit_profile_name"
QT_MOC_LITERAL(38, 1096, 30), // "on_CheckboxSetOnResume_clicked"
QT_MOC_LITERAL(39, 1127, 43), // "on_ComboBoxResumeProfile_curr..."
QT_MOC_LITERAL(40, 1171, 19), // "resume_profile_name"
QT_MOC_LITERAL(41, 1191, 31), // "on_CheckboxSetOnSuspend_clicked"
QT_MOC_LITERAL(42, 1223, 44), // "on_ComboBoxSuspendProfile_cur..."
QT_MOC_LITERAL(43, 1268, 20), // "suspend_profile_name"
QT_MOC_LITERAL(44, 1289, 38), // "on_CheckboxDisableKeyExpansio..."
QT_MOC_LITERAL(45, 1328, 30), // "on_CheckboxShowLEDView_clicked"
QT_MOC_LITERAL(46, 1359, 29), // "on_CheckboxAllDevices_clicked"
QT_MOC_LITERAL(47, 1389, 35) // "on_CheckboxLegacyWorkaround_c..."

    },
    "OpenRGBSettingsPage\0TrayIconChanged\0"
    "\0tray_icon\0UpdateProfiles\0changeEvent\0"
    "QEvent*\0event\0on_ComboBoxLanguage_currentTextChanged\0"
    "on_ComboBoxTheme_currentTextChanged\0"
    "on_ComboBoxHexFormat_currentTextChanged\0"
    "on_CheckboxMinimizeOnClose_clicked\0"
    "on_CheckboxTrayIconGreyscale_clicked\0"
    "on_CheckboxLoadGeometry_clicked\0"
    "on_CheckboxSaveGeometry_clicked\0"
    "on_CheckboxAutoStart_clicked\0"
    "on_CheckboxAutoStartMinimized_clicked\0"
    "on_CheckboxAutoStartServer_clicked\0"
    "on_CheckboxAutoStartClient_clicked\0"
    "on_CheckboxAutoStartProfile_clicked\0"
    "on_TextServerHost_textChanged\0"
    "on_TextServerPort_valueChanged\0"
    "on_TextClientHost_textChanged\0"
    "on_TextCustomArgs_textChanged\0"
    "on_ComboBoxAutoStartProfile_currentTextChanged\0"
    "on_CheckboxAutoStartSetServerHost_clicked\0"
    "on_CheckboxAutoStartSetServerPort_clicked\0"
    "on_CheckboxAutoStartCustom_clicked\0"
    "on_CheckboxRunZoneChecks_clicked\0"
    "on_OpenSettingsFolderButton_clicked\0"
    "on_CheckboxLogConsole_clicked\0"
    "on_CheckboxLogFile_clicked\0"
    "on_CheckboxAMDSMBusReduceCPU_clicked\0"
    "on_CheckboxSharedSMBusAccess_clicked\0"
    "on_CheckboxSetOnExit_clicked\0checked\0"
    "on_ComboBoxExitProfile_currentTextChanged\0"
    "exit_profile_name\0on_CheckboxSetOnResume_clicked\0"
    "on_ComboBoxResumeProfile_currentTextChanged\0"
    "resume_profile_name\0on_CheckboxSetOnSuspend_clicked\0"
    "on_ComboBoxSuspendProfile_currentTextChanged\0"
    "suspend_profile_name\0"
    "on_CheckboxDisableKeyExpansion_clicked\0"
    "on_CheckboxShowLEDView_clicked\0"
    "on_CheckboxAllDevices_clicked\0"
    "on_CheckboxLegacyWorkaround_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OpenRGBSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      39,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  209,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  212,    2, 0x0a /* Public */,
       5,    1,  213,    2, 0x08 /* Private */,
       8,    1,  216,    2, 0x08 /* Private */,
       9,    1,  219,    2, 0x08 /* Private */,
      10,    1,  222,    2, 0x08 /* Private */,
      11,    0,  225,    2, 0x08 /* Private */,
      12,    0,  226,    2, 0x08 /* Private */,
      13,    0,  227,    2, 0x08 /* Private */,
      14,    0,  228,    2, 0x08 /* Private */,
      15,    0,  229,    2, 0x08 /* Private */,
      16,    0,  230,    2, 0x08 /* Private */,
      17,    0,  231,    2, 0x08 /* Private */,
      18,    0,  232,    2, 0x08 /* Private */,
      19,    0,  233,    2, 0x08 /* Private */,
      20,    1,  234,    2, 0x08 /* Private */,
      21,    1,  237,    2, 0x08 /* Private */,
      22,    1,  240,    2, 0x08 /* Private */,
      23,    1,  243,    2, 0x08 /* Private */,
      24,    1,  246,    2, 0x08 /* Private */,
      25,    0,  249,    2, 0x08 /* Private */,
      26,    0,  250,    2, 0x08 /* Private */,
      27,    0,  251,    2, 0x08 /* Private */,
      28,    0,  252,    2, 0x08 /* Private */,
      29,    0,  253,    2, 0x08 /* Private */,
      30,    0,  254,    2, 0x08 /* Private */,
      31,    0,  255,    2, 0x08 /* Private */,
      32,    0,  256,    2, 0x08 /* Private */,
      33,    0,  257,    2, 0x08 /* Private */,
      34,    1,  258,    2, 0x08 /* Private */,
      36,    1,  261,    2, 0x08 /* Private */,
      38,    1,  264,    2, 0x08 /* Private */,
      39,    1,  267,    2, 0x08 /* Private */,
      41,    1,  270,    2, 0x08 /* Private */,
      42,    1,  273,    2, 0x08 /* Private */,
      44,    0,  276,    2, 0x08 /* Private */,
      45,    0,  277,    2, 0x08 /* Private */,
      46,    1,  278,    2, 0x08 /* Private */,
      47,    1,  281,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   35,
    QMetaType::Void, QMetaType::QString,   37,
    QMetaType::Void, QMetaType::Bool,   35,
    QMetaType::Void, QMetaType::QString,   40,
    QMetaType::Void, QMetaType::Bool,   35,
    QMetaType::Void, QMetaType::QString,   43,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   35,
    QMetaType::Void, QMetaType::Bool,   35,

       0        // eod
};

void OpenRGBSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<OpenRGBSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->TrayIconChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->UpdateProfiles(); break;
        case 2: _t->changeEvent((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 3: _t->on_ComboBoxLanguage_currentTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->on_ComboBoxTheme_currentTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->on_ComboBoxHexFormat_currentTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->on_CheckboxMinimizeOnClose_clicked(); break;
        case 7: _t->on_CheckboxTrayIconGreyscale_clicked(); break;
        case 8: _t->on_CheckboxLoadGeometry_clicked(); break;
        case 9: _t->on_CheckboxSaveGeometry_clicked(); break;
        case 10: _t->on_CheckboxAutoStart_clicked(); break;
        case 11: _t->on_CheckboxAutoStartMinimized_clicked(); break;
        case 12: _t->on_CheckboxAutoStartServer_clicked(); break;
        case 13: _t->on_CheckboxAutoStartClient_clicked(); break;
        case 14: _t->on_CheckboxAutoStartProfile_clicked(); break;
        case 15: _t->on_TextServerHost_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->on_TextServerPort_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->on_TextClientHost_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->on_TextCustomArgs_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->on_ComboBoxAutoStartProfile_currentTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->on_CheckboxAutoStartSetServerHost_clicked(); break;
        case 21: _t->on_CheckboxAutoStartSetServerPort_clicked(); break;
        case 22: _t->on_CheckboxAutoStartCustom_clicked(); break;
        case 23: _t->on_CheckboxRunZoneChecks_clicked(); break;
        case 24: _t->on_OpenSettingsFolderButton_clicked(); break;
        case 25: _t->on_CheckboxLogConsole_clicked(); break;
        case 26: _t->on_CheckboxLogFile_clicked(); break;
        case 27: _t->on_CheckboxAMDSMBusReduceCPU_clicked(); break;
        case 28: _t->on_CheckboxSharedSMBusAccess_clicked(); break;
        case 29: _t->on_CheckboxSetOnExit_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->on_ComboBoxExitProfile_currentTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 31: _t->on_CheckboxSetOnResume_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->on_ComboBoxResumeProfile_currentTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 33: _t->on_CheckboxSetOnSuspend_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 34: _t->on_ComboBoxSuspendProfile_currentTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 35: _t->on_CheckboxDisableKeyExpansion_clicked(); break;
        case 36: _t->on_CheckboxShowLEDView_clicked(); break;
        case 37: _t->on_CheckboxAllDevices_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 38: _t->on_CheckboxLegacyWorkaround_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (OpenRGBSettingsPage::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OpenRGBSettingsPage::TrayIconChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject OpenRGBSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_OpenRGBSettingsPage.data,
    qt_meta_data_OpenRGBSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *OpenRGBSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenRGBSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OpenRGBSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int OpenRGBSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void OpenRGBSettingsPage::TrayIconChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
