/********************************************************************************
** Form generated from reading UI file 'DMXSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DMXSETTINGSENTRY_H
#define UI_DMXSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DMXSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *BrightnessLabel;
    QLineEdit *BrightnessEdit;
    QLabel *label;
    QLineEdit *GreenEdit;
    QLineEdit *RedEdit;
    QLabel *NameLabel;
    QLabel *GreenLabel;
    QLabel *RedLabel;
    QLineEdit *BlueEdit;
    QLineEdit *NameEdit;
    QLabel *KeepaliveTimeLabel;
    QLineEdit *KeepaliveTimeEdit;
    QLabel *PortLabel;
    QComboBox *PortComboBox;

    void setupUi(QWidget *DMXSettingsEntry)
    {
        if (DMXSettingsEntry->objectName().isEmpty())
            DMXSettingsEntry->setObjectName(QString::fromUtf8("DMXSettingsEntry"));
        DMXSettingsEntry->resize(531, 206);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DMXSettingsEntry->sizePolicy().hasHeightForWidth());
        DMXSettingsEntry->setSizePolicy(sizePolicy);
        DMXSettingsEntry->setWindowTitle(QString::fromUtf8("DMX Settings Entry"));
        gridLayout = new QGridLayout(DMXSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(DMXSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        BrightnessLabel = new QLabel(groupBox);
        BrightnessLabel->setObjectName(QString::fromUtf8("BrightnessLabel"));

        gridLayout_2->addWidget(BrightnessLabel, 4, 4, 1, 1);

        BrightnessEdit = new QLineEdit(groupBox);
        BrightnessEdit->setObjectName(QString::fromUtf8("BrightnessEdit"));

        gridLayout_2->addWidget(BrightnessEdit, 4, 5, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_2->addWidget(label, 4, 0, 1, 1);

        GreenEdit = new QLineEdit(groupBox);
        GreenEdit->setObjectName(QString::fromUtf8("GreenEdit"));

        gridLayout_2->addWidget(GreenEdit, 3, 5, 1, 1);

        RedEdit = new QLineEdit(groupBox);
        RedEdit->setObjectName(QString::fromUtf8("RedEdit"));

        gridLayout_2->addWidget(RedEdit, 3, 3, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 1, 0, 1, 1);

        GreenLabel = new QLabel(groupBox);
        GreenLabel->setObjectName(QString::fromUtf8("GreenLabel"));

        gridLayout_2->addWidget(GreenLabel, 3, 4, 1, 1);

        RedLabel = new QLabel(groupBox);
        RedLabel->setObjectName(QString::fromUtf8("RedLabel"));

        gridLayout_2->addWidget(RedLabel, 3, 0, 1, 1);

        BlueEdit = new QLineEdit(groupBox);
        BlueEdit->setObjectName(QString::fromUtf8("BlueEdit"));

        gridLayout_2->addWidget(BlueEdit, 4, 3, 1, 1);

        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 1, 3, 1, 1);

        KeepaliveTimeLabel = new QLabel(groupBox);
        KeepaliveTimeLabel->setObjectName(QString::fromUtf8("KeepaliveTimeLabel"));

        gridLayout_2->addWidget(KeepaliveTimeLabel, 5, 0, 1, 1);

        KeepaliveTimeEdit = new QLineEdit(groupBox);
        KeepaliveTimeEdit->setObjectName(QString::fromUtf8("KeepaliveTimeEdit"));

        gridLayout_2->addWidget(KeepaliveTimeEdit, 5, 3, 1, 1);

        PortLabel = new QLabel(groupBox);
        PortLabel->setObjectName(QString::fromUtf8("PortLabel"));

        gridLayout_2->addWidget(PortLabel, 1, 4, 1, 1);

        PortComboBox = new QComboBox(groupBox);
        PortComboBox->setObjectName(QString::fromUtf8("PortComboBox"));
        PortComboBox->setEditable(true);
        PortComboBox->setInsertPolicy(QComboBox::NoInsert);

        gridLayout_2->addWidget(PortComboBox, 1, 5, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(DMXSettingsEntry);

        QMetaObject::connectSlotsByName(DMXSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *DMXSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("DMXSettingsEntry", "DMX Device", nullptr));
        BrightnessLabel->setText(QCoreApplication::translate("DMXSettingsEntry", "Brightness Channel:", nullptr));
        label->setText(QCoreApplication::translate("DMXSettingsEntry", "Blue Channel:", nullptr));
        NameLabel->setText(QCoreApplication::translate("DMXSettingsEntry", "Name:", nullptr));
        GreenLabel->setText(QCoreApplication::translate("DMXSettingsEntry", "Green Channel:", nullptr));
        RedLabel->setText(QCoreApplication::translate("DMXSettingsEntry", "Red Channel:", nullptr));
        KeepaliveTimeLabel->setText(QCoreApplication::translate("DMXSettingsEntry", "Keepalive Time:", nullptr));
        PortLabel->setText(QCoreApplication::translate("DMXSettingsEntry", "Port:", nullptr));
        (void)DMXSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class DMXSettingsEntry: public Ui_DMXSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DMXSETTINGSENTRY_H
