/********************************************************************************
** Form generated from reading UI file 'SerialSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERIALSETTINGSENTRY_H
#define UI_SERIALSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SerialSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *NumLEDsLabel;
    QLabel *BaudLabel;
    QComboBox *ProtocolComboBox;
    QLabel *NameLabel;
    QLineEdit *NameEdit;
    QLabel *ProtocolLabel;
    QLineEdit *BaudEdit;
    QLineEdit *NumLEDsEdit;
    QLabel *PortLabel;
    QComboBox *PortComboBox;

    void setupUi(QWidget *SerialSettingsEntry)
    {
        if (SerialSettingsEntry->objectName().isEmpty())
            SerialSettingsEntry->setObjectName(QString::fromUtf8("SerialSettingsEntry"));
        SerialSettingsEntry->resize(531, 237);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SerialSettingsEntry->sizePolicy().hasHeightForWidth());
        SerialSettingsEntry->setSizePolicy(sizePolicy);
        SerialSettingsEntry->setWindowTitle(QString::fromUtf8("Serial Settings Entry"));
        gridLayout = new QGridLayout(SerialSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(SerialSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        NumLEDsLabel = new QLabel(groupBox);
        NumLEDsLabel->setObjectName(QString::fromUtf8("NumLEDsLabel"));

        gridLayout_2->addWidget(NumLEDsLabel, 2, 4, 1, 1);

        BaudLabel = new QLabel(groupBox);
        BaudLabel->setObjectName(QString::fromUtf8("BaudLabel"));

        gridLayout_2->addWidget(BaudLabel, 2, 0, 1, 1);

        ProtocolComboBox = new QComboBox(groupBox);
        ProtocolComboBox->setObjectName(QString::fromUtf8("ProtocolComboBox"));

        gridLayout_2->addWidget(ProtocolComboBox, 3, 3, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 1, 0, 1, 1);

        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 1, 3, 1, 1);

        ProtocolLabel = new QLabel(groupBox);
        ProtocolLabel->setObjectName(QString::fromUtf8("ProtocolLabel"));

        gridLayout_2->addWidget(ProtocolLabel, 3, 0, 1, 1);

        BaudEdit = new QLineEdit(groupBox);
        BaudEdit->setObjectName(QString::fromUtf8("BaudEdit"));

        gridLayout_2->addWidget(BaudEdit, 2, 3, 1, 1);

        NumLEDsEdit = new QLineEdit(groupBox);
        NumLEDsEdit->setObjectName(QString::fromUtf8("NumLEDsEdit"));

        gridLayout_2->addWidget(NumLEDsEdit, 2, 5, 1, 1);

        PortLabel = new QLabel(groupBox);
        PortLabel->setObjectName(QString::fromUtf8("PortLabel"));

        gridLayout_2->addWidget(PortLabel, 1, 4, 1, 1);

        PortComboBox = new QComboBox(groupBox);
        PortComboBox->setObjectName(QString::fromUtf8("PortComboBox"));
        PortComboBox->setEditable(true);
        PortComboBox->setInsertPolicy(QComboBox::NoInsert);

        gridLayout_2->addWidget(PortComboBox, 1, 5, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);

        QWidget::setTabOrder(NameEdit, BaudEdit);
        QWidget::setTabOrder(BaudEdit, NumLEDsEdit);
        QWidget::setTabOrder(NumLEDsEdit, ProtocolComboBox);

        retranslateUi(SerialSettingsEntry);

        QMetaObject::connectSlotsByName(SerialSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *SerialSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("SerialSettingsEntry", "Serial Device", nullptr));
        NumLEDsLabel->setText(QCoreApplication::translate("SerialSettingsEntry", "Number of LEDs:", nullptr));
        BaudLabel->setText(QCoreApplication::translate("SerialSettingsEntry", "Baud:", nullptr));
        NameLabel->setText(QCoreApplication::translate("SerialSettingsEntry", "Name:", nullptr));
        ProtocolLabel->setText(QCoreApplication::translate("SerialSettingsEntry", "Protocol:", nullptr));
        PortLabel->setText(QCoreApplication::translate("SerialSettingsEntry", "Port:", nullptr));
        (void)SerialSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class SerialSettingsEntry: public Ui_SerialSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SERIALSETTINGSENTRY_H
