/********************************************************************************
** Form generated from reading UI file 'OpenRGBPluginsPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBPLUGINSPAGE_H
#define UI_OPENRGBPLUGINSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "qt/OpenRGBPluginsPage/OpenRGBPluginsList.h"

QT_BEGIN_NAMESPACE

class Ui_OpenRGBPluginsPage
{
public:
    QGridLayout *gridLayout;
    OpenRGBPluginsList *PluginsList;
    QPushButton *InstallPluginButton;
    QPushButton *RemovePluginButton;
    QLabel *LinkLabel;

    void setupUi(QWidget *OpenRGBPluginsPage)
    {
        if (OpenRGBPluginsPage->objectName().isEmpty())
            OpenRGBPluginsPage->setObjectName(QString::fromUtf8("OpenRGBPluginsPage"));
        OpenRGBPluginsPage->resize(400, 300);
        OpenRGBPluginsPage->setWindowTitle(QString::fromUtf8("Plugins Page"));
        gridLayout = new QGridLayout(OpenRGBPluginsPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        PluginsList = new OpenRGBPluginsList(OpenRGBPluginsPage);
        PluginsList->setObjectName(QString::fromUtf8("PluginsList"));
        PluginsList->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        gridLayout->addWidget(PluginsList, 1, 0, 1, 2);

        InstallPluginButton = new QPushButton(OpenRGBPluginsPage);
        InstallPluginButton->setObjectName(QString::fromUtf8("InstallPluginButton"));

        gridLayout->addWidget(InstallPluginButton, 2, 0, 1, 1);

        RemovePluginButton = new QPushButton(OpenRGBPluginsPage);
        RemovePluginButton->setObjectName(QString::fromUtf8("RemovePluginButton"));
        RemovePluginButton->setEnabled(false);

        gridLayout->addWidget(RemovePluginButton, 2, 1, 1, 1);

        LinkLabel = new QLabel(OpenRGBPluginsPage);
        LinkLabel->setObjectName(QString::fromUtf8("LinkLabel"));
        LinkLabel->setTextFormat(Qt::RichText);
        LinkLabel->setAlignment(Qt::AlignCenter);
        LinkLabel->setOpenExternalLinks(true);

        gridLayout->addWidget(LinkLabel, 0, 0, 1, 2);


        retranslateUi(OpenRGBPluginsPage);

        QMetaObject::connectSlotsByName(OpenRGBPluginsPage);
    } // setupUi

    void retranslateUi(QWidget *OpenRGBPluginsPage)
    {
        InstallPluginButton->setText(QCoreApplication::translate("OpenRGBPluginsPage", "Install Plugin", nullptr));
        RemovePluginButton->setText(QCoreApplication::translate("OpenRGBPluginsPage", "Remove Plugin", nullptr));
        LinkLabel->setText(QCoreApplication::translate("OpenRGBPluginsPage", "<html><head/><body>Looking for plugins? See the official list at <a href=\"https://openrgb.org/plugins.html\">OpenRGB.org</a></body></html>", nullptr));
        (void)OpenRGBPluginsPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBPluginsPage: public Ui_OpenRGBPluginsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBPLUGINSPAGE_H
