/********************************************************************************
** Form generated from reading UI file 'GoveeSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GOVEESETTINGSENTRY_H
#define UI_GOVEESETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_GoveeSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *IPLabel;
    QLineEdit *IPEdit;

    void setupUi(QWidget *GoveeSettingsEntry)
    {
        if (GoveeSettingsEntry->objectName().isEmpty())
            GoveeSettingsEntry->setObjectName(QString::fromUtf8("GoveeSettingsEntry"));
        GoveeSettingsEntry->resize(328, 81);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GoveeSettingsEntry->sizePolicy().hasHeightForWidth());
        GoveeSettingsEntry->setSizePolicy(sizePolicy);
        GoveeSettingsEntry->setWindowTitle(QString::fromUtf8("Philips Wiz Settings Entry"));
        gridLayout = new QGridLayout(GoveeSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(GoveeSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 0, 0, 1, 1);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 0, 1, 1, 1);


        gridLayout->addWidget(groupBox, 0, 1, 1, 1);


        retranslateUi(GoveeSettingsEntry);

        QMetaObject::connectSlotsByName(GoveeSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *GoveeSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("GoveeSettingsEntry", "Govee Device", nullptr));
        IPLabel->setText(QCoreApplication::translate("GoveeSettingsEntry", "IP:", nullptr));
        (void)GoveeSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class GoveeSettingsEntry: public Ui_GoveeSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GOVEESETTINGSENTRY_H
