/********************************************************************************
** Form generated from reading UI file 'OpenRGBClientInfoPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBCLIENTINFOPAGE_H
#define UI_OPENRGBCLIENTINFOPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBClientInfoPage
{
public:
    QGridLayout *gridLayout;
    QLineEdit *ClientPortValue;
    QLabel *ClientPortLabel;
    QSpacerItem *horizontalSpacer;
    QPushButton *ClientConnectButton;
    QLineEdit *ClientIPValue;
    QLabel *ClientIPLabel;
    QTreeWidget *ClientTree;

    void setupUi(QFrame *OpenRGBClientInfoPage)
    {
        if (OpenRGBClientInfoPage->objectName().isEmpty())
            OpenRGBClientInfoPage->setObjectName(QString::fromUtf8("OpenRGBClientInfoPage"));
        OpenRGBClientInfoPage->resize(664, 300);
        OpenRGBClientInfoPage->setWindowTitle(QString::fromUtf8("Client Info Page"));
        gridLayout = new QGridLayout(OpenRGBClientInfoPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        ClientPortValue = new QLineEdit(OpenRGBClientInfoPage);
        ClientPortValue->setObjectName(QString::fromUtf8("ClientPortValue"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ClientPortValue->sizePolicy().hasHeightForWidth());
        ClientPortValue->setSizePolicy(sizePolicy);

        gridLayout->addWidget(ClientPortValue, 0, 6, 1, 1);

        ClientPortLabel = new QLabel(OpenRGBClientInfoPage);
        ClientPortLabel->setObjectName(QString::fromUtf8("ClientPortLabel"));

        gridLayout->addWidget(ClientPortLabel, 0, 5, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 7, 1, 1);

        ClientConnectButton = new QPushButton(OpenRGBClientInfoPage);
        ClientConnectButton->setObjectName(QString::fromUtf8("ClientConnectButton"));

        gridLayout->addWidget(ClientConnectButton, 0, 8, 1, 1);

        ClientIPValue = new QLineEdit(OpenRGBClientInfoPage);
        ClientIPValue->setObjectName(QString::fromUtf8("ClientIPValue"));

        gridLayout->addWidget(ClientIPValue, 0, 4, 1, 1);

        ClientIPLabel = new QLabel(OpenRGBClientInfoPage);
        ClientIPLabel->setObjectName(QString::fromUtf8("ClientIPLabel"));

        gridLayout->addWidget(ClientIPLabel, 0, 3, 1, 1);

        ClientTree = new QTreeWidget(OpenRGBClientInfoPage);
        ClientTree->headerItem()->setText(3, QString());
        ClientTree->headerItem()->setText(4, QString());
        ClientTree->setObjectName(QString::fromUtf8("ClientTree"));
        ClientTree->setColumnCount(5);

        gridLayout->addWidget(ClientTree, 1, 3, 1, 6);

        QWidget::setTabOrder(ClientIPValue, ClientPortValue);
        QWidget::setTabOrder(ClientPortValue, ClientConnectButton);
        QWidget::setTabOrder(ClientConnectButton, ClientTree);

        retranslateUi(OpenRGBClientInfoPage);

        QMetaObject::connectSlotsByName(OpenRGBClientInfoPage);
    } // setupUi

    void retranslateUi(QFrame *OpenRGBClientInfoPage)
    {
        ClientPortLabel->setText(QCoreApplication::translate("OpenRGBClientInfoPage", "Port:", nullptr));
        ClientConnectButton->setText(QCoreApplication::translate("OpenRGBClientInfoPage", "Connect", nullptr));
        ClientIPLabel->setText(QCoreApplication::translate("OpenRGBClientInfoPage", "IP:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = ClientTree->headerItem();
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("OpenRGBClientInfoPage", "Save Connection", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("OpenRGBClientInfoPage", "Protocol Version", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("OpenRGBClientInfoPage", "Connected Clients", nullptr));
        (void)OpenRGBClientInfoPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBClientInfoPage: public Ui_OpenRGBClientInfoPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBCLIENTINFOPAGE_H
