/********************************************************************************
** Form generated from reading UI file 'OpenRGBHardwareIDsDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBHARDWAREIDSDIALOG_H
#define UI_OPENRGBHARDWAREIDSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBHardwareIDsDialog
{
public:
    QGridLayout *gridLayout;
    QPushButton *CopyToClipboardButton;
    QTreeWidget *HardwareIdsList;

    void setupUi(QWidget *OpenRGBHardwareIDsDialog)
    {
        if (OpenRGBHardwareIDsDialog->objectName().isEmpty())
            OpenRGBHardwareIDsDialog->setObjectName(QString::fromUtf8("OpenRGBHardwareIDsDialog"));
        OpenRGBHardwareIDsDialog->resize(700, 500);
        gridLayout = new QGridLayout(OpenRGBHardwareIDsDialog);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        CopyToClipboardButton = new QPushButton(OpenRGBHardwareIDsDialog);
        CopyToClipboardButton->setObjectName(QString::fromUtf8("CopyToClipboardButton"));

        gridLayout->addWidget(CopyToClipboardButton, 1, 0, 1, 1);

        HardwareIdsList = new QTreeWidget(OpenRGBHardwareIDsDialog);
        HardwareIdsList->setObjectName(QString::fromUtf8("HardwareIdsList"));

        gridLayout->addWidget(HardwareIdsList, 0, 0, 1, 1);


        retranslateUi(OpenRGBHardwareIDsDialog);

        QMetaObject::connectSlotsByName(OpenRGBHardwareIDsDialog);
    } // setupUi

    void retranslateUi(QWidget *OpenRGBHardwareIDsDialog)
    {
        OpenRGBHardwareIDsDialog->setWindowTitle(QCoreApplication::translate("OpenRGBHardwareIDsDialog", "Hardware IDs", nullptr));
        CopyToClipboardButton->setText(QCoreApplication::translate("OpenRGBHardwareIDsDialog", "Copy to clipboard", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = HardwareIdsList->headerItem();
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("OpenRGBHardwareIDsDialog", "Vendor", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("OpenRGBHardwareIDsDialog", "Device", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("OpenRGBHardwareIDsDialog", "Location", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenRGBHardwareIDsDialog: public Ui_OpenRGBHardwareIDsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBHARDWAREIDSDIALOG_H
