/****************************************************************************
** Meta object code from reading C++ file 'OpenRGBDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "qt/OpenRGBDialog/OpenRGBDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OpenRGBDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OpenRGBDialog_t {
    QByteArrayData data[44];
    char stringdata0[797];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OpenRGBDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OpenRGBDialog_t qt_meta_stringdata_OpenRGBDialog = {
    {
QT_MOC_LITERAL(0, 0, 13), // "OpenRGBDialog"
QT_MOC_LITERAL(1, 14, 18), // "ProfileListChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 11), // "changeEvent"
QT_MOC_LITERAL(4, 46, 7), // "QEvent*"
QT_MOC_LITERAL(5, 54, 5), // "event"
QT_MOC_LITERAL(6, 60, 11), // "SetTrayIcon"
QT_MOC_LITERAL(7, 72, 9), // "tray_icon"
QT_MOC_LITERAL(8, 82, 17), // "handleAboutToQuit"
QT_MOC_LITERAL(9, 100, 7), // "on_Exit"
QT_MOC_LITERAL(10, 108, 12), // "on_LightsOff"
QT_MOC_LITERAL(11, 121, 11), // "on_QuickRed"
QT_MOC_LITERAL(12, 133, 14), // "on_QuickYellow"
QT_MOC_LITERAL(13, 148, 13), // "on_QuickGreen"
QT_MOC_LITERAL(14, 162, 12), // "on_QuickCyan"
QT_MOC_LITERAL(15, 175, 12), // "on_QuickBlue"
QT_MOC_LITERAL(16, 188, 15), // "on_QuickMagenta"
QT_MOC_LITERAL(17, 204, 13), // "on_QuickWhite"
QT_MOC_LITERAL(18, 218, 19), // "onDeviceListUpdated"
QT_MOC_LITERAL(19, 238, 26), // "onDetectionProgressUpdated"
QT_MOC_LITERAL(20, 265, 18), // "onDetectionStarted"
QT_MOC_LITERAL(21, 284, 16), // "onDetectionEnded"
QT_MOC_LITERAL(22, 301, 16), // "on_SetAllDevices"
QT_MOC_LITERAL(23, 318, 3), // "red"
QT_MOC_LITERAL(24, 322, 5), // "green"
QT_MOC_LITERAL(25, 328, 4), // "blue"
QT_MOC_LITERAL(26, 333, 18), // "on_SaveSizeProfile"
QT_MOC_LITERAL(27, 352, 11), // "on_ShowHide"
QT_MOC_LITERAL(28, 364, 19), // "onShowDialogMessage"
QT_MOC_LITERAL(29, 384, 9), // "on_ReShow"
QT_MOC_LITERAL(30, 394, 33), // "QSystemTrayIcon::ActivationRe..."
QT_MOC_LITERAL(31, 428, 6), // "reason"
QT_MOC_LITERAL(32, 435, 18), // "on_ProfileSelected"
QT_MOC_LITERAL(33, 454, 28), // "on_ButtonLoadProfile_clicked"
QT_MOC_LITERAL(34, 483, 30), // "on_ButtonDeleteProfile_clicked"
QT_MOC_LITERAL(35, 514, 33), // "on_ButtonToggleDeviceView_cli..."
QT_MOC_LITERAL(36, 548, 30), // "on_ButtonStopDetection_clicked"
QT_MOC_LITERAL(37, 579, 23), // "on_ButtonRescan_clicked"
QT_MOC_LITERAL(38, 603, 30), // "on_ActionSaveProfile_triggered"
QT_MOC_LITERAL(39, 634, 32), // "on_ActionSaveProfileAs_triggered"
QT_MOC_LITERAL(40, 667, 28), // "on_MainTabBar_currentChanged"
QT_MOC_LITERAL(41, 696, 35), // "on_InformationTabBar_currentC..."
QT_MOC_LITERAL(42, 732, 31), // "on_DevicesTabBar_currentChanged"
QT_MOC_LITERAL(43, 764, 32) // "on_SettingsTabBar_currentChanged"

    },
    "OpenRGBDialog\0ProfileListChanged\0\0"
    "changeEvent\0QEvent*\0event\0SetTrayIcon\0"
    "tray_icon\0handleAboutToQuit\0on_Exit\0"
    "on_LightsOff\0on_QuickRed\0on_QuickYellow\0"
    "on_QuickGreen\0on_QuickCyan\0on_QuickBlue\0"
    "on_QuickMagenta\0on_QuickWhite\0"
    "onDeviceListUpdated\0onDetectionProgressUpdated\0"
    "onDetectionStarted\0onDetectionEnded\0"
    "on_SetAllDevices\0red\0green\0blue\0"
    "on_SaveSizeProfile\0on_ShowHide\0"
    "onShowDialogMessage\0on_ReShow\0"
    "QSystemTrayIcon::ActivationReason\0"
    "reason\0on_ProfileSelected\0"
    "on_ButtonLoadProfile_clicked\0"
    "on_ButtonDeleteProfile_clicked\0"
    "on_ButtonToggleDeviceView_clicked\0"
    "on_ButtonStopDetection_clicked\0"
    "on_ButtonRescan_clicked\0"
    "on_ActionSaveProfile_triggered\0"
    "on_ActionSaveProfileAs_triggered\0"
    "on_MainTabBar_currentChanged\0"
    "on_InformationTabBar_currentChanged\0"
    "on_DevicesTabBar_currentChanged\0"
    "on_SettingsTabBar_currentChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OpenRGBDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      34,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  184,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  185,    2, 0x0a /* Public */,
       6,    1,  188,    2, 0x0a /* Public */,
       8,    0,  191,    2, 0x0a /* Public */,
       9,    0,  192,    2, 0x08 /* Private */,
      10,    0,  193,    2, 0x08 /* Private */,
      11,    0,  194,    2, 0x08 /* Private */,
      12,    0,  195,    2, 0x08 /* Private */,
      13,    0,  196,    2, 0x08 /* Private */,
      14,    0,  197,    2, 0x08 /* Private */,
      15,    0,  198,    2, 0x08 /* Private */,
      16,    0,  199,    2, 0x08 /* Private */,
      17,    0,  200,    2, 0x08 /* Private */,
      18,    0,  201,    2, 0x08 /* Private */,
      19,    0,  202,    2, 0x08 /* Private */,
      20,    0,  203,    2, 0x08 /* Private */,
      21,    0,  204,    2, 0x08 /* Private */,
      22,    3,  205,    2, 0x08 /* Private */,
      26,    0,  212,    2, 0x08 /* Private */,
      27,    0,  213,    2, 0x08 /* Private */,
      28,    0,  214,    2, 0x08 /* Private */,
      29,    1,  215,    2, 0x08 /* Private */,
      32,    0,  218,    2, 0x08 /* Private */,
      33,    0,  219,    2, 0x08 /* Private */,
      34,    0,  220,    2, 0x08 /* Private */,
      35,    0,  221,    2, 0x08 /* Private */,
      36,    0,  222,    2, 0x08 /* Private */,
      37,    0,  223,    2, 0x08 /* Private */,
      38,    0,  224,    2, 0x08 /* Private */,
      39,    0,  225,    2, 0x08 /* Private */,
      40,    1,  226,    2, 0x08 /* Private */,
      41,    1,  229,    2, 0x08 /* Private */,
      42,    1,  232,    2, 0x08 /* Private */,
      43,    1,  235,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UChar, QMetaType::UChar, QMetaType::UChar,   23,   24,   25,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 30,   31,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void OpenRGBDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<OpenRGBDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->ProfileListChanged(); break;
        case 1: _t->changeEvent((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 2: _t->SetTrayIcon((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->handleAboutToQuit(); break;
        case 4: _t->on_Exit(); break;
        case 5: _t->on_LightsOff(); break;
        case 6: _t->on_QuickRed(); break;
        case 7: _t->on_QuickYellow(); break;
        case 8: _t->on_QuickGreen(); break;
        case 9: _t->on_QuickCyan(); break;
        case 10: _t->on_QuickBlue(); break;
        case 11: _t->on_QuickMagenta(); break;
        case 12: _t->on_QuickWhite(); break;
        case 13: _t->onDeviceListUpdated(); break;
        case 14: _t->onDetectionProgressUpdated(); break;
        case 15: _t->onDetectionStarted(); break;
        case 16: _t->onDetectionEnded(); break;
        case 17: _t->on_SetAllDevices((*reinterpret_cast< unsigned char(*)>(_a[1])),(*reinterpret_cast< unsigned char(*)>(_a[2])),(*reinterpret_cast< unsigned char(*)>(_a[3]))); break;
        case 18: _t->on_SaveSizeProfile(); break;
        case 19: _t->on_ShowHide(); break;
        case 20: _t->onShowDialogMessage(); break;
        case 21: _t->on_ReShow((*reinterpret_cast< QSystemTrayIcon::ActivationReason(*)>(_a[1]))); break;
        case 22: _t->on_ProfileSelected(); break;
        case 23: _t->on_ButtonLoadProfile_clicked(); break;
        case 24: _t->on_ButtonDeleteProfile_clicked(); break;
        case 25: _t->on_ButtonToggleDeviceView_clicked(); break;
        case 26: _t->on_ButtonStopDetection_clicked(); break;
        case 27: _t->on_ButtonRescan_clicked(); break;
        case 28: _t->on_ActionSaveProfile_triggered(); break;
        case 29: _t->on_ActionSaveProfileAs_triggered(); break;
        case 30: _t->on_MainTabBar_currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->on_InformationTabBar_currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->on_DevicesTabBar_currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->on_SettingsTabBar_currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (OpenRGBDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OpenRGBDialog::ProfileListChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject OpenRGBDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_OpenRGBDialog.data,
    qt_meta_data_OpenRGBDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *OpenRGBDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenRGBDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OpenRGBDialog.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int OpenRGBDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void OpenRGBDialog::ProfileListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
