/********************************************************************************
** Form generated from reading UI file 'PhilipsHueSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PHILIPSHUESETTINGSENTRY_H
#define UI_PHILIPSHUESETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PhilipsHueSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *EntertainmentLabel;
    QCheckBox *EntertainmentCheckBox;
    QLabel *AutoConnectLabel;
    QCheckBox *AutoConnectCheckBox;
    QLabel *IPLabel;
    QLabel *ClientKeyValue;
    QLabel *ClientKeyLabel;
    QLabel *UsernameLabel;
    QLabel *MACLabel;
    QPushButton *UnpairButton;
    QLineEdit *MACEdit;
    QLineEdit *IPEdit;
    QLabel *UsernameValue;

    void setupUi(QWidget *PhilipsHueSettingsEntry)
    {
        if (PhilipsHueSettingsEntry->objectName().isEmpty())
            PhilipsHueSettingsEntry->setObjectName(QString::fromUtf8("PhilipsHueSettingsEntry"));
        PhilipsHueSettingsEntry->resize(297, 260);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PhilipsHueSettingsEntry->sizePolicy().hasHeightForWidth());
        PhilipsHueSettingsEntry->setSizePolicy(sizePolicy);
        PhilipsHueSettingsEntry->setWindowTitle(QString::fromUtf8("Philips Hue Settings Entry"));
        gridLayout = new QGridLayout(PhilipsHueSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(PhilipsHueSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        EntertainmentLabel = new QLabel(groupBox);
        EntertainmentLabel->setObjectName(QString::fromUtf8("EntertainmentLabel"));

        gridLayout_2->addWidget(EntertainmentLabel, 3, 0, 1, 1);

        EntertainmentCheckBox = new QCheckBox(groupBox);
        EntertainmentCheckBox->setObjectName(QString::fromUtf8("EntertainmentCheckBox"));

        gridLayout_2->addWidget(EntertainmentCheckBox, 3, 3, 1, 1);

        AutoConnectLabel = new QLabel(groupBox);
        AutoConnectLabel->setObjectName(QString::fromUtf8("AutoConnectLabel"));

        gridLayout_2->addWidget(AutoConnectLabel, 4, 0, 1, 1);

        AutoConnectCheckBox = new QCheckBox(groupBox);
        AutoConnectCheckBox->setObjectName(QString::fromUtf8("AutoConnectCheckBox"));

        gridLayout_2->addWidget(AutoConnectCheckBox, 4, 3, 1, 1);

        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 1, 0, 1, 1);

        ClientKeyValue = new QLabel(groupBox);
        ClientKeyValue->setObjectName(QString::fromUtf8("ClientKeyValue"));

        gridLayout_2->addWidget(ClientKeyValue, 6, 3, 1, 1);

        ClientKeyLabel = new QLabel(groupBox);
        ClientKeyLabel->setObjectName(QString::fromUtf8("ClientKeyLabel"));

        gridLayout_2->addWidget(ClientKeyLabel, 6, 0, 1, 1);

        UsernameLabel = new QLabel(groupBox);
        UsernameLabel->setObjectName(QString::fromUtf8("UsernameLabel"));

        gridLayout_2->addWidget(UsernameLabel, 5, 0, 1, 1);

        MACLabel = new QLabel(groupBox);
        MACLabel->setObjectName(QString::fromUtf8("MACLabel"));

        gridLayout_2->addWidget(MACLabel, 2, 0, 1, 1);

        UnpairButton = new QPushButton(groupBox);
        UnpairButton->setObjectName(QString::fromUtf8("UnpairButton"));

        gridLayout_2->addWidget(UnpairButton, 7, 0, 1, 4);

        MACEdit = new QLineEdit(groupBox);
        MACEdit->setObjectName(QString::fromUtf8("MACEdit"));

        gridLayout_2->addWidget(MACEdit, 2, 3, 1, 1);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 1, 3, 1, 1);

        UsernameValue = new QLabel(groupBox);
        UsernameValue->setObjectName(QString::fromUtf8("UsernameValue"));

        gridLayout_2->addWidget(UsernameValue, 5, 3, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(PhilipsHueSettingsEntry);

        QMetaObject::connectSlotsByName(PhilipsHueSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *PhilipsHueSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("PhilipsHueSettingsEntry", "Philips Hue Bridge", nullptr));
        EntertainmentLabel->setText(QCoreApplication::translate("PhilipsHueSettingsEntry", "Entertainment Mode:", nullptr));
        EntertainmentCheckBox->setText(QString());
        AutoConnectLabel->setText(QCoreApplication::translate("PhilipsHueSettingsEntry", "Auto Connect Group:", nullptr));
        AutoConnectCheckBox->setText(QString());
        IPLabel->setText(QCoreApplication::translate("PhilipsHueSettingsEntry", "IP:", nullptr));
        ClientKeyValue->setText(QString());
        ClientKeyLabel->setText(QCoreApplication::translate("PhilipsHueSettingsEntry", "Client Key:", nullptr));
        UsernameLabel->setText(QCoreApplication::translate("PhilipsHueSettingsEntry", "Username:", nullptr));
        MACLabel->setText(QCoreApplication::translate("PhilipsHueSettingsEntry", "MAC:", nullptr));
        UnpairButton->setText(QCoreApplication::translate("PhilipsHueSettingsEntry", "Unpair Bridge", nullptr));
        UsernameValue->setText(QString());
        (void)PhilipsHueSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class PhilipsHueSettingsEntry: public Ui_PhilipsHueSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PHILIPSHUESETTINGSENTRY_H
