/********************************************************************************
** Form generated from reading UI file 'DDPSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DDPSETTINGSENTRY_H
#define UI_DDPSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DDPSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *IPLabel;
    QLineEdit *IPEdit;
    QLabel *NameLabel;
    QLineEdit *NameEdit;
    QLabel *PortLabel;
    QSpinBox *PortSpinBox;
    QLabel *NumLedsLabel;
    QSpinBox *NumLedsSpinBox;
    QLabel *KeepaliveTimeLabel;
    QSpinBox *KeepaliveTimeSpinBox;

    void setupUi(QWidget *DDPSettingsEntry)
    {
        if (DDPSettingsEntry->objectName().isEmpty())
            DDPSettingsEntry->setObjectName(QString::fromUtf8("DDPSettingsEntry"));
        DDPSettingsEntry->resize(400, 200);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DDPSettingsEntry->sizePolicy().hasHeightForWidth());
        DDPSettingsEntry->setSizePolicy(sizePolicy);
        DDPSettingsEntry->setWindowTitle(QString::fromUtf8("DDP Settings Entry"));
        gridLayout = new QGridLayout(DDPSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(DDPSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 0, 0, 1, 1);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 0, 1, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 1, 0, 1, 1);

        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 1, 1, 1, 1);

        PortLabel = new QLabel(groupBox);
        PortLabel->setObjectName(QString::fromUtf8("PortLabel"));

        gridLayout_2->addWidget(PortLabel, 2, 0, 1, 1);

        PortSpinBox = new QSpinBox(groupBox);
        PortSpinBox->setObjectName(QString::fromUtf8("PortSpinBox"));
        PortSpinBox->setMinimum(1);
        PortSpinBox->setMaximum(65535);
        PortSpinBox->setValue(4048);

        gridLayout_2->addWidget(PortSpinBox, 2, 1, 1, 1);

        NumLedsLabel = new QLabel(groupBox);
        NumLedsLabel->setObjectName(QString::fromUtf8("NumLedsLabel"));

        gridLayout_2->addWidget(NumLedsLabel, 3, 0, 1, 1);

        NumLedsSpinBox = new QSpinBox(groupBox);
        NumLedsSpinBox->setObjectName(QString::fromUtf8("NumLedsSpinBox"));
        NumLedsSpinBox->setMinimum(1);
        NumLedsSpinBox->setMaximum(10000);
        NumLedsSpinBox->setValue(50);

        gridLayout_2->addWidget(NumLedsSpinBox, 3, 1, 1, 1);

        KeepaliveTimeLabel = new QLabel(groupBox);
        KeepaliveTimeLabel->setObjectName(QString::fromUtf8("KeepaliveTimeLabel"));

        gridLayout_2->addWidget(KeepaliveTimeLabel, 4, 0, 1, 1);

        KeepaliveTimeSpinBox = new QSpinBox(groupBox);
        KeepaliveTimeSpinBox->setObjectName(QString::fromUtf8("KeepaliveTimeSpinBox"));
        KeepaliveTimeSpinBox->setMinimum(0);
        KeepaliveTimeSpinBox->setMaximum(10000);
        KeepaliveTimeSpinBox->setValue(1000);

        gridLayout_2->addWidget(KeepaliveTimeSpinBox, 4, 1, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(DDPSettingsEntry);

        QMetaObject::connectSlotsByName(DDPSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *DDPSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("DDPSettingsEntry", "DDP Device", nullptr));
        IPLabel->setText(QCoreApplication::translate("DDPSettingsEntry", "IP Address:", nullptr));
        IPEdit->setPlaceholderText(QCoreApplication::translate("DDPSettingsEntry", "192.168.1.100", nullptr));
        NameLabel->setText(QCoreApplication::translate("DDPSettingsEntry", "Name:", nullptr));
        NameEdit->setPlaceholderText(QCoreApplication::translate("DDPSettingsEntry", "Device Name", nullptr));
        PortLabel->setText(QCoreApplication::translate("DDPSettingsEntry", "Port:", nullptr));
        NumLedsLabel->setText(QCoreApplication::translate("DDPSettingsEntry", "Number of LEDs:", nullptr));
        KeepaliveTimeLabel->setText(QCoreApplication::translate("DDPSettingsEntry", "Keepalive Time (ms):", nullptr));
        KeepaliveTimeSpinBox->setSpecialValueText(QCoreApplication::translate("DDPSettingsEntry", "Disabled", nullptr));
        (void)DDPSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class DDPSettingsEntry: public Ui_DDPSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DDPSETTINGSENTRY_H
