/********************************************************************************
** Form generated from reading UI file 'OpenRGBZonesBulkResizer.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBZONESBULKRESIZER_H
#define UI_OPENRGBZONESBULKRESIZER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBZonesBulkResizer
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QLabel *help_label;
    QCheckBox *do_not_show_again_checkbox;
    QPushButton *save_button;
    QTableWidget *zones_table;
    QPushButton *ignore_button;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *OpenRGBZonesBulkResizer)
    {
        if (OpenRGBZonesBulkResizer->objectName().isEmpty())
            OpenRGBZonesBulkResizer->setObjectName(QString::fromUtf8("OpenRGBZonesBulkResizer"));
        OpenRGBZonesBulkResizer->resize(800, 500);
        gridLayout = new QGridLayout(OpenRGBZonesBulkResizer);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 2);

        help_label = new QLabel(OpenRGBZonesBulkResizer);
        help_label->setObjectName(QString::fromUtf8("help_label"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(help_label->sizePolicy().hasHeightForWidth());
        help_label->setSizePolicy(sizePolicy);
        help_label->setWordWrap(true);

        gridLayout->addWidget(help_label, 0, 0, 1, 2);

        do_not_show_again_checkbox = new QCheckBox(OpenRGBZonesBulkResizer);
        do_not_show_again_checkbox->setObjectName(QString::fromUtf8("do_not_show_again_checkbox"));

        gridLayout->addWidget(do_not_show_again_checkbox, 5, 0, 1, 2);

        save_button = new QPushButton(OpenRGBZonesBulkResizer);
        save_button->setObjectName(QString::fromUtf8("save_button"));

        gridLayout->addWidget(save_button, 4, 1, 1, 1);

        zones_table = new QTableWidget(OpenRGBZonesBulkResizer);
        zones_table->setObjectName(QString::fromUtf8("zones_table"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(100);
        sizePolicy1.setVerticalStretch(100);
        sizePolicy1.setHeightForWidth(zones_table->sizePolicy().hasHeightForWidth());
        zones_table->setSizePolicy(sizePolicy1);
        zones_table->setStyleSheet(QString::fromUtf8(""));
        zones_table->setFrameShape(QFrame::StyledPanel);
        zones_table->setFrameShadow(QFrame::Raised);
        zones_table->setShowGrid(false);
        zones_table->setGridStyle(Qt::NoPen);

        gridLayout->addWidget(zones_table, 2, 0, 1, 2);

        ignore_button = new QPushButton(OpenRGBZonesBulkResizer);
        ignore_button->setObjectName(QString::fromUtf8("ignore_button"));

        gridLayout->addWidget(ignore_button, 4, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 1, 0, 1, 2);

        do_not_show_again_checkbox->raise();
        save_button->raise();
        zones_table->raise();
        ignore_button->raise();
        help_label->raise();

        retranslateUi(OpenRGBZonesBulkResizer);

        QMetaObject::connectSlotsByName(OpenRGBZonesBulkResizer);
    } // setupUi

    void retranslateUi(QWidget *OpenRGBZonesBulkResizer)
    {
        OpenRGBZonesBulkResizer->setWindowTitle(QCoreApplication::translate("OpenRGBZonesBulkResizer", "Zones Resizer", nullptr));
        help_label->setText(QCoreApplication::translate("OpenRGBZonesBulkResizer", "<html><head/><body><p>One or more resizable zones have not been configured.  Resizable zones are most commonly used for addressable RGB headers where the size of the connected device cannot be detected automatically.</p><p>Please enter the number of LEDs in each zone below.</p><p>For more information about calcuating the correct size, please check <a href=\"https://openrgb.org/resize.html\"><span style=\" text-decoration: underline; color:#0000ff;\">this link.</span></a></p></body></html>", nullptr));
        do_not_show_again_checkbox->setText(QCoreApplication::translate("OpenRGBZonesBulkResizer", "Do not show again", nullptr));
        save_button->setText(QCoreApplication::translate("OpenRGBZonesBulkResizer", "Save and close", nullptr));
        ignore_button->setText(QCoreApplication::translate("OpenRGBZonesBulkResizer", "Ignore", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenRGBZonesBulkResizer: public Ui_OpenRGBZonesBulkResizer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBZONESBULKRESIZER_H
