/********************************************************************************
** Form generated from reading UI file 'PhilipsWizSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PHILIPSWIZSETTINGSENTRY_H
#define UI_PHILIPSWIZSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PhilipsWizSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *UseCoolWhiteCheckBox;
    QCheckBox *UseWarmWhiteCheckBox;
    QLineEdit *IPEdit;
    QLabel *IPLabel;
    QComboBox *WhiteStrategyComboBox;
    QLabel *WhiteStrategyLabel;

    void setupUi(QWidget *PhilipsWizSettingsEntry)
    {
        if (PhilipsWizSettingsEntry->objectName().isEmpty())
            PhilipsWizSettingsEntry->setObjectName(QString::fromUtf8("PhilipsWizSettingsEntry"));
        PhilipsWizSettingsEntry->resize(327, 149);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PhilipsWizSettingsEntry->sizePolicy().hasHeightForWidth());
        PhilipsWizSettingsEntry->setSizePolicy(sizePolicy);
        PhilipsWizSettingsEntry->setWindowTitle(QString::fromUtf8("Philips Wiz Settings Entry"));
        gridLayout = new QGridLayout(PhilipsWizSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(PhilipsWizSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        UseCoolWhiteCheckBox = new QCheckBox(groupBox);
        UseCoolWhiteCheckBox->setObjectName(QString::fromUtf8("UseCoolWhiteCheckBox"));

        gridLayout_2->addWidget(UseCoolWhiteCheckBox, 2, 0, 1, 1);

        UseWarmWhiteCheckBox = new QCheckBox(groupBox);
        UseWarmWhiteCheckBox->setObjectName(QString::fromUtf8("UseWarmWhiteCheckBox"));

        gridLayout_2->addWidget(UseWarmWhiteCheckBox, 2, 1, 1, 1);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 0, 1, 1, 1);

        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 0, 0, 1, 1);

        WhiteStrategyComboBox = new QComboBox(groupBox);
        WhiteStrategyComboBox->setObjectName(QString::fromUtf8("WhiteStrategyComboBox"));

        gridLayout_2->addWidget(WhiteStrategyComboBox, 1, 1, 1, 1);

        WhiteStrategyLabel = new QLabel(groupBox);
        WhiteStrategyLabel->setObjectName(QString::fromUtf8("WhiteStrategyLabel"));

        gridLayout_2->addWidget(WhiteStrategyLabel, 1, 0, 1, 1);


        gridLayout->addWidget(groupBox, 0, 1, 1, 1);


        retranslateUi(PhilipsWizSettingsEntry);

        QMetaObject::connectSlotsByName(PhilipsWizSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *PhilipsWizSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("PhilipsWizSettingsEntry", "Philips Wiz Device", nullptr));
        UseCoolWhiteCheckBox->setText(QCoreApplication::translate("PhilipsWizSettingsEntry", "Use Cool White", nullptr));
        UseWarmWhiteCheckBox->setText(QCoreApplication::translate("PhilipsWizSettingsEntry", "Use Warm White", nullptr));
        IPLabel->setText(QCoreApplication::translate("PhilipsWizSettingsEntry", "IP:", nullptr));
        WhiteStrategyLabel->setText(QCoreApplication::translate("PhilipsWizSettingsEntry", "White Strategy:", nullptr));
        (void)PhilipsWizSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class PhilipsWizSettingsEntry: public Ui_PhilipsWizSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PHILIPSWIZSETTINGSENTRY_H
