/********************************************************************************
** Form generated from reading UI file 'OpenRGBPluginsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBPLUGINSENTRY_H
#define UI_OPENRGBPLUGINSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBPluginsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *URLLabel;
    QLabel *IconView;
    QLabel *URLValue;
    QLabel *EnabledLabel;
    QLabel *DescriptionLabel;
    QLabel *NameValue;
    QLabel *PathValue;
    QLabel *VersionValue;
    QLabel *CommitValue;
    QLabel *NameLabel;
    QLabel *PathLabel;
    QCheckBox *EnabledCheckBox;
    QLabel *VersionLabel;
    QLabel *CommitLabel;
    QLabel *DescriptionValue;
    QLabel *APIVersionLabel;
    QLabel *APIVersionValue;

    void setupUi(QWidget *OpenRGBPluginsEntry)
    {
        if (OpenRGBPluginsEntry->objectName().isEmpty())
            OpenRGBPluginsEntry->setObjectName(QString::fromUtf8("OpenRGBPluginsEntry"));
        OpenRGBPluginsEntry->resize(478, 238);
        OpenRGBPluginsEntry->setWindowTitle(QString::fromUtf8("Plugins Entry"));
        gridLayout = new QGridLayout(OpenRGBPluginsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(OpenRGBPluginsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        URLLabel = new QLabel(groupBox);
        URLLabel->setObjectName(QString::fromUtf8("URLLabel"));

        gridLayout_2->addWidget(URLLabel, 5, 1, 1, 1);

        IconView = new QLabel(groupBox);
        IconView->setObjectName(QString::fromUtf8("IconView"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(IconView->sizePolicy().hasHeightForWidth());
        IconView->setSizePolicy(sizePolicy);
        IconView->setMinimumSize(QSize(64, 64));
        IconView->setMaximumSize(QSize(64, 64));
        IconView->setText(QString::fromUtf8("Icon"));
        IconView->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(IconView, 0, 0, 8, 1);

        URLValue = new QLabel(groupBox);
        URLValue->setObjectName(QString::fromUtf8("URLValue"));
        URLValue->setText(QString::fromUtf8("URL Value"));
        URLValue->setOpenExternalLinks(true);

        gridLayout_2->addWidget(URLValue, 5, 2, 1, 1);

        EnabledLabel = new QLabel(groupBox);
        EnabledLabel->setObjectName(QString::fromUtf8("EnabledLabel"));

        gridLayout_2->addWidget(EnabledLabel, 7, 1, 1, 1);

        DescriptionLabel = new QLabel(groupBox);
        DescriptionLabel->setObjectName(QString::fromUtf8("DescriptionLabel"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(DescriptionLabel->sizePolicy().hasHeightForWidth());
        DescriptionLabel->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(DescriptionLabel, 1, 1, 1, 1);

        NameValue = new QLabel(groupBox);
        NameValue->setObjectName(QString::fromUtf8("NameValue"));
        QSizePolicy sizePolicy2(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(NameValue->sizePolicy().hasHeightForWidth());
        NameValue->setSizePolicy(sizePolicy2);
        NameValue->setText(QString::fromUtf8("Name Value"));

        gridLayout_2->addWidget(NameValue, 0, 2, 1, 1);

        PathValue = new QLabel(groupBox);
        PathValue->setObjectName(QString::fromUtf8("PathValue"));
        PathValue->setText(QString::fromUtf8("Path Value"));

        gridLayout_2->addWidget(PathValue, 2, 2, 1, 1);

        VersionValue = new QLabel(groupBox);
        VersionValue->setObjectName(QString::fromUtf8("VersionValue"));
        VersionValue->setText(QString::fromUtf8("Version Value"));

        gridLayout_2->addWidget(VersionValue, 3, 2, 1, 1);

        CommitValue = new QLabel(groupBox);
        CommitValue->setObjectName(QString::fromUtf8("CommitValue"));
        CommitValue->setText(QString::fromUtf8("Commit Value"));

        gridLayout_2->addWidget(CommitValue, 4, 2, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));
        sizePolicy1.setHeightForWidth(NameLabel->sizePolicy().hasHeightForWidth());
        NameLabel->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(NameLabel, 0, 1, 1, 1);

        PathLabel = new QLabel(groupBox);
        PathLabel->setObjectName(QString::fromUtf8("PathLabel"));

        gridLayout_2->addWidget(PathLabel, 2, 1, 1, 1);

        EnabledCheckBox = new QCheckBox(groupBox);
        EnabledCheckBox->setObjectName(QString::fromUtf8("EnabledCheckBox"));

        gridLayout_2->addWidget(EnabledCheckBox, 7, 2, 1, 1);

        VersionLabel = new QLabel(groupBox);
        VersionLabel->setObjectName(QString::fromUtf8("VersionLabel"));

        gridLayout_2->addWidget(VersionLabel, 3, 1, 1, 1);

        CommitLabel = new QLabel(groupBox);
        CommitLabel->setObjectName(QString::fromUtf8("CommitLabel"));

        gridLayout_2->addWidget(CommitLabel, 4, 1, 1, 1);

        DescriptionValue = new QLabel(groupBox);
        DescriptionValue->setObjectName(QString::fromUtf8("DescriptionValue"));
        sizePolicy2.setHeightForWidth(DescriptionValue->sizePolicy().hasHeightForWidth());
        DescriptionValue->setSizePolicy(sizePolicy2);
        DescriptionValue->setText(QString::fromUtf8("Description Value"));

        gridLayout_2->addWidget(DescriptionValue, 1, 2, 1, 1);

        APIVersionLabel = new QLabel(groupBox);
        APIVersionLabel->setObjectName(QString::fromUtf8("APIVersionLabel"));

        gridLayout_2->addWidget(APIVersionLabel, 6, 1, 1, 1);

        APIVersionValue = new QLabel(groupBox);
        APIVersionValue->setObjectName(QString::fromUtf8("APIVersionValue"));

        gridLayout_2->addWidget(APIVersionValue, 6, 2, 1, 1);


        gridLayout->addWidget(groupBox, 0, 0, 1, 1);


        retranslateUi(OpenRGBPluginsEntry);

        QMetaObject::connectSlotsByName(OpenRGBPluginsEntry);
    } // setupUi

    void retranslateUi(QWidget *OpenRGBPluginsEntry)
    {
        groupBox->setTitle(QString());
        URLLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "URL:", nullptr));
        EnabledLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "Enabled", nullptr));
        DescriptionLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "Description:", nullptr));
        NameLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "Name:", nullptr));
        PathLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "Path:", nullptr));
        EnabledCheckBox->setText(QString());
        VersionLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "Version:", nullptr));
        CommitLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "Commit:", nullptr));
        APIVersionLabel->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "API Version:", nullptr));
        APIVersionValue->setText(QCoreApplication::translate("OpenRGBPluginsEntry", "API Version Value", nullptr));
        (void)OpenRGBPluginsEntry;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBPluginsEntry: public Ui_OpenRGBPluginsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBPLUGINSENTRY_H
