/********************************************************************************
** Form generated from reading UI file 'OpenRGBServerInfoPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBSERVERINFOPAGE_H
#define UI_OPENRGBSERVERINFOPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBServerInfoPage
{
public:
    QGridLayout *gridLayout;
    QPushButton *ServerStopButton;
    QLabel *ServerPortLabel;
    QLabel *ServerClientsLabel;
    QTreeWidget *ServerClientTree;
    QLineEdit *ServerPortValue;
    QLabel *ServerStatusLabel;
    QPushButton *ServerStartButton;
    QLabel *ServerStatusValue;
    QSpacerItem *horizontalSpacer;
    QLabel *ServerHostLabel;
    QLineEdit *ServerHostValue;

    void setupUi(QFrame *OpenRGBServerInfoPage)
    {
        if (OpenRGBServerInfoPage->objectName().isEmpty())
            OpenRGBServerInfoPage->setObjectName(QString::fromUtf8("OpenRGBServerInfoPage"));
        OpenRGBServerInfoPage->resize(664, 300);
        OpenRGBServerInfoPage->setWindowTitle(QString::fromUtf8("Server Info Page"));
        gridLayout = new QGridLayout(OpenRGBServerInfoPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        ServerStopButton = new QPushButton(OpenRGBServerInfoPage);
        ServerStopButton->setObjectName(QString::fromUtf8("ServerStopButton"));

        gridLayout->addWidget(ServerStopButton, 2, 3, 1, 1);

        ServerPortLabel = new QLabel(OpenRGBServerInfoPage);
        ServerPortLabel->setObjectName(QString::fromUtf8("ServerPortLabel"));

        gridLayout->addWidget(ServerPortLabel, 2, 0, 1, 1);

        ServerClientsLabel = new QLabel(OpenRGBServerInfoPage);
        ServerClientsLabel->setObjectName(QString::fromUtf8("ServerClientsLabel"));

        gridLayout->addWidget(ServerClientsLabel, 4, 0, 1, 1);

        ServerClientTree = new QTreeWidget(OpenRGBServerInfoPage);
        ServerClientTree->setObjectName(QString::fromUtf8("ServerClientTree"));
        ServerClientTree->setColumnCount(3);

        gridLayout->addWidget(ServerClientTree, 5, 0, 1, 4);

        ServerPortValue = new QLineEdit(OpenRGBServerInfoPage);
        ServerPortValue->setObjectName(QString::fromUtf8("ServerPortValue"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ServerPortValue->sizePolicy().hasHeightForWidth());
        ServerPortValue->setSizePolicy(sizePolicy);

        gridLayout->addWidget(ServerPortValue, 2, 1, 1, 1);

        ServerStatusLabel = new QLabel(OpenRGBServerInfoPage);
        ServerStatusLabel->setObjectName(QString::fromUtf8("ServerStatusLabel"));

        gridLayout->addWidget(ServerStatusLabel, 0, 0, 1, 1);

        ServerStartButton = new QPushButton(OpenRGBServerInfoPage);
        ServerStartButton->setObjectName(QString::fromUtf8("ServerStartButton"));

        gridLayout->addWidget(ServerStartButton, 0, 3, 1, 1);

        ServerStatusValue = new QLabel(OpenRGBServerInfoPage);
        ServerStatusValue->setObjectName(QString::fromUtf8("ServerStatusValue"));

        gridLayout->addWidget(ServerStatusValue, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        ServerHostLabel = new QLabel(OpenRGBServerInfoPage);
        ServerHostLabel->setObjectName(QString::fromUtf8("ServerHostLabel"));

        gridLayout->addWidget(ServerHostLabel, 1, 0, 1, 1);

        ServerHostValue = new QLineEdit(OpenRGBServerInfoPage);
        ServerHostValue->setObjectName(QString::fromUtf8("ServerHostValue"));
        sizePolicy.setHeightForWidth(ServerHostValue->sizePolicy().hasHeightForWidth());
        ServerHostValue->setSizePolicy(sizePolicy);

        gridLayout->addWidget(ServerHostValue, 1, 1, 1, 1);

        QWidget::setTabOrder(ServerPortValue, ServerStartButton);
        QWidget::setTabOrder(ServerStartButton, ServerStopButton);
        QWidget::setTabOrder(ServerStopButton, ServerClientTree);

        retranslateUi(OpenRGBServerInfoPage);

        QMetaObject::connectSlotsByName(OpenRGBServerInfoPage);
    } // setupUi

    void retranslateUi(QFrame *OpenRGBServerInfoPage)
    {
        ServerStopButton->setText(QCoreApplication::translate("OpenRGBServerInfoPage", "Stop Server", nullptr));
        ServerPortLabel->setText(QCoreApplication::translate("OpenRGBServerInfoPage", "Server Port:", nullptr));
        ServerClientsLabel->setText(QCoreApplication::translate("OpenRGBServerInfoPage", "Connected Clients:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = ServerClientTree->headerItem();
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("OpenRGBServerInfoPage", "Client Name", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("OpenRGBServerInfoPage", "Protocol Version", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("OpenRGBServerInfoPage", "Client IP", nullptr));
        ServerStatusLabel->setText(QCoreApplication::translate("OpenRGBServerInfoPage", "Server Status:", nullptr));
        ServerStartButton->setText(QCoreApplication::translate("OpenRGBServerInfoPage", "Start Server", nullptr));
        ServerStatusValue->setText(QCoreApplication::translate("OpenRGBServerInfoPage", "Offline", nullptr));
        ServerHostLabel->setText(QCoreApplication::translate("OpenRGBServerInfoPage", "Server Host:", nullptr));
        (void)OpenRGBServerInfoPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBServerInfoPage: public Ui_OpenRGBServerInfoPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBSERVERINFOPAGE_H
