/********************************************************************************
** Form generated from reading UI file 'OpenRGBConsolePage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBCONSOLEPAGE_H
#define UI_OPENRGBCONSOLEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextEdit>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBConsolePage
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *log_level;
    QPushButton *refresh;
    QPushButton *clear;
    QTextEdit *logs;

    void setupUi(QFrame *OpenRGBConsolePage)
    {
        if (OpenRGBConsolePage->objectName().isEmpty())
            OpenRGBConsolePage->setObjectName(QString::fromUtf8("OpenRGBConsolePage"));
        OpenRGBConsolePage->resize(1328, 915);
        OpenRGBConsolePage->setWindowTitle(QString::fromUtf8("Log Console Page"));
        gridLayout = new QGridLayout(OpenRGBConsolePage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(OpenRGBConsolePage);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 1, 0, 1, 1);

        log_level = new QComboBox(OpenRGBConsolePage);
        log_level->setObjectName(QString::fromUtf8("log_level"));

        gridLayout->addWidget(log_level, 1, 1, 1, 1);

        refresh = new QPushButton(OpenRGBConsolePage);
        refresh->setObjectName(QString::fromUtf8("refresh"));

        gridLayout->addWidget(refresh, 1, 2, 1, 1);

        clear = new QPushButton(OpenRGBConsolePage);
        clear->setObjectName(QString::fromUtf8("clear"));

        gridLayout->addWidget(clear, 1, 3, 1, 1);

        logs = new QTextEdit(OpenRGBConsolePage);
        logs->setObjectName(QString::fromUtf8("logs"));
        QFont font;
        font.setFamily(QString::fromUtf8("Monospace"));
        logs->setFont(font);

        gridLayout->addWidget(logs, 0, 0, 1, 4);


        retranslateUi(OpenRGBConsolePage);

        QMetaObject::connectSlotsByName(OpenRGBConsolePage);
    } // setupUi

    void retranslateUi(QFrame *OpenRGBConsolePage)
    {
        label->setText(QCoreApplication::translate("OpenRGBConsolePage", "Log level", nullptr));
        refresh->setText(QCoreApplication::translate("OpenRGBConsolePage", "Refresh logs", nullptr));
        clear->setText(QCoreApplication::translate("OpenRGBConsolePage", "Clear log", nullptr));
        (void)OpenRGBConsolePage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBConsolePage: public Ui_OpenRGBConsolePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBCONSOLEPAGE_H
