/********************************************************************************
** Form generated from reading UI file 'NanoleafScanDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NANOLEAFSCANDIALOG_H
#define UI_NANOLEAFSCANDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_NanoleafScanDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *SyncLabel;
    QListWidget *NanoleafDeviceList;
    QHBoxLayout *horizontalLayout;
    QPushButton *ScanForNanoleafDevicesButton;
    QPushButton *AddNanoleafDeviceButton;
    QPushButton *RemoveNanoleafDeviceButton;

    void setupUi(QDialog *NanoleafScanDialog)
    {
        if (NanoleafScanDialog->objectName().isEmpty())
            NanoleafScanDialog->setObjectName(QString::fromUtf8("NanoleafScanDialog"));
        NanoleafScanDialog->resize(400, 300);
        NanoleafScanDialog->setWindowTitle(QString::fromUtf8("Nanoleaf Scan Page"));
        verticalLayout = new QVBoxLayout(NanoleafScanDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        SyncLabel = new QLabel(NanoleafScanDialog);
        SyncLabel->setObjectName(QString::fromUtf8("SyncLabel"));
        SyncLabel->setAlignment(Qt::AlignCenter);
        SyncLabel->setWordWrap(true);

        verticalLayout->addWidget(SyncLabel);

        NanoleafDeviceList = new QListWidget(NanoleafScanDialog);
        NanoleafDeviceList->setObjectName(QString::fromUtf8("NanoleafDeviceList"));
        NanoleafDeviceList->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        verticalLayout->addWidget(NanoleafDeviceList);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        ScanForNanoleafDevicesButton = new QPushButton(NanoleafScanDialog);
        ScanForNanoleafDevicesButton->setObjectName(QString::fromUtf8("ScanForNanoleafDevicesButton"));

        horizontalLayout->addWidget(ScanForNanoleafDevicesButton);

        AddNanoleafDeviceButton = new QPushButton(NanoleafScanDialog);
        AddNanoleafDeviceButton->setObjectName(QString::fromUtf8("AddNanoleafDeviceButton"));

        horizontalLayout->addWidget(AddNanoleafDeviceButton);

        RemoveNanoleafDeviceButton = new QPushButton(NanoleafScanDialog);
        RemoveNanoleafDeviceButton->setObjectName(QString::fromUtf8("RemoveNanoleafDeviceButton"));

        horizontalLayout->addWidget(RemoveNanoleafDeviceButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(NanoleafScanDialog);

        QMetaObject::connectSlotsByName(NanoleafScanDialog);
    } // setupUi

    void retranslateUi(QDialog *NanoleafScanDialog)
    {
        SyncLabel->setText(QCoreApplication::translate("NanoleafScanDialog", "To pair, hold the on-off button down for 5-7 seconds until the LED starts flashing in a pattern, a new entry should appear in the list below, then click the \"Pair\" button on the entry within 30 seconds.", nullptr));
        ScanForNanoleafDevicesButton->setText(QCoreApplication::translate("NanoleafScanDialog", "Scan", nullptr));
        AddNanoleafDeviceButton->setText(QCoreApplication::translate("NanoleafScanDialog", "Add manually", nullptr));
        RemoveNanoleafDeviceButton->setText(QCoreApplication::translate("NanoleafScanDialog", "Remove", nullptr));
        (void)NanoleafScanDialog;
    } // retranslateUi

};

namespace Ui {
    class NanoleafScanDialog: public Ui_NanoleafScanDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NANOLEAFSCANDIALOG_H
