/********************************************************************************
** Form generated from reading UI file 'YeelightSettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_YEELIGHTSETTINGSENTRY_H
#define UI_YEELIGHTSETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_YeelightSettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *MusicModeCheckBox;
    QLabel *IPLabel;
    QLineEdit *HostIPEdit;
    QToolButton *HostIPChooserButton;
    QLabel *MusicModeLabel;
    QLabel *label;
    QLineEdit *IPEdit;
    QLabel *label_2;

    void setupUi(QWidget *YeelightSettingsEntry)
    {
        if (YeelightSettingsEntry->objectName().isEmpty())
            YeelightSettingsEntry->setObjectName(QString::fromUtf8("YeelightSettingsEntry"));
        YeelightSettingsEntry->resize(972, 385);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(YeelightSettingsEntry->sizePolicy().hasHeightForWidth());
        YeelightSettingsEntry->setSizePolicy(sizePolicy);
        YeelightSettingsEntry->setWindowTitle(QString::fromUtf8("Yeelight Settings Entry"));
        gridLayout = new QGridLayout(YeelightSettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(YeelightSettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        MusicModeCheckBox = new QCheckBox(groupBox);
        MusicModeCheckBox->setObjectName(QString::fromUtf8("MusicModeCheckBox"));

        gridLayout_2->addWidget(MusicModeCheckBox, 2, 1, 1, 1);

        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 1, 0, 1, 1);

        HostIPEdit = new QLineEdit(groupBox);
        HostIPEdit->setObjectName(QString::fromUtf8("HostIPEdit"));

        gridLayout_2->addWidget(HostIPEdit, 5, 1, 1, 1);

        HostIPChooserButton = new QToolButton(groupBox);
        HostIPChooserButton->setObjectName(QString::fromUtf8("HostIPChooserButton"));

        gridLayout_2->addWidget(HostIPChooserButton, 5, 2, 1, 1);

        MusicModeLabel = new QLabel(groupBox);
        MusicModeLabel->setObjectName(QString::fromUtf8("MusicModeLabel"));

        gridLayout_2->addWidget(MusicModeLabel, 2, 0, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_2->addWidget(label, 5, 0, 1, 1);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 1, 1, 1, 2);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout_2->addWidget(label_2, 6, 1, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(YeelightSettingsEntry);

        QMetaObject::connectSlotsByName(YeelightSettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *YeelightSettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("YeelightSettingsEntry", "Yeelight Device", nullptr));
        MusicModeCheckBox->setText(QString());
        IPLabel->setText(QCoreApplication::translate("YeelightSettingsEntry", "IP:", nullptr));
        HostIPChooserButton->setText(QCoreApplication::translate("YeelightSettingsEntry", "?", nullptr));
        MusicModeLabel->setText(QCoreApplication::translate("YeelightSettingsEntry", "Music Mode:", nullptr));
        label->setText(QCoreApplication::translate("YeelightSettingsEntry", "Override host IP:", nullptr));
        label_2->setText(QCoreApplication::translate("YeelightSettingsEntry", "Left blank for auto discovering host ip", nullptr));
        (void)YeelightSettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class YeelightSettingsEntry: public Ui_YeelightSettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_YEELIGHTSETTINGSENTRY_H
