/********************************************************************************
** Form generated from reading UI file 'E131SettingsEntry.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_E131SETTINGSENTRY_H
#define UI_E131SETTINGSENTRY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_E131SettingsEntry
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLineEdit *StartChannelEdit;
    QLineEdit *NumLEDsEdit;
    QLineEdit *MatrixWidthEdit;
    QLabel *StartChannelLabel;
    QLabel *NumLEDsLabel;
    QLineEdit *StartUniverseEdit;
    QLineEdit *NameEdit;
    QComboBox *MatrixOrderComboBox;
    QLabel *StartUniverseLabel;
    QLineEdit *IPEdit;
    QLabel *NameLabel;
    QLabel *MatrixOrderLabel;
    QComboBox *TypeComboBox;
    QLineEdit *MatrixHeightEdit;
    QLabel *MatrixHeightLabel;
    QLabel *MatrixWidthLabel;
    QLabel *TypeLabel;
    QLabel *IPLabel;
    QLabel *UniverseSizeLabel;
    QLineEdit *UniverseSizeEdit;
    QLabel *KeepaliveTimeLabel;
    QLineEdit *KeepaliveTimeEdit;
    QLabel *RGBOrderLabel;
    QComboBox *RGBOrderComboBox;

    void setupUi(QWidget *E131SettingsEntry)
    {
        if (E131SettingsEntry->objectName().isEmpty())
            E131SettingsEntry->setObjectName(QString::fromUtf8("E131SettingsEntry"));
        E131SettingsEntry->resize(531, 256);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(E131SettingsEntry->sizePolicy().hasHeightForWidth());
        E131SettingsEntry->setSizePolicy(sizePolicy);
        E131SettingsEntry->setWindowTitle(QString::fromUtf8("E.131 Settings Entry"));
        gridLayout = new QGridLayout(E131SettingsEntry);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox = new QGroupBox(E131SettingsEntry);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        StartChannelEdit = new QLineEdit(groupBox);
        StartChannelEdit->setObjectName(QString::fromUtf8("StartChannelEdit"));

        gridLayout_2->addWidget(StartChannelEdit, 2, 5, 1, 1);

        NumLEDsEdit = new QLineEdit(groupBox);
        NumLEDsEdit->setObjectName(QString::fromUtf8("NumLEDsEdit"));

        gridLayout_2->addWidget(NumLEDsEdit, 5, 3, 1, 1);

        MatrixWidthEdit = new QLineEdit(groupBox);
        MatrixWidthEdit->setObjectName(QString::fromUtf8("MatrixWidthEdit"));

        gridLayout_2->addWidget(MatrixWidthEdit, 6, 3, 1, 1);

        StartChannelLabel = new QLabel(groupBox);
        StartChannelLabel->setObjectName(QString::fromUtf8("StartChannelLabel"));

        gridLayout_2->addWidget(StartChannelLabel, 2, 4, 1, 1);

        NumLEDsLabel = new QLabel(groupBox);
        NumLEDsLabel->setObjectName(QString::fromUtf8("NumLEDsLabel"));

        gridLayout_2->addWidget(NumLEDsLabel, 5, 0, 1, 1);

        StartUniverseEdit = new QLineEdit(groupBox);
        StartUniverseEdit->setObjectName(QString::fromUtf8("StartUniverseEdit"));

        gridLayout_2->addWidget(StartUniverseEdit, 2, 3, 1, 1);

        NameEdit = new QLineEdit(groupBox);
        NameEdit->setObjectName(QString::fromUtf8("NameEdit"));

        gridLayout_2->addWidget(NameEdit, 1, 3, 1, 1);

        MatrixOrderComboBox = new QComboBox(groupBox);
        MatrixOrderComboBox->setObjectName(QString::fromUtf8("MatrixOrderComboBox"));

        gridLayout_2->addWidget(MatrixOrderComboBox, 7, 3, 1, 1);

        StartUniverseLabel = new QLabel(groupBox);
        StartUniverseLabel->setObjectName(QString::fromUtf8("StartUniverseLabel"));

        gridLayout_2->addWidget(StartUniverseLabel, 2, 0, 1, 1);

        IPEdit = new QLineEdit(groupBox);
        IPEdit->setObjectName(QString::fromUtf8("IPEdit"));

        gridLayout_2->addWidget(IPEdit, 1, 5, 1, 1);

        NameLabel = new QLabel(groupBox);
        NameLabel->setObjectName(QString::fromUtf8("NameLabel"));

        gridLayout_2->addWidget(NameLabel, 1, 0, 1, 1);

        MatrixOrderLabel = new QLabel(groupBox);
        MatrixOrderLabel->setObjectName(QString::fromUtf8("MatrixOrderLabel"));

        gridLayout_2->addWidget(MatrixOrderLabel, 7, 0, 1, 1);

        TypeComboBox = new QComboBox(groupBox);
        TypeComboBox->setObjectName(QString::fromUtf8("TypeComboBox"));

        gridLayout_2->addWidget(TypeComboBox, 5, 5, 1, 1);

        MatrixHeightEdit = new QLineEdit(groupBox);
        MatrixHeightEdit->setObjectName(QString::fromUtf8("MatrixHeightEdit"));

        gridLayout_2->addWidget(MatrixHeightEdit, 6, 5, 1, 1);

        MatrixHeightLabel = new QLabel(groupBox);
        MatrixHeightLabel->setObjectName(QString::fromUtf8("MatrixHeightLabel"));

        gridLayout_2->addWidget(MatrixHeightLabel, 6, 4, 1, 1);

        MatrixWidthLabel = new QLabel(groupBox);
        MatrixWidthLabel->setObjectName(QString::fromUtf8("MatrixWidthLabel"));

        gridLayout_2->addWidget(MatrixWidthLabel, 6, 0, 1, 1);

        TypeLabel = new QLabel(groupBox);
        TypeLabel->setObjectName(QString::fromUtf8("TypeLabel"));

        gridLayout_2->addWidget(TypeLabel, 5, 4, 1, 1);

        IPLabel = new QLabel(groupBox);
        IPLabel->setObjectName(QString::fromUtf8("IPLabel"));

        gridLayout_2->addWidget(IPLabel, 1, 4, 1, 1);

        UniverseSizeLabel = new QLabel(groupBox);
        UniverseSizeLabel->setObjectName(QString::fromUtf8("UniverseSizeLabel"));

        gridLayout_2->addWidget(UniverseSizeLabel, 8, 0, 1, 1);

        UniverseSizeEdit = new QLineEdit(groupBox);
        UniverseSizeEdit->setObjectName(QString::fromUtf8("UniverseSizeEdit"));

        gridLayout_2->addWidget(UniverseSizeEdit, 8, 3, 1, 1);

        KeepaliveTimeLabel = new QLabel(groupBox);
        KeepaliveTimeLabel->setObjectName(QString::fromUtf8("KeepaliveTimeLabel"));

        gridLayout_2->addWidget(KeepaliveTimeLabel, 8, 4, 1, 1);

        KeepaliveTimeEdit = new QLineEdit(groupBox);
        KeepaliveTimeEdit->setObjectName(QString::fromUtf8("KeepaliveTimeEdit"));

        gridLayout_2->addWidget(KeepaliveTimeEdit, 8, 5, 1, 1);

        RGBOrderLabel = new QLabel(groupBox);
        RGBOrderLabel->setObjectName(QString::fromUtf8("RGBOrderLabel"));

        gridLayout_2->addWidget(RGBOrderLabel, 7, 4, 1, 1);

        RGBOrderComboBox = new QComboBox(groupBox);
        RGBOrderComboBox->setObjectName(QString::fromUtf8("RGBOrderComboBox"));

        gridLayout_2->addWidget(RGBOrderComboBox, 7, 5, 1, 1);


        gridLayout->addWidget(groupBox, 1, 0, 1, 2);

        QWidget::setTabOrder(NameEdit, IPEdit);
        QWidget::setTabOrder(IPEdit, StartUniverseEdit);
        QWidget::setTabOrder(StartUniverseEdit, StartChannelEdit);
        QWidget::setTabOrder(StartChannelEdit, NumLEDsEdit);
        QWidget::setTabOrder(NumLEDsEdit, TypeComboBox);
        QWidget::setTabOrder(TypeComboBox, MatrixWidthEdit);
        QWidget::setTabOrder(MatrixWidthEdit, MatrixHeightEdit);
        QWidget::setTabOrder(MatrixHeightEdit, MatrixOrderComboBox);
        QWidget::setTabOrder(MatrixOrderComboBox, UniverseSizeEdit);
        QWidget::setTabOrder(UniverseSizeEdit, KeepaliveTimeEdit);

        retranslateUi(E131SettingsEntry);

        QMetaObject::connectSlotsByName(E131SettingsEntry);
    } // setupUi

    void retranslateUi(QWidget *E131SettingsEntry)
    {
        groupBox->setTitle(QCoreApplication::translate("E131SettingsEntry", "E1.31 Device", nullptr));
        StartChannelLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Start Channel:", nullptr));
        NumLEDsLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Number of LEDs:", nullptr));
        StartUniverseLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Start Universe:", nullptr));
        NameLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Name:", nullptr));
        MatrixOrderLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Matrix Order:", nullptr));
        MatrixHeightLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Matrix Height:", nullptr));
        MatrixWidthLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Matrix Width:", nullptr));
        TypeLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Type:", nullptr));
        IPLabel->setText(QCoreApplication::translate("E131SettingsEntry", "IP (Unicast):", nullptr));
        UniverseSizeLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Universe Size:", nullptr));
        KeepaliveTimeLabel->setText(QCoreApplication::translate("E131SettingsEntry", "Keepalive Time:", nullptr));
        RGBOrderLabel->setText(QCoreApplication::translate("E131SettingsEntry", "RGB Order:", nullptr));
        (void)E131SettingsEntry;
    } // retranslateUi

};

namespace Ui {
    class E131SettingsEntry: public Ui_E131SettingsEntry {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_E131SETTINGSENTRY_H
