/********************************************************************************
** Form generated from reading UI file 'OpenRGBDevicePage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBDEVICEPAGE_H
#define UI_OPENRGBDEVICEPAGE_H

#include <ColorWheel.h>
#include <DeviceView.h>
#include <QTooltipedSlider.h>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <swatches.h>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBDevicePage
{
public:
    QGridLayout *OpenRGBDevicePageUiGridLayout;
    QFrame *ColorFrame;
    QGridLayout *ColorGridLayout;
    QFrame *ColorEntryFrame;
    QGridLayout *ColorEntryGridLayout;
    QLabel *RedLabel;
    QSpinBox *RedSpinBox;
    QLabel *HueLabel;
    QSpinBox *HueSpinBox;
    QLabel *GreenLabel;
    QSpinBox *GreenSpinBox;
    QLabel *SatLabel;
    QSpinBox *SatSpinBox;
    QLabel *BlueLabel;
    QSpinBox *BlueSpinBox;
    QLabel *ValLabel;
    QSpinBox *ValSpinBox;
    QLabel *HexLabel;
    QLineEdit *HexLineEdit;
    ColorWheel *ColorWheelBox;
    Swatches *SwatchBox;
    QPushButton *DeviceSaveButton;
    QFrame *ControlsFrame;
    QGridLayout *ControlsGridLayout;
    QLabel *SpeedLabel;
    QComboBox *LEDBox;
    QComboBox *ZoneBox;
    QRadioButton *RandomCheck;
    QLabel *ModeLabel;
    QLabel *DirectionLabel;
    QTooltipedSlider *SpeedSlider;
    QLabel *ColorLabel;
    QRadioButton *PerLEDCheck;
    QLabel *ZoneLabel;
    QComboBox *ModeBox;
    QPushButton *SetAllButton;
    QLabel *LEDLabel;
    QPushButton *EditZoneButton;
    QRadioButton *ModeSpecificCheck;
    QPushButton *ApplyColorsButton;
    QPushButton *SelectAllLEDsButton;
    QTooltipedSlider *BrightnessSlider;
    QComboBox *DirectionBox;
    QLabel *BrightnessLabel;
    QFrame *DeviceViewBoxFrame;
    QGridLayout *DeviceViewBoxGridLayout;
    DeviceView *DeviceViewBox;

    void setupUi(QFrame *OpenRGBDevicePage)
    {
        if (OpenRGBDevicePage->objectName().isEmpty())
            OpenRGBDevicePage->setObjectName(QString::fromUtf8("OpenRGBDevicePage"));
        OpenRGBDevicePage->resize(843, 374);
        OpenRGBDevicePage->setWindowTitle(QString::fromUtf8("Device Page"));
        OpenRGBDevicePageUiGridLayout = new QGridLayout(OpenRGBDevicePage);
        OpenRGBDevicePageUiGridLayout->setObjectName(QString::fromUtf8("OpenRGBDevicePageUiGridLayout"));
        ColorFrame = new QFrame(OpenRGBDevicePage);
        ColorFrame->setObjectName(QString::fromUtf8("ColorFrame"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ColorFrame->sizePolicy().hasHeightForWidth());
        ColorFrame->setSizePolicy(sizePolicy);
        ColorFrame->setAutoFillBackground(true);
        ColorFrame->setFrameShape(QFrame::Shape::StyledPanel);
        ColorFrame->setFrameShadow(QFrame::Shadow::Sunken);
        ColorGridLayout = new QGridLayout(ColorFrame);
        ColorGridLayout->setObjectName(QString::fromUtf8("ColorGridLayout"));
        ColorEntryFrame = new QFrame(ColorFrame);
        ColorEntryFrame->setObjectName(QString::fromUtf8("ColorEntryFrame"));
        ColorEntryFrame->setFrameShape(QFrame::Shape::NoFrame);
        ColorEntryFrame->setFrameShadow(QFrame::Shadow::Raised);
        ColorEntryGridLayout = new QGridLayout(ColorEntryFrame);
        ColorEntryGridLayout->setObjectName(QString::fromUtf8("ColorEntryGridLayout"));
        ColorEntryGridLayout->setContentsMargins(0, 0, 0, 0);
        RedLabel = new QLabel(ColorEntryFrame);
        RedLabel->setObjectName(QString::fromUtf8("RedLabel"));

        ColorEntryGridLayout->addWidget(RedLabel, 0, 0, 1, 1);

        RedSpinBox = new QSpinBox(ColorEntryFrame);
        RedSpinBox->setObjectName(QString::fromUtf8("RedSpinBox"));
        RedSpinBox->setMaximum(255);

        ColorEntryGridLayout->addWidget(RedSpinBox, 0, 1, 1, 1);

        HueLabel = new QLabel(ColorEntryFrame);
        HueLabel->setObjectName(QString::fromUtf8("HueLabel"));

        ColorEntryGridLayout->addWidget(HueLabel, 0, 2, 1, 1);

        HueSpinBox = new QSpinBox(ColorEntryFrame);
        HueSpinBox->setObjectName(QString::fromUtf8("HueSpinBox"));
        HueSpinBox->setMaximum(359);

        ColorEntryGridLayout->addWidget(HueSpinBox, 0, 3, 1, 1);

        GreenLabel = new QLabel(ColorEntryFrame);
        GreenLabel->setObjectName(QString::fromUtf8("GreenLabel"));

        ColorEntryGridLayout->addWidget(GreenLabel, 1, 0, 1, 1);

        GreenSpinBox = new QSpinBox(ColorEntryFrame);
        GreenSpinBox->setObjectName(QString::fromUtf8("GreenSpinBox"));
        GreenSpinBox->setMaximum(255);

        ColorEntryGridLayout->addWidget(GreenSpinBox, 1, 1, 1, 1);

        SatLabel = new QLabel(ColorEntryFrame);
        SatLabel->setObjectName(QString::fromUtf8("SatLabel"));

        ColorEntryGridLayout->addWidget(SatLabel, 1, 2, 1, 1);

        SatSpinBox = new QSpinBox(ColorEntryFrame);
        SatSpinBox->setObjectName(QString::fromUtf8("SatSpinBox"));
        SatSpinBox->setMaximum(255);

        ColorEntryGridLayout->addWidget(SatSpinBox, 1, 3, 1, 1);

        BlueLabel = new QLabel(ColorEntryFrame);
        BlueLabel->setObjectName(QString::fromUtf8("BlueLabel"));

        ColorEntryGridLayout->addWidget(BlueLabel, 2, 0, 1, 1);

        BlueSpinBox = new QSpinBox(ColorEntryFrame);
        BlueSpinBox->setObjectName(QString::fromUtf8("BlueSpinBox"));
        BlueSpinBox->setMaximum(255);

        ColorEntryGridLayout->addWidget(BlueSpinBox, 2, 1, 1, 1);

        ValLabel = new QLabel(ColorEntryFrame);
        ValLabel->setObjectName(QString::fromUtf8("ValLabel"));

        ColorEntryGridLayout->addWidget(ValLabel, 2, 2, 1, 1);

        ValSpinBox = new QSpinBox(ColorEntryFrame);
        ValSpinBox->setObjectName(QString::fromUtf8("ValSpinBox"));
        ValSpinBox->setMaximum(255);

        ColorEntryGridLayout->addWidget(ValSpinBox, 2, 3, 1, 1);

        HexLabel = new QLabel(ColorEntryFrame);
        HexLabel->setObjectName(QString::fromUtf8("HexLabel"));

        ColorEntryGridLayout->addWidget(HexLabel, 3, 0, 1, 1);

        HexLineEdit = new QLineEdit(ColorEntryFrame);
        HexLineEdit->setObjectName(QString::fromUtf8("HexLineEdit"));
        HexLineEdit->setMaxLength(8);

        ColorEntryGridLayout->addWidget(HexLineEdit, 3, 1, 1, 3);

        ColorEntryGridLayout->setColumnStretch(1, 1);
        ColorEntryGridLayout->setColumnStretch(3, 1);

        ColorGridLayout->addWidget(ColorEntryFrame, 2, 0, 1, 1);

        ColorWheelBox = new ColorWheel(ColorFrame);
        ColorWheelBox->setObjectName(QString::fromUtf8("ColorWheelBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ColorWheelBox->sizePolicy().hasHeightForWidth());
        ColorWheelBox->setSizePolicy(sizePolicy1);

        ColorGridLayout->addWidget(ColorWheelBox, 0, 0, 1, 1);

        SwatchBox = new Swatches(ColorFrame);
        SwatchBox->setObjectName(QString::fromUtf8("SwatchBox"));
        sizePolicy1.setHeightForWidth(SwatchBox->sizePolicy().hasHeightForWidth());
        SwatchBox->setSizePolicy(sizePolicy1);
        SwatchBox->setStyleSheet(QString::fromUtf8(""));

        ColorGridLayout->addWidget(SwatchBox, 1, 0, 1, 1);

        DeviceSaveButton = new QPushButton(ColorFrame);
        DeviceSaveButton->setObjectName(QString::fromUtf8("DeviceSaveButton"));

        ColorGridLayout->addWidget(DeviceSaveButton, 3, 0, 1, 1);

        ColorGridLayout->setRowStretch(0, 10);

        OpenRGBDevicePageUiGridLayout->addWidget(ColorFrame, 1, 1, 1, 1);

        ControlsFrame = new QFrame(OpenRGBDevicePage);
        ControlsFrame->setObjectName(QString::fromUtf8("ControlsFrame"));
        sizePolicy.setHeightForWidth(ControlsFrame->sizePolicy().hasHeightForWidth());
        ControlsFrame->setSizePolicy(sizePolicy);
        ControlsFrame->setAutoFillBackground(true);
        ControlsFrame->setFrameShape(QFrame::Shape::StyledPanel);
        ControlsFrame->setFrameShadow(QFrame::Shadow::Sunken);
        ControlsGridLayout = new QGridLayout(ControlsFrame);
        ControlsGridLayout->setObjectName(QString::fromUtf8("ControlsGridLayout"));
        SpeedLabel = new QLabel(ControlsFrame);
        SpeedLabel->setObjectName(QString::fromUtf8("SpeedLabel"));

        ControlsGridLayout->addWidget(SpeedLabel, 5, 0, 1, 1);

        LEDBox = new QComboBox(ControlsFrame);
        LEDBox->setObjectName(QString::fromUtf8("LEDBox"));

        ControlsGridLayout->addWidget(LEDBox, 1, 1, 1, 2);

        ZoneBox = new QComboBox(ControlsFrame);
        ZoneBox->setObjectName(QString::fromUtf8("ZoneBox"));

        ControlsGridLayout->addWidget(ZoneBox, 0, 1, 1, 2);

        RandomCheck = new QRadioButton(ControlsFrame);
        RandomCheck->setObjectName(QString::fromUtf8("RandomCheck"));

        ControlsGridLayout->addWidget(RandomCheck, 4, 3, 1, 1);

        ModeLabel = new QLabel(ControlsFrame);
        ModeLabel->setObjectName(QString::fromUtf8("ModeLabel"));

        ControlsGridLayout->addWidget(ModeLabel, 3, 0, 1, 1);

        DirectionLabel = new QLabel(ControlsFrame);
        DirectionLabel->setObjectName(QString::fromUtf8("DirectionLabel"));

        ControlsGridLayout->addWidget(DirectionLabel, 6, 0, 1, 1);

        SpeedSlider = new QTooltipedSlider(ControlsFrame);
        SpeedSlider->setObjectName(QString::fromUtf8("SpeedSlider"));
        SpeedSlider->setOrientation(Qt::Orientation::Horizontal);

        ControlsGridLayout->addWidget(SpeedSlider, 5, 1, 1, 3);

        ColorLabel = new QLabel(ControlsFrame);
        ColorLabel->setObjectName(QString::fromUtf8("ColorLabel"));

        ControlsGridLayout->addWidget(ColorLabel, 4, 0, 1, 1);

        PerLEDCheck = new QRadioButton(ControlsFrame);
        PerLEDCheck->setObjectName(QString::fromUtf8("PerLEDCheck"));

        ControlsGridLayout->addWidget(PerLEDCheck, 4, 1, 1, 1);

        ZoneLabel = new QLabel(ControlsFrame);
        ZoneLabel->setObjectName(QString::fromUtf8("ZoneLabel"));

        ControlsGridLayout->addWidget(ZoneLabel, 0, 0, 1, 1);

        ModeBox = new QComboBox(ControlsFrame);
        ModeBox->setObjectName(QString::fromUtf8("ModeBox"));

        ControlsGridLayout->addWidget(ModeBox, 3, 1, 1, 3);

        SetAllButton = new QPushButton(ControlsFrame);
        SetAllButton->setObjectName(QString::fromUtf8("SetAllButton"));

        ControlsGridLayout->addWidget(SetAllButton, 2, 3, 1, 1);

        LEDLabel = new QLabel(ControlsFrame);
        LEDLabel->setObjectName(QString::fromUtf8("LEDLabel"));

        ControlsGridLayout->addWidget(LEDLabel, 1, 0, 1, 1);

        EditZoneButton = new QPushButton(ControlsFrame);
        EditZoneButton->setObjectName(QString::fromUtf8("EditZoneButton"));

        ControlsGridLayout->addWidget(EditZoneButton, 0, 3, 1, 1);

        ModeSpecificCheck = new QRadioButton(ControlsFrame);
        ModeSpecificCheck->setObjectName(QString::fromUtf8("ModeSpecificCheck"));

        ControlsGridLayout->addWidget(ModeSpecificCheck, 4, 2, 1, 1);

        ApplyColorsButton = new QPushButton(ControlsFrame);
        ApplyColorsButton->setObjectName(QString::fromUtf8("ApplyColorsButton"));

        ControlsGridLayout->addWidget(ApplyColorsButton, 2, 1, 1, 2);

        SelectAllLEDsButton = new QPushButton(ControlsFrame);
        SelectAllLEDsButton->setObjectName(QString::fromUtf8("SelectAllLEDsButton"));

        ControlsGridLayout->addWidget(SelectAllLEDsButton, 1, 3, 1, 1);

        BrightnessSlider = new QTooltipedSlider(ControlsFrame);
        BrightnessSlider->setObjectName(QString::fromUtf8("BrightnessSlider"));
        BrightnessSlider->setOrientation(Qt::Orientation::Horizontal);

        ControlsGridLayout->addWidget(BrightnessSlider, 7, 1, 1, 3);

        DirectionBox = new QComboBox(ControlsFrame);
        DirectionBox->setObjectName(QString::fromUtf8("DirectionBox"));

        ControlsGridLayout->addWidget(DirectionBox, 6, 1, 1, 3);

        BrightnessLabel = new QLabel(ControlsFrame);
        BrightnessLabel->setObjectName(QString::fromUtf8("BrightnessLabel"));

        ControlsGridLayout->addWidget(BrightnessLabel, 7, 0, 1, 1);

        ControlsGridLayout->setColumnStretch(1, 1);
        ControlsGridLayout->setColumnStretch(2, 1);
        ControlsGridLayout->setColumnStretch(3, 1);

        OpenRGBDevicePageUiGridLayout->addWidget(ControlsFrame, 1, 0, 1, 1);

        DeviceViewBoxFrame = new QFrame(OpenRGBDevicePage);
        DeviceViewBoxFrame->setObjectName(QString::fromUtf8("DeviceViewBoxFrame"));
        sizePolicy1.setHeightForWidth(DeviceViewBoxFrame->sizePolicy().hasHeightForWidth());
        DeviceViewBoxFrame->setSizePolicy(sizePolicy1);
        DeviceViewBoxFrame->setMinimumSize(QSize(0, 0));
        DeviceViewBoxFrame->setAutoFillBackground(true);
        DeviceViewBoxFrame->setFrameShape(QFrame::Shape::StyledPanel);
        DeviceViewBoxFrame->setFrameShadow(QFrame::Shadow::Sunken);
        DeviceViewBoxGridLayout = new QGridLayout(DeviceViewBoxFrame);
        DeviceViewBoxGridLayout->setObjectName(QString::fromUtf8("DeviceViewBoxGridLayout"));
        DeviceViewBox = new DeviceView(DeviceViewBoxFrame);
        DeviceViewBox->setObjectName(QString::fromUtf8("DeviceViewBox"));
        sizePolicy.setHeightForWidth(DeviceViewBox->sizePolicy().hasHeightForWidth());
        DeviceViewBox->setSizePolicy(sizePolicy);
        DeviceViewBox->setMinimumSize(QSize(0, 0));

        DeviceViewBoxGridLayout->addWidget(DeviceViewBox, 0, 0, 1, 1);


        OpenRGBDevicePageUiGridLayout->addWidget(DeviceViewBoxFrame, 0, 0, 1, 2);

        OpenRGBDevicePageUiGridLayout->setColumnStretch(0, 3);
        OpenRGBDevicePageUiGridLayout->setColumnStretch(1, 1);
        QWidget::setTabOrder(ZoneBox, EditZoneButton);
        QWidget::setTabOrder(EditZoneButton, LEDBox);
        QWidget::setTabOrder(LEDBox, SelectAllLEDsButton);
        QWidget::setTabOrder(SelectAllLEDsButton, ApplyColorsButton);
        QWidget::setTabOrder(ApplyColorsButton, SetAllButton);
        QWidget::setTabOrder(SetAllButton, ModeBox);
        QWidget::setTabOrder(ModeBox, PerLEDCheck);
        QWidget::setTabOrder(PerLEDCheck, ModeSpecificCheck);
        QWidget::setTabOrder(ModeSpecificCheck, RandomCheck);
        QWidget::setTabOrder(RandomCheck, SpeedSlider);
        QWidget::setTabOrder(SpeedSlider, DirectionBox);
        QWidget::setTabOrder(DirectionBox, BrightnessSlider);
        QWidget::setTabOrder(BrightnessSlider, RedSpinBox);
        QWidget::setTabOrder(RedSpinBox, GreenSpinBox);
        QWidget::setTabOrder(GreenSpinBox, BlueSpinBox);
        QWidget::setTabOrder(BlueSpinBox, HueSpinBox);
        QWidget::setTabOrder(HueSpinBox, SatSpinBox);
        QWidget::setTabOrder(SatSpinBox, ValSpinBox);
        QWidget::setTabOrder(ValSpinBox, DeviceSaveButton);

        retranslateUi(OpenRGBDevicePage);

        QMetaObject::connectSlotsByName(OpenRGBDevicePage);
    } // setupUi

    void retranslateUi(QFrame *OpenRGBDevicePage)
    {
        RedLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "R:", nullptr));
        HueLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "H:", nullptr));
        GreenLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "G:", nullptr));
        SatLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "S:", nullptr));
        BlueLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "B:", nullptr));
        ValLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "V:", nullptr));
        HexLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "Hex:", nullptr));
        DeviceSaveButton->setText(QCoreApplication::translate("OpenRGBDevicePage", "Save To Device", nullptr));
        SpeedLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "Speed:", nullptr));
        RandomCheck->setText(QCoreApplication::translate("OpenRGBDevicePage", "Random", nullptr));
        ModeLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "Mode:", nullptr));
        DirectionLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "Dir:", nullptr));
        ColorLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "Colors:", nullptr));
        PerLEDCheck->setText(QCoreApplication::translate("OpenRGBDevicePage", "Per-LED", nullptr));
        ZoneLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "Zone:", nullptr));
#if QT_CONFIG(tooltip)
        SetAllButton->setToolTip(QCoreApplication::translate("OpenRGBDevicePage", "<html><head/><body><p align=\"justify\">Sets all devices to<br/><b>Static</b> mode and<br/>applies the selected color.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        SetAllButton->setText(QCoreApplication::translate("OpenRGBDevicePage", "Apply All Devices", nullptr));
        LEDLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "LED:", nullptr));
        EditZoneButton->setText(QCoreApplication::translate("OpenRGBDevicePage", "Edit", nullptr));
        ModeSpecificCheck->setText(QCoreApplication::translate("OpenRGBDevicePage", "Mode-Specific", nullptr));
        ApplyColorsButton->setText(QCoreApplication::translate("OpenRGBDevicePage", "Apply Colors To Selection", nullptr));
        SelectAllLEDsButton->setText(QCoreApplication::translate("OpenRGBDevicePage", "Select All", nullptr));
        BrightnessLabel->setText(QCoreApplication::translate("OpenRGBDevicePage", "Brightness:", nullptr));
        (void)OpenRGBDevicePage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBDevicePage: public Ui_OpenRGBDevicePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBDEVICEPAGE_H
