/********************************************************************************
** Form generated from reading UI file 'OpenRGBSoftwareInfoPage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENRGBSOFTWAREINFOPAGE_H
#define UI_OPENRGBSOFTWAREINFOPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_OpenRGBSoftwareInfoPage
{
public:
    QGridLayout *gridLayout;
    QFrame *SoftwareInfoFrame;
    QGridLayout *gridLayout_2;
    QLabel *BuildDateValue;
    QLabel *GitCommitDateValue;
    QLabel *GitlabLinkValue;
    QLabel *SDKVersionLabel;
    QSpacerItem *verticalSpacer;
    QLabel *WebsiteLinkLabel;
    QLabel *BuildDateLabel;
    QLabel *GitCommitIDLabel;
    QLabel *GitCommitDateLabel;
    QLabel *QtVersionValue;
    QLabel *GitlabLinkLabel;
    QLabel *GitBranchValue;
    QLabel *WebsiteLinkValue;
    QLabel *PluginAPIVersionValue;
    QLabel *GitCommitIDValue;
    QLabel *PluginAPIVersionLabel;
    QLabel *GitBranchLabel;
    QLabel *SDKVersionValue;
    QLabel *QtVersionLabel;
    QLabel *OsVersionLabel;
    QLabel *OsVersionValue;
    QGridLayout *gridLayout_3;
    QLabel *VersionLabel;
    QLabel *LicenseValue;
    QLabel *VersionValue;
    QLabel *LicenseLabel;
    QLabel *IconLabel;
    QLabel *CopyrightLabel;
    QLabel *CopyrightValue;
    QSpacerItem *horizontalSpacer;
    QLabel *ProjectDescriptionLabel;

    void setupUi(QFrame *OpenRGBSoftwareInfoPage)
    {
        if (OpenRGBSoftwareInfoPage->objectName().isEmpty())
            OpenRGBSoftwareInfoPage->setObjectName(QString::fromUtf8("OpenRGBSoftwareInfoPage"));
        OpenRGBSoftwareInfoPage->resize(502, 434);
        OpenRGBSoftwareInfoPage->setWindowTitle(QString::fromUtf8("Software Info Page"));
        OpenRGBSoftwareInfoPage->setAutoFillBackground(false);
        OpenRGBSoftwareInfoPage->setFrameShape(QFrame::NoFrame);
        OpenRGBSoftwareInfoPage->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(OpenRGBSoftwareInfoPage);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        SoftwareInfoFrame = new QFrame(OpenRGBSoftwareInfoPage);
        SoftwareInfoFrame->setObjectName(QString::fromUtf8("SoftwareInfoFrame"));
        SoftwareInfoFrame->setAutoFillBackground(true);
        SoftwareInfoFrame->setFrameShape(QFrame::StyledPanel);
        SoftwareInfoFrame->setFrameShadow(QFrame::Sunken);
        gridLayout_2 = new QGridLayout(SoftwareInfoFrame);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        BuildDateValue = new QLabel(SoftwareInfoFrame);
        BuildDateValue->setObjectName(QString::fromUtf8("BuildDateValue"));
        BuildDateValue->setText(QString::fromUtf8("Build Date Value"));

        gridLayout_2->addWidget(BuildDateValue, 6, 1, 1, 1);

        GitCommitDateValue = new QLabel(SoftwareInfoFrame);
        GitCommitDateValue->setObjectName(QString::fromUtf8("GitCommitDateValue"));
        GitCommitDateValue->setText(QString::fromUtf8("Git Commit Date Value"));

        gridLayout_2->addWidget(GitCommitDateValue, 8, 1, 1, 1);

        GitlabLinkValue = new QLabel(SoftwareInfoFrame);
        GitlabLinkValue->setObjectName(QString::fromUtf8("GitlabLinkValue"));
        GitlabLinkValue->setTextFormat(Qt::RichText);
        GitlabLinkValue->setOpenExternalLinks(true);

        gridLayout_2->addWidget(GitlabLinkValue, 10, 1, 1, 1);

        SDKVersionLabel = new QLabel(SoftwareInfoFrame);
        SDKVersionLabel->setObjectName(QString::fromUtf8("SDKVersionLabel"));

        gridLayout_2->addWidget(SDKVersionLabel, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 12, 0, 1, 1);

        WebsiteLinkLabel = new QLabel(SoftwareInfoFrame);
        WebsiteLinkLabel->setObjectName(QString::fromUtf8("WebsiteLinkLabel"));

        gridLayout_2->addWidget(WebsiteLinkLabel, 11, 0, 1, 1);

        BuildDateLabel = new QLabel(SoftwareInfoFrame);
        BuildDateLabel->setObjectName(QString::fromUtf8("BuildDateLabel"));

        gridLayout_2->addWidget(BuildDateLabel, 6, 0, 1, 1);

        GitCommitIDLabel = new QLabel(SoftwareInfoFrame);
        GitCommitIDLabel->setObjectName(QString::fromUtf8("GitCommitIDLabel"));

        gridLayout_2->addWidget(GitCommitIDLabel, 7, 0, 1, 1);

        GitCommitDateLabel = new QLabel(SoftwareInfoFrame);
        GitCommitDateLabel->setObjectName(QString::fromUtf8("GitCommitDateLabel"));

        gridLayout_2->addWidget(GitCommitDateLabel, 8, 0, 1, 1);

        QtVersionValue = new QLabel(SoftwareInfoFrame);
        QtVersionValue->setObjectName(QString::fromUtf8("QtVersionValue"));

        gridLayout_2->addWidget(QtVersionValue, 4, 1, 1, 1);

        GitlabLinkLabel = new QLabel(SoftwareInfoFrame);
        GitlabLinkLabel->setObjectName(QString::fromUtf8("GitlabLinkLabel"));

        gridLayout_2->addWidget(GitlabLinkLabel, 10, 0, 1, 1);

        GitBranchValue = new QLabel(SoftwareInfoFrame);
        GitBranchValue->setObjectName(QString::fromUtf8("GitBranchValue"));
        GitBranchValue->setText(QString::fromUtf8("Git Branch Value"));

        gridLayout_2->addWidget(GitBranchValue, 9, 1, 1, 1);

        WebsiteLinkValue = new QLabel(SoftwareInfoFrame);
        WebsiteLinkValue->setObjectName(QString::fromUtf8("WebsiteLinkValue"));
        WebsiteLinkValue->setTextFormat(Qt::RichText);
        WebsiteLinkValue->setOpenExternalLinks(true);

        gridLayout_2->addWidget(WebsiteLinkValue, 11, 1, 1, 1);

        PluginAPIVersionValue = new QLabel(SoftwareInfoFrame);
        PluginAPIVersionValue->setObjectName(QString::fromUtf8("PluginAPIVersionValue"));
        PluginAPIVersionValue->setText(QString::fromUtf8("Plugin API Version Value"));

        gridLayout_2->addWidget(PluginAPIVersionValue, 3, 1, 1, 1);

        GitCommitIDValue = new QLabel(SoftwareInfoFrame);
        GitCommitIDValue->setObjectName(QString::fromUtf8("GitCommitIDValue"));
        GitCommitIDValue->setText(QString::fromUtf8("Git Commit ID Value"));
        GitCommitIDValue->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout_2->addWidget(GitCommitIDValue, 7, 1, 1, 1);

        PluginAPIVersionLabel = new QLabel(SoftwareInfoFrame);
        PluginAPIVersionLabel->setObjectName(QString::fromUtf8("PluginAPIVersionLabel"));

        gridLayout_2->addWidget(PluginAPIVersionLabel, 3, 0, 1, 1);

        GitBranchLabel = new QLabel(SoftwareInfoFrame);
        GitBranchLabel->setObjectName(QString::fromUtf8("GitBranchLabel"));

        gridLayout_2->addWidget(GitBranchLabel, 9, 0, 1, 1);

        SDKVersionValue = new QLabel(SoftwareInfoFrame);
        SDKVersionValue->setObjectName(QString::fromUtf8("SDKVersionValue"));
        SDKVersionValue->setText(QString::fromUtf8("SDK Version Value"));

        gridLayout_2->addWidget(SDKVersionValue, 2, 1, 1, 1);

        QtVersionLabel = new QLabel(SoftwareInfoFrame);
        QtVersionLabel->setObjectName(QString::fromUtf8("QtVersionLabel"));

        gridLayout_2->addWidget(QtVersionLabel, 4, 0, 1, 1);

        OsVersionLabel = new QLabel(SoftwareInfoFrame);
        OsVersionLabel->setObjectName(QString::fromUtf8("OsVersionLabel"));

        gridLayout_2->addWidget(OsVersionLabel, 5, 0, 1, 1);

        OsVersionValue = new QLabel(SoftwareInfoFrame);
        OsVersionValue->setObjectName(QString::fromUtf8("OsVersionValue"));

        gridLayout_2->addWidget(OsVersionValue, 5, 1, 1, 1);

        gridLayout_2->setColumnStretch(1, 1);

        gridLayout->addWidget(SoftwareInfoFrame, 2, 0, 1, 1);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        VersionLabel = new QLabel(OpenRGBSoftwareInfoPage);
        VersionLabel->setObjectName(QString::fromUtf8("VersionLabel"));

        gridLayout_3->addWidget(VersionLabel, 1, 1, 1, 1);

        LicenseValue = new QLabel(OpenRGBSoftwareInfoPage);
        LicenseValue->setObjectName(QString::fromUtf8("LicenseValue"));

        gridLayout_3->addWidget(LicenseValue, 2, 2, 1, 1);

        VersionValue = new QLabel(OpenRGBSoftwareInfoPage);
        VersionValue->setObjectName(QString::fromUtf8("VersionValue"));
        VersionValue->setText(QString::fromUtf8("Version Value"));

        gridLayout_3->addWidget(VersionValue, 1, 2, 1, 1);

        LicenseLabel = new QLabel(OpenRGBSoftwareInfoPage);
        LicenseLabel->setObjectName(QString::fromUtf8("LicenseLabel"));

        gridLayout_3->addWidget(LicenseLabel, 2, 1, 1, 1);

        IconLabel = new QLabel(OpenRGBSoftwareInfoPage);
        IconLabel->setObjectName(QString::fromUtf8("IconLabel"));
        IconLabel->setMinimumSize(QSize(128, 128));
        IconLabel->setPixmap(QPixmap(QString::fromUtf8(":/org.openrgb.OpenRGB.png")));
        IconLabel->setScaledContents(false);
        IconLabel->setAlignment(Qt::AlignCenter);

        gridLayout_3->addWidget(IconLabel, 0, 0, 5, 1);

        CopyrightLabel = new QLabel(OpenRGBSoftwareInfoPage);
        CopyrightLabel->setObjectName(QString::fromUtf8("CopyrightLabel"));

        gridLayout_3->addWidget(CopyrightLabel, 3, 1, 1, 1);

        CopyrightValue = new QLabel(OpenRGBSoftwareInfoPage);
        CopyrightValue->setObjectName(QString::fromUtf8("CopyrightValue"));

        gridLayout_3->addWidget(CopyrightValue, 3, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 2, 3, 1, 1);

        ProjectDescriptionLabel = new QLabel(OpenRGBSoftwareInfoPage);
        ProjectDescriptionLabel->setObjectName(QString::fromUtf8("ProjectDescriptionLabel"));

        gridLayout_3->addWidget(ProjectDescriptionLabel, 0, 1, 1, 3);


        gridLayout->addLayout(gridLayout_3, 0, 0, 1, 1);


        retranslateUi(OpenRGBSoftwareInfoPage);

        QMetaObject::connectSlotsByName(OpenRGBSoftwareInfoPage);
    } // setupUi

    void retranslateUi(QFrame *OpenRGBSoftwareInfoPage)
    {
        GitlabLinkValue->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "<a href=\"https://gitlab.com/CalcProgrammer1/OpenRGB\">https://gitlab.com/CalcProgrammer1/OpenRGB</a>", nullptr));
        SDKVersionLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "SDK Version:", nullptr));
        WebsiteLinkLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Website:", nullptr));
        BuildDateLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Build Date:", nullptr));
        GitCommitIDLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Git Commit ID:", nullptr));
        GitCommitDateLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Git Commit Date:", nullptr));
        QtVersionValue->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Qt Version Value", nullptr));
        GitlabLinkLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "GitLab:", nullptr));
        WebsiteLinkValue->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "<a href=\"https://openrgb.org\">https://openrgb.org</a>", nullptr));
        PluginAPIVersionLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Plugin API Version:", nullptr));
        GitBranchLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Git Branch:", nullptr));
        QtVersionLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Qt Version:", nullptr));
        OsVersionLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "OS Version:", nullptr));
        OsVersionValue->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "OS Version Value", nullptr));
        VersionLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Version:", nullptr));
        LicenseValue->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "GNU General Public License, version 2", nullptr));
        LicenseLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "License:", nullptr));
        IconLabel->setText(QString());
        CopyrightLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Copyright:", nullptr));
        CopyrightValue->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "Adam Honse, OpenRGB Team", nullptr));
        ProjectDescriptionLabel->setText(QCoreApplication::translate("OpenRGBSoftwareInfoPage", "<b>OpenRGB</b>, an open-source RGB control utility", nullptr));
        (void)OpenRGBSoftwareInfoPage;
    } // retranslateUi

};

namespace Ui {
    class OpenRGBSoftwareInfoPage: public Ui_OpenRGBSoftwareInfoPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENRGBSOFTWAREINFOPAGE_H
